import _defineProperty from '@babel/runtime/helpers/defineProperty';
import React__default, { memo, forwardRef } from 'react';
import { isPresent, findIndexBy, noop } from '@bigbinary/neeto-cist';
import classnames from 'classnames';
import Avatar from '@bigbinary/neetoui/Avatar';
import { jsx, jsxs, Fragment } from 'react/jsx-runtime';
import { P as PropTypes } from './index-DAYCJu79.js';
import Typography from '@bigbinary/neetoui/Typography';
import DateFormat from './DateFormat.js';
import MoreDropdown from './MoreDropdown.js';
import { globalProps } from '@bigbinary/neeto-commons-frontend/initializers';
import Tooltip from '@bigbinary/neetoui/Tooltip';
import { collectBy, prop, eqProps, pluck, pathEq } from 'ramda';
import { useTranslation } from 'react-i18next';
import EmojiPicker from './EmojiPicker.js';
import { n } from './inject-css-DmrvuTKK.js';
import './_commonjsHelpers-BFTU3MAI.js';
import '@bigbinary/neeto-commons-frontend/react-utils/useTimer';
import '@bigbinary/neeto-commons-frontend/utils/datetime';
import '@babel/runtime/helpers/objectWithoutProperties';
import '@bigbinary/neeto-icons/MenuHorizontal';
import '@bigbinary/neeto-icons/MenuVertical';
import '@bigbinary/neetoui/Button';
import '@bigbinary/neetoui/Dropdown';
import '@babel/runtime/helpers/slicedToArray';
import '@bigbinary/neeto-icons/SmileFaceGrey';
import 'emoji-mart';
import '@tanstack/react-query';
import 'axios';

var ActivityIcon = function ActivityIcon(_ref) {
  var icon = _ref.icon,
    unread = _ref.unread;
  return /*#__PURE__*/jsx("div", {
    className: "flex-shrink-0",
    children: /*#__PURE__*/jsxs("span", {
      className: classnames("neeto-ui-bg-gray-200 neeto-ui-text-gray-600 neeto-ui-rounded-full neeto-molecules-activity-node-icon relative z-10 flex h-7 w-7 items-center justify-center p-1", {
        "neeto-ui-text-primary-600 neeto-ui-bg-primary-100": unread
      }),
      children: [icon, unread && /*#__PURE__*/jsx("span", {
        className: "neeto-ui-rounded-full neeto-ui-bg-primary-800 absolute -right-0.5 -top-0.5 h-2 w-2"
      })]
    })
  });
};

var Activity = function Activity(_ref) {
  var user = _ref.user,
    icon = _ref.icon,
    _ref$unread = _ref.unread,
    unread = _ref$unread === void 0 ? false : _ref$unread,
    className = _ref.className,
    children = _ref.children;
  var avatar = {
    name: user.name,
    imageUrl: user.profileImageUrl
  };
  return /*#__PURE__*/jsxs("div", {
    className: classnames("neeto-molecules-engagements-node relative -mt-4 flex items-center gap-2 py-4", className),
    children: [/*#__PURE__*/jsx(ActivityIcon, {
      icon: icon,
      unread: unread
    }), /*#__PURE__*/jsx(Avatar, {
      size: "small",
      user: avatar
    }), /*#__PURE__*/jsx("div", {
      className: "pt-0.5",
      children: children
    })]
  });
};

var CommentHeader = function CommentHeader(_ref) {
  var user = _ref.user,
    comment = _ref.comment,
    info = _ref.info,
    actions = _ref.actions;
  var avatar = {
    name: user.name,
    imageUrl: user.profileImageUrl
  };
  return /*#__PURE__*/jsxs("div", {
    className: "neeto-ui-bg-gray-100 neeto-ui-border-gray-300 flex items-center justify-between rounded-t-md border-b py-2 pl-4 pr-2",
    children: [/*#__PURE__*/jsxs("div", {
      className: "flex min-w-0 flex-grow flex-wrap items-center gap-2",
      children: [/*#__PURE__*/jsx(Avatar, {
        size: "medium",
        user: avatar
      }), /*#__PURE__*/jsx(Typography, {
        className: "neeto-ui-text-gray-700",
        style: "body2",
        weight: "semibold",
        children: user.name
      }), /*#__PURE__*/jsx(Typography, {
        className: "neeto-ui-text-gray-700",
        style: "body2",
        children: "\u2022"
      }), info && /*#__PURE__*/jsxs(Fragment, {
        children: [/*#__PURE__*/jsx(Typography, {
          className: "neeto-ui-text-gray-500 lowercase",
          style: "body2",
          children: info
        }), /*#__PURE__*/jsx(Typography, {
          className: "neeto-ui-text-gray-700",
          style: "body2",
          children: "\u2022"
        })]
      }), comment.createdAt && /*#__PURE__*/jsx(DateFormat.FromNow, {
        date: comment.createdAt,
        typographyProps: {
          style: "body2",
          className: "neeto-ui-text-gray-500"
        }
      })]
    }), isPresent(actions) && /*#__PURE__*/jsx(MoreDropdown, {
      dropdownButtonProps: {
        className: "self-start fles-shrink-0"
      },
      dropdownProps: {
        position: "bottom-start"
      },
      menuItems: actions
    })]
  });
};

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var findOwnIndex = findIndexBy({
  userId: globalProps.user.id
});
var groupReactions = collectBy(prop("unified"));
var Reactions = function Reactions(_ref) {
  var reactions = _ref.reactions,
    onAdd = _ref.onAdd,
    onRemove = _ref.onRemove;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var groups = groupReactions(reactions);
  var onSelect = function onSelect(emoji) {
    // Try to find group to which emoji belongs in existing reactions.
    var group = groups.find(pathEq(emoji.unified, [0, "unified"]));
    if (group && findOwnIndex(group) >= 0) return; // User already reacted with same emoji.
    onAdd(_objectSpread(_objectSpread({}, emoji), {}, {
      emoji: emoji["native"]
    }));
  };
  return /*#__PURE__*/jsxs("div", {
    className: "mt-2 flex flex-wrap gap-0.5",
    children: [/*#__PURE__*/jsx("div", {
      className: "neeto-ui-rounded-full neeto-ui-bg-gray-200 mr-2",
      children: /*#__PURE__*/jsx(EmojiPicker, {
        onSelect: onSelect
      })
    }), groups.map(function (reactions) {
      var ownIndex = findOwnIndex(reactions);
      var selected = ownIndex >= 0;
      var reaction = selected ? reactions[ownIndex] : reactions[0];
      var names = pluck("reactor", reactions).join(", ");
      return /*#__PURE__*/jsx(Tooltip, {
        position: "top",
        content: /*#__PURE__*/jsx("p", {
          className: "text-center text-xs",
          children: t("neetoMolecules.common.reacted", {
            names: names
          })
        }),
        children: /*#__PURE__*/jsx("div", {
          className: classnames("neeto-ui-rounded-full mx-1 flex cursor-pointer items-center justify-center px-2 py-1", {
            "neeto-ui-bg-accent-100": selected,
            "neeto-ui-bg-gray-100": !selected
          }),
          onClick: function onClick() {
            return (selected ? onRemove : onAdd)(reaction);
          },
          children: /*#__PURE__*/jsxs(Typography, {
            className: "space-x-1 text-sm",
            style: "body2",
            children: [/*#__PURE__*/jsx("span", {
              className: "text-sm",
              children: reaction.emoji
            }), /*#__PURE__*/jsx("span", {
              className: "text-sm",
              children: reactions.length
            })]
          })
        })
      }, reaction.unified);
    })]
  });
};
var Reactions$1 = /*#__PURE__*/memo(Reactions, eqProps("reactions"));

var ENGAGEMENT_TYPES = {
  COMMENT: "comment",
  ACTIVITY: "activity"
};

var createCommentElementId = function createCommentElementId(comment) {
  return "neeto-molecules-engagement-comment--".concat(comment.id);
};
var defaultMatchType = function defaultMatchType(engagement) {
  if (engagement.commenter) return ENGAGEMENT_TYPES.COMMENT;else if (engagement.creator) return ENGAGEMENT_TYPES.ACTIVITY;
  return null;
};

var Comment = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var user = _ref.user,
    comment = _ref.comment,
    reactions = _ref.reactions,
    info = _ref.info,
    actions = _ref.actions,
    className = _ref.className,
    children = _ref.children,
    onAddReaction = _ref.onAddReaction,
    onRemoveReaction = _ref.onRemoveReaction;
  return /*#__PURE__*/jsxs("div", {
    ref: ref,
    id: createCommentElementId(comment),
    className: classnames("neeto-ui-bg-white neeto-ui-rounded-md neeto-ui-border-gray-300 neeto-molecules-comments-node mb-4 w-full border", className),
    children: [/*#__PURE__*/jsx(CommentHeader, {
      actions: actions,
      comment: comment,
      info: info,
      user: user
    }), /*#__PURE__*/jsxs("div", {
      className: "neeto-molecules-comments-node__inner p-4",
      children: [children, reactions !== false && /*#__PURE__*/jsx(Reactions$1, {
        reactions: reactions,
        onAdd: onAddReaction,
        onRemove: onRemoveReaction
      })]
    })]
  });
});
Comment.displayName = "Comment";
Comment.propTypes = {
  /** Object representing the user information  */
  user: PropTypes.shape({
    name: PropTypes.string.isRequired
  }).isRequired,
  /** Object representing the comment item.  */
  comment: PropTypes.shape({
    id: PropTypes.string.isRequired,
    createdAt: PropTypes.string.isRequired
  }).isRequired,
  /** Array of reactions. Settings this to `false` will disable reactions for the item  */
  reactions: PropTypes.oneOfType([PropTypes.array, PropTypes.bool]),
  /**  Optional text label to be displayed in the header. */
  info: PropTypes.string,
  /**  Optional action items to be passed to the menuItems prop of the actions dropdown */
  actions: PropTypes.arrayOf(PropTypes.shape({
    isVisible: PropTypes.bool,
    key: PropTypes.string.isRequired,
    label: PropTypes.string.isRequired,
    onClick: PropTypes.func.isRequired
  })),
  /**  Additional classes passed on to the board view. */
  className: PropTypes.string,
  /** Callback function triggered when a reaction (emoji) is added */
  onAddReaction: PropTypes.func,
  /** Callback function triggered when a reaction (emoji) is removed*/
  onRemoveReaction: PropTypes.func
};

var css = ".neeto-molecules-comments-node{position:relative}.neeto-molecules-comments-node:before{background-color:rgb(var(--neeto-ui-gray-200));content:\"\";height:1rem;left:13px;position:absolute;top:calc(100% + 1px);transform:translateX(-50%);width:2px}.neeto-molecules-comments-node:last-child:before{display:none}.neeto-molecules-engagements-node{position:relative}.neeto-molecules-engagements-node:before{background-color:rgb(var(--neeto-ui-gray-200));content:\"\";height:100%;left:14px;position:absolute;top:0;transform:translateX(-50%);width:2px}.neeto-molecules-activity-node-icon svg{height:16px;width:16px}";
n(css,{});

var Engagements = function Engagements(_ref) {
  var data = _ref.data,
    _ref$isActivitiesEnab = _ref.isActivitiesEnabled,
    isActivitiesEnabled = _ref$isActivitiesEnab === void 0 ? false : _ref$isActivitiesEnab,
    _ref$matchType = _ref.matchType,
    matchType = _ref$matchType === void 0 ? defaultMatchType : _ref$matchType,
    renderComment = _ref.renderComment,
    renderActivity = _ref.renderActivity;
  var rendererHashmap = _defineProperty(_defineProperty({}, ENGAGEMENT_TYPES.COMMENT, renderComment), ENGAGEMENT_TYPES.ACTIVITY, isActivitiesEnabled ? renderActivity : noop);
  return /*#__PURE__*/jsx(Fragment, {
    children: data.map(function (engagement, index) {
      var type = matchType(engagement);
      var renderer = rendererHashmap[type];
      if (!renderer) return null;
      return /*#__PURE__*/jsx(React__default.Fragment, {
        children: renderer(engagement, index)
      }, engagement.id);
    })
  });
};
Engagements.displayName = "Engagements";
Engagements.Comment = Comment;
Engagements.Activity = Activity;
Engagements.TYPES = ENGAGEMENT_TYPES;

export { Engagements as default };
//# sourceMappingURL=Engagements.js.map
