import _asyncToGenerator from '@babel/runtime/helpers/asyncToGenerator';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import _regeneratorRuntime from '@babel/runtime/regenerator';
import { useState } from 'react';
import Button$1 from '@bigbinary/neetoui/Button';
import Toastr from '@bigbinary/neetoui/Toastr';
import Typography from '@bigbinary/neetoui/Typography';
import { useTranslation, Trans } from 'react-i18next';
import { t } from 'i18next';
import * as yup from 'yup';
import { Formik, Form } from 'formik';
import { getQueryParams } from '@bigbinary/neeto-commons-frontend/utils';
import Button from '@bigbinary/neetoui/formik/Button';
import Input from '@bigbinary/neetoui/formik/Input';
import { assoc } from 'ramda';
import { jsx, jsxs } from 'react/jsx-runtime';

var INITIAL_FORM_VALUES = {
  email: "",
  password: ""
};
var DEFAULT_EMAIL = "oliver@example.com";
var DEFAULT_PASSWORD = "welcome";
var LOGIN_FORM_VALIDATION_SCHEMA = yup.object().shape({
  email: yup.string().email(t("neetoMolecules.login.invalidEmail")).required(t("neetoMolecules.login.emailRequired")),
  password: yup.string().required(t("neetoMolecules.login.passwordRequired"))
});

var SignInForm = function SignInForm(_ref) {
  var handleFormSubmit = _ref.handleFormSubmit;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var _getQueryParams = getQueryParams(),
    _getQueryParams$email = _getQueryParams.email,
    email = _getQueryParams$email === void 0 ? "" : _getQueryParams$email;
  var emailPrefilledInitialValues = function emailPrefilledInitialValues() {
    return assoc("email", email, INITIAL_FORM_VALUES);
  };
  if (Button === undefined) {
    return /*#__PURE__*/jsx(Trans, {
      components: {
        code: /*#__PURE__*/jsx("code", {})
      },
      i18nKey: "neetoMolecules.login.installNeetoUI"
    });
  }
  return /*#__PURE__*/jsx(Formik, {
    initialValues: emailPrefilledInitialValues(),
    validationSchema: LOGIN_FORM_VALIDATION_SCHEMA,
    onSubmit: handleFormSubmit,
    children: /*#__PURE__*/jsxs(Form, {
      className: "w-full space-y-6",
      children: [/*#__PURE__*/jsx(Input, {
        required: true,
        "data-cy": "login-email-text-field",
        "data-test-id": "login-email",
        label: t("neetoMolecules.login.email"),
        name: "email",
        size: "large"
      }), /*#__PURE__*/jsx(Input, {
        required: true,
        "data-cy": "login-password-text-field",
        "data-test-id": "login-password",
        label: t("neetoMolecules.login.password"),
        name: "password",
        size: "large",
        type: "password"
      }), /*#__PURE__*/jsx(Button, {
        fullWidth: true,
        "data-cy": "login-submit-button",
        "data-test-id": "login-submit-button",
        label: t("neetoMolecules.login.login"),
        size: "large",
        style: "secondary",
        type: "submit"
      })]
    })
  });
};

var SignIn = function SignIn(_ref) {
  var handleSubmit = _ref.handleSubmit;
  var _useState = useState(null),
    _useState2 = _slicedToArray(_useState, 2),
    isSubmitting = _useState2[0],
    setIsSubmitting = _useState2[1];
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var redirectAfterSuccessfulLogin = function redirectAfterSuccessfulLogin(redirectTo) {
    window.location.pathname = redirectTo || "/";
  };
  var handleFormSubmit = /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(formValues) {
      var response;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            _context.next = 3;
            return handleSubmit({
              user: formValues
            });
          case 3:
            response = _context.sent;
            Toastr.success(t("neetoMolecules.login.success"));
            redirectAfterSuccessfulLogin(response.redirectTo);
            _context.next = 10;
            break;
          case 8:
            _context.prev = 8;
            _context.t0 = _context["catch"](0);
          case 10:
          case "end":
            return _context.stop();
        }
      }, _callee, null, [[0, 8]]);
    }));
    return function handleFormSubmit(_x) {
      return _ref2.apply(this, arguments);
    };
  }();
  var loginAsOliver = /*#__PURE__*/function () {
    var _ref3 = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) switch (_context2.prev = _context2.next) {
          case 0:
            setIsSubmitting(true);
            _context2.next = 3;
            return handleFormSubmit({
              email: DEFAULT_EMAIL,
              password: DEFAULT_PASSWORD
            });
          case 3:
            setIsSubmitting(false);
          case 4:
          case "end":
            return _context2.stop();
        }
      }, _callee2);
    }));
    return function loginAsOliver() {
      return _ref3.apply(this, arguments);
    };
  }();
  return /*#__PURE__*/jsx("div", {
    className: "flex h-screen w-full justify-center",
    children: /*#__PURE__*/jsxs("div", {
      className: "neeto-ui-bg-white neeto-ui-rounded-lg neeto-ui-shadow-sm w-full max-w-lg space-y-6 self-center p-8 sm:min-w-max sm:p-10",
      children: [/*#__PURE__*/jsx(Typography, {
        style: "h3",
        weight: "medium",
        children: /*#__PURE__*/jsx(Trans, {
          components: {
            bold: /*#__PURE__*/jsx("b", {
              "data-test-id": "organization-name"
            })
          },
          i18nKey: "neetoMolecules.login.toOrganizationAccount",
          values: {
            organizationName: globalProps.organization.name
          }
        })
      }), /*#__PURE__*/jsx(Button$1, {
        fullWidth: true,
        disabled: isSubmitting,
        label: t("neetoMolecules.login.loginAsOliver"),
        loading: isSubmitting,
        size: "large",
        style: "primary",
        onClick: loginAsOliver
      }), /*#__PURE__*/jsx(Typography, {
        className: "text-center",
        style: "body1",
        weight: "semibold",
        children: t("neetoMolecules.common.or").toLocaleUpperCase()
      }), /*#__PURE__*/jsx(SignInForm, {
        handleFormSubmit: handleFormSubmit
      })]
    })
  });
};

export { SignIn as default };
//# sourceMappingURL=LoginPage.js.map
