import _defineProperty from '@babel/runtime/helpers/defineProperty';
import i18next, { t } from 'i18next';
import { values, last, pluck, identity, any, assoc, prop, fromPairs, isEmpty } from 'ramda';
import { useMutation, useQuery, QueryClient, QueryClientProvider } from '@tanstack/react-query';
import Info from '@bigbinary/neeto-icons/Info';
import Callout from '@bigbinary/neetoui/Callout';
import { Trans, useTranslation } from 'react-i18next';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import { memo, useEffect, useState, useRef } from 'react';
import classnames from 'classnames';
import { capitalize, noop, isNotEmpty } from '@bigbinary/neeto-cist';
import usePrevious from '@bigbinary/neeto-commons-frontend/react-utils/usePrevious';
import Button from '@bigbinary/neetoui/Button';
import Toastr from '@bigbinary/neetoui/Toastr';
import Typography from '@bigbinary/neetoui/Typography';
import Spinner from '@bigbinary/neetoui/Spinner';
import { jsxs, Fragment, jsx } from 'react/jsx-runtime';
import Select from '@bigbinary/neetoui/Select';
import CopyToClipboardButton from './CopyToClipboardButton.js';
import { c as commonjsGlobal, g as getDefaultExportFromCjs } from './_commonjsHelpers-BFTU3MAI.js';
import { n } from './inject-css-DmrvuTKK.js';
import { Formik, Form } from 'formik';
import Pane from '@bigbinary/neetoui/Pane';
import Input from '@bigbinary/neetoui/formik/Input';
import MultiEmailInput from '@bigbinary/neetoui/formik/MultiEmailInput';
import axios from 'axios';
import * as yup from 'yup';
import useMutationWithInvalidation from '@bigbinary/neeto-commons-frontend/react-utils/useMutationWithInvalidation';
import Label from '@bigbinary/neetoui/Label';
import withT from '@bigbinary/neeto-commons-frontend/react-utils/withT';
import Switch from '@bigbinary/neetoui/Switch';
import Tooltip from '@bigbinary/neetoui/Tooltip';
import '@babel/runtime/helpers/objectWithoutProperties';
import '@bigbinary/neeto-commons-frontend/utils/general';
import '@bigbinary/neeto-icons/Copy';
import '@bigbinary/neeto-icons/Check';

var NEETO_WIDGET_USER_IDENTITY_KEY = "NeetoWidgetUserIdentity";
var SESSION_CONTEXT_KEY = "NeetoReplayWidgetSessionContext";
var INSTALLATION_HELP_EMAIL = "support@neeto.com";
var SAMPLE_CONTEXT_CODE_STRING = "window.".concat(SESSION_CONTEXT_KEY, " = {\n  key1: \"value\",\n  key2: [\"array\", \"of\", \"values\"],\n  /* More key-value pairs */\n}");
var WIDGET_TYPES = {
  engage: "engage",
  chat: "chat",
  replay: "replay"
};
var WIDGET_HELP_LINKS = {
  engage: "https://help.neetoengage.com/articles/installation",
  chat: "https://help.neetochat.com/articles/installation-using-javascript-snippet",
  replay: "https://help.neetoreplay.com/articles/install-widget"
};
var WIDGET_DESCRIPTIONS = {
  engage: t("neetoMolecules.widget.email.body.values.embedCode.description.engage"),
  chat: t("neetoMolecules.widget.email.body.values.embedCode.description.chat"),
  replay: t("neetoMolecules.widget.email.body.values.embedCode.description.replay")
};
var WIDGET_TYPES_VALUES = values(WIDGET_TYPES);
var QUERY_KEYS = {
  apiKey: "neetoWidgetApiKey",
  configuration: "neetoWidgetConfiguration"
};
var DEFAULT_QUERY_STALE_TIME = 60 * 60 * 1000; // 1 hour in milliseconds

var EMAIL_TYPES = {
  embedCode: "embedCode",
  userIdentity: "userIdentity",
  sessionContext: "sessionContext",
  "null": ""
};
var RAILS_ENV = {
  production: "production",
  staging: "staging",
  development: "development"
};
var NEETO_WIDGET_SCRIPT_URL = {
  staging: "https://d3nshle8hzelnq.cloudfront.net/neeto-widget-staging.js",
  production: "https://d13nryxs46eypn.cloudfront.net/neeto-widget.js"
};
var AVAILABLE_FRAMEWORK_OPTIONS = Object.freeze({
  rails: "rails",
  django: "django",
  php: "php"
});
var FRAMEWORK_SELECT_OPTIONS = [{
  label: "Ruby(Rails)",
  value: AVAILABLE_FRAMEWORK_OPTIONS.rails
}, {
  label: "Python(Django)",
  value: AVAILABLE_FRAMEWORK_OPTIONS.django
}, {
  label: "PHP",
  value: AVAILABLE_FRAMEWORK_OPTIONS.php
}];
var SAMPLE_USER_IDENTITY_CODE_STRING = _defineProperty(_defineProperty(_defineProperty({}, AVAILABLE_FRAMEWORK_OPTIONS.rails, "window.".concat(NEETO_WIDGET_USER_IDENTITY_KEY, " = {\n  user_identifier: \"<%= current_user.id %>\", // User identifier\"\n  name: \"<%= current_user.name %>\", // Full name\n  email: \"<%= current_user.email %>\", // Email address\n  started_at: \"<%= current_user.created_at.to_i %>\" // Signup date as a Unix timestamp ,\n}")), AVAILABLE_FRAMEWORK_OPTIONS.django, "window.".concat(NEETO_WIDGET_USER_IDENTITY_KEY, " = {\n  user_identifier: \"{{ request.user.id|escapejs }}\", // User identifier\n  name: \"{{ request.user.name|escapejs }}\", // Full name\n  email: \"{{ request.user.email|escapejs }}\", // Email address\n  started_at: \"{{ request.user.created_at|date:'U' }}\" // Signup date as a Unix timestamp\"\n}")), AVAILABLE_FRAMEWORK_OPTIONS.php, "window.".concat(NEETO_WIDGET_USER_IDENTITY_KEY, " = {\n  user_identifier: <?php echo json_encode($current_user->id) ?>, // User identifier\n  name: <?php echo json_encode($current_user->name) ?>, // Full name\n  email: <?php echo json_encode($current_user->email) ?>, // Email address\n  started_at: <?php echo strtotime($current_user->created_at) ?> // Signup date as a Unix timestamp\" ,\n}"));
var WIDGET_CONFIG_URL = "/api/widget/v1/neeto_widget_tokens";
var EMBED_CODE_EMAIL_URL = "/api/widget/v1/email_snippets";
var CHAT_WIDGET_KB_BASE_URL = "https://help.neetochat.com";
var ENGAGE_WIDGET_KB_BASE_URL = "https://help.neetoengage.com";
var REPLAY_WIDGET_KB_BASE_URL = "https://help.neetoreplay.com";
var NEETO_REPLAY_CONFIGURE_URL = "".concat(REPLAY_WIDGET_KB_BASE_URL, "/articles/configure-widget");
var NEETO_CHAT_USER_IDENTITY_URL = "".concat(CHAT_WIDGET_KB_BASE_URL, "/articles/info-about-logged-in-users");
var WIDGET_KB_HELP_URL = {
  engage: "".concat(ENGAGE_WIDGET_KB_BASE_URL, "/categories/widget-installation-usage"),
  chat: "".concat(CHAT_WIDGET_KB_BASE_URL, "/categories/installation"),
  replay: "".concat(REPLAY_WIDGET_KB_BASE_URL, "/categories/widget-installation-usage")
};
var USE_NEETO_WIDGET_NPM_PAGE_URL = "https://www.npmjs.com/package/@bigbinary/react-use-neeto-widget";

var ChatWidgetBody = function ChatWidgetBody(_ref) {
  var widgets = _ref.widgets;
  return /*#__PURE__*/jsxs(Fragment, {
    children: [widgets.includes(WIDGET_TYPES.engage) && /*#__PURE__*/jsx(Trans, {
      i18nKey: "neetoMolecules.widget.email.body.values.embedCode.engageHelp",
      values: {
        helpLink: WIDGET_HELP_LINKS.engage
      },
      components: {
        p: /*#__PURE__*/jsx(Typography, {
          className: "mb-2",
          style: "body2"
        }),
        a: /*#__PURE__*/jsx(Button, {
          href: WIDGET_HELP_LINKS.engage,
          rel: "noreferrer",
          style: "link",
          target: "_blank"
        })
      }
    }), widgets.includes(WIDGET_TYPES.chat) && /*#__PURE__*/jsx(Trans, {
      i18nKey: "neetoMolecules.widget.email.body.values.embedCode.chatHelp",
      values: {
        helpLink: WIDGET_HELP_LINKS.chat
      },
      components: {
        p: /*#__PURE__*/jsx(Typography, {
          className: "mb-2",
          style: "body2"
        }),
        a: /*#__PURE__*/jsx(Button, {
          href: WIDGET_HELP_LINKS.chat,
          rel: "noreferrer",
          style: "link",
          target: "_blank"
        })
      }
    }), widgets.includes(WIDGET_TYPES.replay) && /*#__PURE__*/jsx(Trans, {
      i18nKey: "neetoMolecules.widget.email.body.values.embedCode.replayHelp",
      values: {
        helpLink: WIDGET_HELP_LINKS.replay
      },
      components: {
        p: /*#__PURE__*/jsx(Typography, {
          className: "mb-2",
          style: "body2"
        }),
        a: /*#__PURE__*/jsx(Button, {
          href: WIDGET_HELP_LINKS.replay,
          rel: "noreferrer",
          style: "link",
          target: "_blank"
        })
      }
    })]
  });
};

var prism = {exports: {}};

(function (module) {
	/* **********************************************
	     Begin prism-core.js
	********************************************** */

	/// <reference lib="WebWorker"/>

	var _self = (typeof window !== 'undefined')
		? window   // if in browser
		: (
			(typeof WorkerGlobalScope !== 'undefined' && self instanceof WorkerGlobalScope)
				? self // if in worker
				: {}   // if in node js
		);

	/**
	 * Prism: Lightweight, robust, elegant syntax highlighting
	 *
	 * @license MIT <https://opensource.org/licenses/MIT>
	 * @author Lea Verou <https://lea.verou.me>
	 * @namespace
	 * @public
	 */
	var Prism = (function (_self) {

		// Private helper vars
		var lang = /(?:^|\s)lang(?:uage)?-([\w-]+)(?=\s|$)/i;
		var uniqueId = 0;

		// The grammar object for plaintext
		var plainTextGrammar = {};


		var _ = {
			/**
			 * By default, Prism will attempt to highlight all code elements (by calling {@link Prism.highlightAll}) on the
			 * current page after the page finished loading. This might be a problem if e.g. you wanted to asynchronously load
			 * additional languages or plugins yourself.
			 *
			 * By setting this value to `true`, Prism will not automatically highlight all code elements on the page.
			 *
			 * You obviously have to change this value before the automatic highlighting started. To do this, you can add an
			 * empty Prism object into the global scope before loading the Prism script like this:
			 *
			 * ```js
			 * window.Prism = window.Prism || {};
			 * Prism.manual = true;
			 * // add a new <script> to load Prism's script
			 * ```
			 *
			 * @default false
			 * @type {boolean}
			 * @memberof Prism
			 * @public
			 */
			manual: _self.Prism && _self.Prism.manual,
			/**
			 * By default, if Prism is in a web worker, it assumes that it is in a worker it created itself, so it uses
			 * `addEventListener` to communicate with its parent instance. However, if you're using Prism manually in your
			 * own worker, you don't want it to do this.
			 *
			 * By setting this value to `true`, Prism will not add its own listeners to the worker.
			 *
			 * You obviously have to change this value before Prism executes. To do this, you can add an
			 * empty Prism object into the global scope before loading the Prism script like this:
			 *
			 * ```js
			 * window.Prism = window.Prism || {};
			 * Prism.disableWorkerMessageHandler = true;
			 * // Load Prism's script
			 * ```
			 *
			 * @default false
			 * @type {boolean}
			 * @memberof Prism
			 * @public
			 */
			disableWorkerMessageHandler: _self.Prism && _self.Prism.disableWorkerMessageHandler,

			/**
			 * A namespace for utility methods.
			 *
			 * All function in this namespace that are not explicitly marked as _public_ are for __internal use only__ and may
			 * change or disappear at any time.
			 *
			 * @namespace
			 * @memberof Prism
			 */
			util: {
				encode: function encode(tokens) {
					if (tokens instanceof Token) {
						return new Token(tokens.type, encode(tokens.content), tokens.alias);
					} else if (Array.isArray(tokens)) {
						return tokens.map(encode);
					} else {
						return tokens.replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/\u00a0/g, ' ');
					}
				},

				/**
				 * Returns the name of the type of the given value.
				 *
				 * @param {any} o
				 * @returns {string}
				 * @example
				 * type(null)      === 'Null'
				 * type(undefined) === 'Undefined'
				 * type(123)       === 'Number'
				 * type('foo')     === 'String'
				 * type(true)      === 'Boolean'
				 * type([1, 2])    === 'Array'
				 * type({})        === 'Object'
				 * type(String)    === 'Function'
				 * type(/abc+/)    === 'RegExp'
				 */
				type: function (o) {
					return Object.prototype.toString.call(o).slice(8, -1);
				},

				/**
				 * Returns a unique number for the given object. Later calls will still return the same number.
				 *
				 * @param {Object} obj
				 * @returns {number}
				 */
				objId: function (obj) {
					if (!obj['__id']) {
						Object.defineProperty(obj, '__id', { value: ++uniqueId });
					}
					return obj['__id'];
				},

				/**
				 * Creates a deep clone of the given object.
				 *
				 * The main intended use of this function is to clone language definitions.
				 *
				 * @param {T} o
				 * @param {Record<number, any>} [visited]
				 * @returns {T}
				 * @template T
				 */
				clone: function deepClone(o, visited) {
					visited = visited || {};

					var clone; var id;
					switch (_.util.type(o)) {
						case 'Object':
							id = _.util.objId(o);
							if (visited[id]) {
								return visited[id];
							}
							clone = /** @type {Record<string, any>} */ ({});
							visited[id] = clone;

							for (var key in o) {
								if (o.hasOwnProperty(key)) {
									clone[key] = deepClone(o[key], visited);
								}
							}

							return /** @type {any} */ (clone);

						case 'Array':
							id = _.util.objId(o);
							if (visited[id]) {
								return visited[id];
							}
							clone = [];
							visited[id] = clone;

							(/** @type {Array} */(/** @type {any} */(o))).forEach(function (v, i) {
								clone[i] = deepClone(v, visited);
							});

							return /** @type {any} */ (clone);

						default:
							return o;
					}
				},

				/**
				 * Returns the Prism language of the given element set by a `language-xxxx` or `lang-xxxx` class.
				 *
				 * If no language is set for the element or the element is `null` or `undefined`, `none` will be returned.
				 *
				 * @param {Element} element
				 * @returns {string}
				 */
				getLanguage: function (element) {
					while (element) {
						var m = lang.exec(element.className);
						if (m) {
							return m[1].toLowerCase();
						}
						element = element.parentElement;
					}
					return 'none';
				},

				/**
				 * Sets the Prism `language-xxxx` class of the given element.
				 *
				 * @param {Element} element
				 * @param {string} language
				 * @returns {void}
				 */
				setLanguage: function (element, language) {
					// remove all `language-xxxx` classes
					// (this might leave behind a leading space)
					element.className = element.className.replace(RegExp(lang, 'gi'), '');

					// add the new `language-xxxx` class
					// (using `classList` will automatically clean up spaces for us)
					element.classList.add('language-' + language);
				},

				/**
				 * Returns the script element that is currently executing.
				 *
				 * This does __not__ work for line script element.
				 *
				 * @returns {HTMLScriptElement | null}
				 */
				currentScript: function () {
					if (typeof document === 'undefined') {
						return null;
					}
					if ('currentScript' in document && 1 < 2 /* hack to trip TS' flow analysis */) {
						return /** @type {any} */ (document.currentScript);
					}

					// IE11 workaround
					// we'll get the src of the current script by parsing IE11's error stack trace
					// this will not work for inline scripts

					try {
						throw new Error();
					} catch (err) {
						// Get file src url from stack. Specifically works with the format of stack traces in IE.
						// A stack will look like this:
						//
						// Error
						//    at _.util.currentScript (http://localhost/components/prism-core.js:119:5)
						//    at Global code (http://localhost/components/prism-core.js:606:1)

						var src = (/at [^(\r\n]*\((.*):[^:]+:[^:]+\)$/i.exec(err.stack) || [])[1];
						if (src) {
							var scripts = document.getElementsByTagName('script');
							for (var i in scripts) {
								if (scripts[i].src == src) {
									return scripts[i];
								}
							}
						}
						return null;
					}
				},

				/**
				 * Returns whether a given class is active for `element`.
				 *
				 * The class can be activated if `element` or one of its ancestors has the given class and it can be deactivated
				 * if `element` or one of its ancestors has the negated version of the given class. The _negated version_ of the
				 * given class is just the given class with a `no-` prefix.
				 *
				 * Whether the class is active is determined by the closest ancestor of `element` (where `element` itself is
				 * closest ancestor) that has the given class or the negated version of it. If neither `element` nor any of its
				 * ancestors have the given class or the negated version of it, then the default activation will be returned.
				 *
				 * In the paradoxical situation where the closest ancestor contains __both__ the given class and the negated
				 * version of it, the class is considered active.
				 *
				 * @param {Element} element
				 * @param {string} className
				 * @param {boolean} [defaultActivation=false]
				 * @returns {boolean}
				 */
				isActive: function (element, className, defaultActivation) {
					var no = 'no-' + className;

					while (element) {
						var classList = element.classList;
						if (classList.contains(className)) {
							return true;
						}
						if (classList.contains(no)) {
							return false;
						}
						element = element.parentElement;
					}
					return !!defaultActivation;
				}
			},

			/**
			 * This namespace contains all currently loaded languages and the some helper functions to create and modify languages.
			 *
			 * @namespace
			 * @memberof Prism
			 * @public
			 */
			languages: {
				/**
				 * The grammar for plain, unformatted text.
				 */
				plain: plainTextGrammar,
				plaintext: plainTextGrammar,
				text: plainTextGrammar,
				txt: plainTextGrammar,

				/**
				 * Creates a deep copy of the language with the given id and appends the given tokens.
				 *
				 * If a token in `redef` also appears in the copied language, then the existing token in the copied language
				 * will be overwritten at its original position.
				 *
				 * ## Best practices
				 *
				 * Since the position of overwriting tokens (token in `redef` that overwrite tokens in the copied language)
				 * doesn't matter, they can technically be in any order. However, this can be confusing to others that trying to
				 * understand the language definition because, normally, the order of tokens matters in Prism grammars.
				 *
				 * Therefore, it is encouraged to order overwriting tokens according to the positions of the overwritten tokens.
				 * Furthermore, all non-overwriting tokens should be placed after the overwriting ones.
				 *
				 * @param {string} id The id of the language to extend. This has to be a key in `Prism.languages`.
				 * @param {Grammar} redef The new tokens to append.
				 * @returns {Grammar} The new language created.
				 * @public
				 * @example
				 * Prism.languages['css-with-colors'] = Prism.languages.extend('css', {
				 *     // Prism.languages.css already has a 'comment' token, so this token will overwrite CSS' 'comment' token
				 *     // at its original position
				 *     'comment': { ... },
				 *     // CSS doesn't have a 'color' token, so this token will be appended
				 *     'color': /\b(?:red|green|blue)\b/
				 * });
				 */
				extend: function (id, redef) {
					var lang = _.util.clone(_.languages[id]);

					for (var key in redef) {
						lang[key] = redef[key];
					}

					return lang;
				},

				/**
				 * Inserts tokens _before_ another token in a language definition or any other grammar.
				 *
				 * ## Usage
				 *
				 * This helper method makes it easy to modify existing languages. For example, the CSS language definition
				 * not only defines CSS highlighting for CSS documents, but also needs to define highlighting for CSS embedded
				 * in HTML through `<style>` elements. To do this, it needs to modify `Prism.languages.markup` and add the
				 * appropriate tokens. However, `Prism.languages.markup` is a regular JavaScript object literal, so if you do
				 * this:
				 *
				 * ```js
				 * Prism.languages.markup.style = {
				 *     // token
				 * };
				 * ```
				 *
				 * then the `style` token will be added (and processed) at the end. `insertBefore` allows you to insert tokens
				 * before existing tokens. For the CSS example above, you would use it like this:
				 *
				 * ```js
				 * Prism.languages.insertBefore('markup', 'cdata', {
				 *     'style': {
				 *         // token
				 *     }
				 * });
				 * ```
				 *
				 * ## Special cases
				 *
				 * If the grammars of `inside` and `insert` have tokens with the same name, the tokens in `inside`'s grammar
				 * will be ignored.
				 *
				 * This behavior can be used to insert tokens after `before`:
				 *
				 * ```js
				 * Prism.languages.insertBefore('markup', 'comment', {
				 *     'comment': Prism.languages.markup.comment,
				 *     // tokens after 'comment'
				 * });
				 * ```
				 *
				 * ## Limitations
				 *
				 * The main problem `insertBefore` has to solve is iteration order. Since ES2015, the iteration order for object
				 * properties is guaranteed to be the insertion order (except for integer keys) but some browsers behave
				 * differently when keys are deleted and re-inserted. So `insertBefore` can't be implemented by temporarily
				 * deleting properties which is necessary to insert at arbitrary positions.
				 *
				 * To solve this problem, `insertBefore` doesn't actually insert the given tokens into the target object.
				 * Instead, it will create a new object and replace all references to the target object with the new one. This
				 * can be done without temporarily deleting properties, so the iteration order is well-defined.
				 *
				 * However, only references that can be reached from `Prism.languages` or `insert` will be replaced. I.e. if
				 * you hold the target object in a variable, then the value of the variable will not change.
				 *
				 * ```js
				 * var oldMarkup = Prism.languages.markup;
				 * var newMarkup = Prism.languages.insertBefore('markup', 'comment', { ... });
				 *
				 * assert(oldMarkup !== Prism.languages.markup);
				 * assert(newMarkup === Prism.languages.markup);
				 * ```
				 *
				 * @param {string} inside The property of `root` (e.g. a language id in `Prism.languages`) that contains the
				 * object to be modified.
				 * @param {string} before The key to insert before.
				 * @param {Grammar} insert An object containing the key-value pairs to be inserted.
				 * @param {Object<string, any>} [root] The object containing `inside`, i.e. the object that contains the
				 * object to be modified.
				 *
				 * Defaults to `Prism.languages`.
				 * @returns {Grammar} The new grammar object.
				 * @public
				 */
				insertBefore: function (inside, before, insert, root) {
					root = root || /** @type {any} */ (_.languages);
					var grammar = root[inside];
					/** @type {Grammar} */
					var ret = {};

					for (var token in grammar) {
						if (grammar.hasOwnProperty(token)) {

							if (token == before) {
								for (var newToken in insert) {
									if (insert.hasOwnProperty(newToken)) {
										ret[newToken] = insert[newToken];
									}
								}
							}

							// Do not insert token which also occur in insert. See #1525
							if (!insert.hasOwnProperty(token)) {
								ret[token] = grammar[token];
							}
						}
					}

					var old = root[inside];
					root[inside] = ret;

					// Update references in other language definitions
					_.languages.DFS(_.languages, function (key, value) {
						if (value === old && key != inside) {
							this[key] = ret;
						}
					});

					return ret;
				},

				// Traverse a language definition with Depth First Search
				DFS: function DFS(o, callback, type, visited) {
					visited = visited || {};

					var objId = _.util.objId;

					for (var i in o) {
						if (o.hasOwnProperty(i)) {
							callback.call(o, i, o[i], type || i);

							var property = o[i];
							var propertyType = _.util.type(property);

							if (propertyType === 'Object' && !visited[objId(property)]) {
								visited[objId(property)] = true;
								DFS(property, callback, null, visited);
							} else if (propertyType === 'Array' && !visited[objId(property)]) {
								visited[objId(property)] = true;
								DFS(property, callback, i, visited);
							}
						}
					}
				}
			},

			plugins: {},

			/**
			 * This is the most high-level function in Prism’s API.
			 * It fetches all the elements that have a `.language-xxxx` class and then calls {@link Prism.highlightElement} on
			 * each one of them.
			 *
			 * This is equivalent to `Prism.highlightAllUnder(document, async, callback)`.
			 *
			 * @param {boolean} [async=false] Same as in {@link Prism.highlightAllUnder}.
			 * @param {HighlightCallback} [callback] Same as in {@link Prism.highlightAllUnder}.
			 * @memberof Prism
			 * @public
			 */
			highlightAll: function (async, callback) {
				_.highlightAllUnder(document, async, callback);
			},

			/**
			 * Fetches all the descendants of `container` that have a `.language-xxxx` class and then calls
			 * {@link Prism.highlightElement} on each one of them.
			 *
			 * The following hooks will be run:
			 * 1. `before-highlightall`
			 * 2. `before-all-elements-highlight`
			 * 3. All hooks of {@link Prism.highlightElement} for each element.
			 *
			 * @param {ParentNode} container The root element, whose descendants that have a `.language-xxxx` class will be highlighted.
			 * @param {boolean} [async=false] Whether each element is to be highlighted asynchronously using Web Workers.
			 * @param {HighlightCallback} [callback] An optional callback to be invoked on each element after its highlighting is done.
			 * @memberof Prism
			 * @public
			 */
			highlightAllUnder: function (container, async, callback) {
				var env = {
					callback: callback,
					container: container,
					selector: 'code[class*="language-"], [class*="language-"] code, code[class*="lang-"], [class*="lang-"] code'
				};

				_.hooks.run('before-highlightall', env);

				env.elements = Array.prototype.slice.apply(env.container.querySelectorAll(env.selector));

				_.hooks.run('before-all-elements-highlight', env);

				for (var i = 0, element; (element = env.elements[i++]);) {
					_.highlightElement(element, async === true, env.callback);
				}
			},

			/**
			 * Highlights the code inside a single element.
			 *
			 * The following hooks will be run:
			 * 1. `before-sanity-check`
			 * 2. `before-highlight`
			 * 3. All hooks of {@link Prism.highlight}. These hooks will be run by an asynchronous worker if `async` is `true`.
			 * 4. `before-insert`
			 * 5. `after-highlight`
			 * 6. `complete`
			 *
			 * Some the above hooks will be skipped if the element doesn't contain any text or there is no grammar loaded for
			 * the element's language.
			 *
			 * @param {Element} element The element containing the code.
			 * It must have a class of `language-xxxx` to be processed, where `xxxx` is a valid language identifier.
			 * @param {boolean} [async=false] Whether the element is to be highlighted asynchronously using Web Workers
			 * to improve performance and avoid blocking the UI when highlighting very large chunks of code. This option is
			 * [disabled by default](https://prismjs.com/faq.html#why-is-asynchronous-highlighting-disabled-by-default).
			 *
			 * Note: All language definitions required to highlight the code must be included in the main `prism.js` file for
			 * asynchronous highlighting to work. You can build your own bundle on the
			 * [Download page](https://prismjs.com/download.html).
			 * @param {HighlightCallback} [callback] An optional callback to be invoked after the highlighting is done.
			 * Mostly useful when `async` is `true`, since in that case, the highlighting is done asynchronously.
			 * @memberof Prism
			 * @public
			 */
			highlightElement: function (element, async, callback) {
				// Find language
				var language = _.util.getLanguage(element);
				var grammar = _.languages[language];

				// Set language on the element, if not present
				_.util.setLanguage(element, language);

				// Set language on the parent, for styling
				var parent = element.parentElement;
				if (parent && parent.nodeName.toLowerCase() === 'pre') {
					_.util.setLanguage(parent, language);
				}

				var code = element.textContent;

				var env = {
					element: element,
					language: language,
					grammar: grammar,
					code: code
				};

				function insertHighlightedCode(highlightedCode) {
					env.highlightedCode = highlightedCode;

					_.hooks.run('before-insert', env);

					env.element.innerHTML = env.highlightedCode;

					_.hooks.run('after-highlight', env);
					_.hooks.run('complete', env);
					callback && callback.call(env.element);
				}

				_.hooks.run('before-sanity-check', env);

				// plugins may change/add the parent/element
				parent = env.element.parentElement;
				if (parent && parent.nodeName.toLowerCase() === 'pre' && !parent.hasAttribute('tabindex')) {
					parent.setAttribute('tabindex', '0');
				}

				if (!env.code) {
					_.hooks.run('complete', env);
					callback && callback.call(env.element);
					return;
				}

				_.hooks.run('before-highlight', env);

				if (!env.grammar) {
					insertHighlightedCode(_.util.encode(env.code));
					return;
				}

				if (async && _self.Worker) {
					var worker = new Worker(_.filename);

					worker.onmessage = function (evt) {
						insertHighlightedCode(evt.data);
					};

					worker.postMessage(JSON.stringify({
						language: env.language,
						code: env.code,
						immediateClose: true
					}));
				} else {
					insertHighlightedCode(_.highlight(env.code, env.grammar, env.language));
				}
			},

			/**
			 * Low-level function, only use if you know what you’re doing. It accepts a string of text as input
			 * and the language definitions to use, and returns a string with the HTML produced.
			 *
			 * The following hooks will be run:
			 * 1. `before-tokenize`
			 * 2. `after-tokenize`
			 * 3. `wrap`: On each {@link Token}.
			 *
			 * @param {string} text A string with the code to be highlighted.
			 * @param {Grammar} grammar An object containing the tokens to use.
			 *
			 * Usually a language definition like `Prism.languages.markup`.
			 * @param {string} language The name of the language definition passed to `grammar`.
			 * @returns {string} The highlighted HTML.
			 * @memberof Prism
			 * @public
			 * @example
			 * Prism.highlight('var foo = true;', Prism.languages.javascript, 'javascript');
			 */
			highlight: function (text, grammar, language) {
				var env = {
					code: text,
					grammar: grammar,
					language: language
				};
				_.hooks.run('before-tokenize', env);
				if (!env.grammar) {
					throw new Error('The language "' + env.language + '" has no grammar.');
				}
				env.tokens = _.tokenize(env.code, env.grammar);
				_.hooks.run('after-tokenize', env);
				return Token.stringify(_.util.encode(env.tokens), env.language);
			},

			/**
			 * This is the heart of Prism, and the most low-level function you can use. It accepts a string of text as input
			 * and the language definitions to use, and returns an array with the tokenized code.
			 *
			 * When the language definition includes nested tokens, the function is called recursively on each of these tokens.
			 *
			 * This method could be useful in other contexts as well, as a very crude parser.
			 *
			 * @param {string} text A string with the code to be highlighted.
			 * @param {Grammar} grammar An object containing the tokens to use.
			 *
			 * Usually a language definition like `Prism.languages.markup`.
			 * @returns {TokenStream} An array of strings and tokens, a token stream.
			 * @memberof Prism
			 * @public
			 * @example
			 * let code = `var foo = 0;`;
			 * let tokens = Prism.tokenize(code, Prism.languages.javascript);
			 * tokens.forEach(token => {
			 *     if (token instanceof Prism.Token && token.type === 'number') {
			 *         console.log(`Found numeric literal: ${token.content}`);
			 *     }
			 * });
			 */
			tokenize: function (text, grammar) {
				var rest = grammar.rest;
				if (rest) {
					for (var token in rest) {
						grammar[token] = rest[token];
					}

					delete grammar.rest;
				}

				var tokenList = new LinkedList();
				addAfter(tokenList, tokenList.head, text);

				matchGrammar(text, tokenList, grammar, tokenList.head, 0);

				return toArray(tokenList);
			},

			/**
			 * @namespace
			 * @memberof Prism
			 * @public
			 */
			hooks: {
				all: {},

				/**
				 * Adds the given callback to the list of callbacks for the given hook.
				 *
				 * The callback will be invoked when the hook it is registered for is run.
				 * Hooks are usually directly run by a highlight function but you can also run hooks yourself.
				 *
				 * One callback function can be registered to multiple hooks and the same hook multiple times.
				 *
				 * @param {string} name The name of the hook.
				 * @param {HookCallback} callback The callback function which is given environment variables.
				 * @public
				 */
				add: function (name, callback) {
					var hooks = _.hooks.all;

					hooks[name] = hooks[name] || [];

					hooks[name].push(callback);
				},

				/**
				 * Runs a hook invoking all registered callbacks with the given environment variables.
				 *
				 * Callbacks will be invoked synchronously and in the order in which they were registered.
				 *
				 * @param {string} name The name of the hook.
				 * @param {Object<string, any>} env The environment variables of the hook passed to all callbacks registered.
				 * @public
				 */
				run: function (name, env) {
					var callbacks = _.hooks.all[name];

					if (!callbacks || !callbacks.length) {
						return;
					}

					for (var i = 0, callback; (callback = callbacks[i++]);) {
						callback(env);
					}
				}
			},

			Token: Token
		};
		_self.Prism = _;


		// Typescript note:
		// The following can be used to import the Token type in JSDoc:
		//
		//   @typedef {InstanceType<import("./prism-core")["Token"]>} Token

		/**
		 * Creates a new token.
		 *
		 * @param {string} type See {@link Token#type type}
		 * @param {string | TokenStream} content See {@link Token#content content}
		 * @param {string|string[]} [alias] The alias(es) of the token.
		 * @param {string} [matchedStr=""] A copy of the full string this token was created from.
		 * @class
		 * @global
		 * @public
		 */
		function Token(type, content, alias, matchedStr) {
			/**
			 * The type of the token.
			 *
			 * This is usually the key of a pattern in a {@link Grammar}.
			 *
			 * @type {string}
			 * @see GrammarToken
			 * @public
			 */
			this.type = type;
			/**
			 * The strings or tokens contained by this token.
			 *
			 * This will be a token stream if the pattern matched also defined an `inside` grammar.
			 *
			 * @type {string | TokenStream}
			 * @public
			 */
			this.content = content;
			/**
			 * The alias(es) of the token.
			 *
			 * @type {string|string[]}
			 * @see GrammarToken
			 * @public
			 */
			this.alias = alias;
			// Copy of the full string this token was created from
			this.length = (matchedStr || '').length | 0;
		}

		/**
		 * A token stream is an array of strings and {@link Token Token} objects.
		 *
		 * Token streams have to fulfill a few properties that are assumed by most functions (mostly internal ones) that process
		 * them.
		 *
		 * 1. No adjacent strings.
		 * 2. No empty strings.
		 *
		 *    The only exception here is the token stream that only contains the empty string and nothing else.
		 *
		 * @typedef {Array<string | Token>} TokenStream
		 * @global
		 * @public
		 */

		/**
		 * Converts the given token or token stream to an HTML representation.
		 *
		 * The following hooks will be run:
		 * 1. `wrap`: On each {@link Token}.
		 *
		 * @param {string | Token | TokenStream} o The token or token stream to be converted.
		 * @param {string} language The name of current language.
		 * @returns {string} The HTML representation of the token or token stream.
		 * @memberof Token
		 * @static
		 */
		Token.stringify = function stringify(o, language) {
			if (typeof o == 'string') {
				return o;
			}
			if (Array.isArray(o)) {
				var s = '';
				o.forEach(function (e) {
					s += stringify(e, language);
				});
				return s;
			}

			var env = {
				type: o.type,
				content: stringify(o.content, language),
				tag: 'span',
				classes: ['token', o.type],
				attributes: {},
				language: language
			};

			var aliases = o.alias;
			if (aliases) {
				if (Array.isArray(aliases)) {
					Array.prototype.push.apply(env.classes, aliases);
				} else {
					env.classes.push(aliases);
				}
			}

			_.hooks.run('wrap', env);

			var attributes = '';
			for (var name in env.attributes) {
				attributes += ' ' + name + '="' + (env.attributes[name] || '').replace(/"/g, '&quot;') + '"';
			}

			return '<' + env.tag + ' class="' + env.classes.join(' ') + '"' + attributes + '>' + env.content + '</' + env.tag + '>';
		};

		/**
		 * @param {RegExp} pattern
		 * @param {number} pos
		 * @param {string} text
		 * @param {boolean} lookbehind
		 * @returns {RegExpExecArray | null}
		 */
		function matchPattern(pattern, pos, text, lookbehind) {
			pattern.lastIndex = pos;
			var match = pattern.exec(text);
			if (match && lookbehind && match[1]) {
				// change the match to remove the text matched by the Prism lookbehind group
				var lookbehindLength = match[1].length;
				match.index += lookbehindLength;
				match[0] = match[0].slice(lookbehindLength);
			}
			return match;
		}

		/**
		 * @param {string} text
		 * @param {LinkedList<string | Token>} tokenList
		 * @param {any} grammar
		 * @param {LinkedListNode<string | Token>} startNode
		 * @param {number} startPos
		 * @param {RematchOptions} [rematch]
		 * @returns {void}
		 * @private
		 *
		 * @typedef RematchOptions
		 * @property {string} cause
		 * @property {number} reach
		 */
		function matchGrammar(text, tokenList, grammar, startNode, startPos, rematch) {
			for (var token in grammar) {
				if (!grammar.hasOwnProperty(token) || !grammar[token]) {
					continue;
				}

				var patterns = grammar[token];
				patterns = Array.isArray(patterns) ? patterns : [patterns];

				for (var j = 0; j < patterns.length; ++j) {
					if (rematch && rematch.cause == token + ',' + j) {
						return;
					}

					var patternObj = patterns[j];
					var inside = patternObj.inside;
					var lookbehind = !!patternObj.lookbehind;
					var greedy = !!patternObj.greedy;
					var alias = patternObj.alias;

					if (greedy && !patternObj.pattern.global) {
						// Without the global flag, lastIndex won't work
						var flags = patternObj.pattern.toString().match(/[imsuy]*$/)[0];
						patternObj.pattern = RegExp(patternObj.pattern.source, flags + 'g');
					}

					/** @type {RegExp} */
					var pattern = patternObj.pattern || patternObj;

					for ( // iterate the token list and keep track of the current token/string position
						var currentNode = startNode.next, pos = startPos;
						currentNode !== tokenList.tail;
						pos += currentNode.value.length, currentNode = currentNode.next
					) {

						if (rematch && pos >= rematch.reach) {
							break;
						}

						var str = currentNode.value;

						if (tokenList.length > text.length) {
							// Something went terribly wrong, ABORT, ABORT!
							return;
						}

						if (str instanceof Token) {
							continue;
						}

						var removeCount = 1; // this is the to parameter of removeBetween
						var match;

						if (greedy) {
							match = matchPattern(pattern, pos, text, lookbehind);
							if (!match || match.index >= text.length) {
								break;
							}

							var from = match.index;
							var to = match.index + match[0].length;
							var p = pos;

							// find the node that contains the match
							p += currentNode.value.length;
							while (from >= p) {
								currentNode = currentNode.next;
								p += currentNode.value.length;
							}
							// adjust pos (and p)
							p -= currentNode.value.length;
							pos = p;

							// the current node is a Token, then the match starts inside another Token, which is invalid
							if (currentNode.value instanceof Token) {
								continue;
							}

							// find the last node which is affected by this match
							for (
								var k = currentNode;
								k !== tokenList.tail && (p < to || typeof k.value === 'string');
								k = k.next
							) {
								removeCount++;
								p += k.value.length;
							}
							removeCount--;

							// replace with the new match
							str = text.slice(pos, p);
							match.index -= pos;
						} else {
							match = matchPattern(pattern, 0, str, lookbehind);
							if (!match) {
								continue;
							}
						}

						// eslint-disable-next-line no-redeclare
						var from = match.index;
						var matchStr = match[0];
						var before = str.slice(0, from);
						var after = str.slice(from + matchStr.length);

						var reach = pos + str.length;
						if (rematch && reach > rematch.reach) {
							rematch.reach = reach;
						}

						var removeFrom = currentNode.prev;

						if (before) {
							removeFrom = addAfter(tokenList, removeFrom, before);
							pos += before.length;
						}

						removeRange(tokenList, removeFrom, removeCount);

						var wrapped = new Token(token, inside ? _.tokenize(matchStr, inside) : matchStr, alias, matchStr);
						currentNode = addAfter(tokenList, removeFrom, wrapped);

						if (after) {
							addAfter(tokenList, currentNode, after);
						}

						if (removeCount > 1) {
							// at least one Token object was removed, so we have to do some rematching
							// this can only happen if the current pattern is greedy

							/** @type {RematchOptions} */
							var nestedRematch = {
								cause: token + ',' + j,
								reach: reach
							};
							matchGrammar(text, tokenList, grammar, currentNode.prev, pos, nestedRematch);

							// the reach might have been extended because of the rematching
							if (rematch && nestedRematch.reach > rematch.reach) {
								rematch.reach = nestedRematch.reach;
							}
						}
					}
				}
			}
		}

		/**
		 * @typedef LinkedListNode
		 * @property {T} value
		 * @property {LinkedListNode<T> | null} prev The previous node.
		 * @property {LinkedListNode<T> | null} next The next node.
		 * @template T
		 * @private
		 */

		/**
		 * @template T
		 * @private
		 */
		function LinkedList() {
			/** @type {LinkedListNode<T>} */
			var head = { value: null, prev: null, next: null };
			/** @type {LinkedListNode<T>} */
			var tail = { value: null, prev: head, next: null };
			head.next = tail;

			/** @type {LinkedListNode<T>} */
			this.head = head;
			/** @type {LinkedListNode<T>} */
			this.tail = tail;
			this.length = 0;
		}

		/**
		 * Adds a new node with the given value to the list.
		 *
		 * @param {LinkedList<T>} list
		 * @param {LinkedListNode<T>} node
		 * @param {T} value
		 * @returns {LinkedListNode<T>} The added node.
		 * @template T
		 */
		function addAfter(list, node, value) {
			// assumes that node != list.tail && values.length >= 0
			var next = node.next;

			var newNode = { value: value, prev: node, next: next };
			node.next = newNode;
			next.prev = newNode;
			list.length++;

			return newNode;
		}
		/**
		 * Removes `count` nodes after the given node. The given node will not be removed.
		 *
		 * @param {LinkedList<T>} list
		 * @param {LinkedListNode<T>} node
		 * @param {number} count
		 * @template T
		 */
		function removeRange(list, node, count) {
			var next = node.next;
			for (var i = 0; i < count && next !== list.tail; i++) {
				next = next.next;
			}
			node.next = next;
			next.prev = node;
			list.length -= i;
		}
		/**
		 * @param {LinkedList<T>} list
		 * @returns {T[]}
		 * @template T
		 */
		function toArray(list) {
			var array = [];
			var node = list.head.next;
			while (node !== list.tail) {
				array.push(node.value);
				node = node.next;
			}
			return array;
		}


		if (!_self.document) {
			if (!_self.addEventListener) {
				// in Node.js
				return _;
			}

			if (!_.disableWorkerMessageHandler) {
				// In worker
				_self.addEventListener('message', function (evt) {
					var message = JSON.parse(evt.data);
					var lang = message.language;
					var code = message.code;
					var immediateClose = message.immediateClose;

					_self.postMessage(_.highlight(code, _.languages[lang], lang));
					if (immediateClose) {
						_self.close();
					}
				}, false);
			}

			return _;
		}

		// Get current script and highlight
		var script = _.util.currentScript();

		if (script) {
			_.filename = script.src;

			if (script.hasAttribute('data-manual')) {
				_.manual = true;
			}
		}

		function highlightAutomaticallyCallback() {
			if (!_.manual) {
				_.highlightAll();
			}
		}

		if (!_.manual) {
			// If the document state is "loading", then we'll use DOMContentLoaded.
			// If the document state is "interactive" and the prism.js script is deferred, then we'll also use the
			// DOMContentLoaded event because there might be some plugins or languages which have also been deferred and they
			// might take longer one animation frame to execute which can create a race condition where only some plugins have
			// been loaded when Prism.highlightAll() is executed, depending on how fast resources are loaded.
			// See https://github.com/PrismJS/prism/issues/2102
			var readyState = document.readyState;
			if (readyState === 'loading' || readyState === 'interactive' && script && script.defer) {
				document.addEventListener('DOMContentLoaded', highlightAutomaticallyCallback);
			} else {
				if (window.requestAnimationFrame) {
					window.requestAnimationFrame(highlightAutomaticallyCallback);
				} else {
					window.setTimeout(highlightAutomaticallyCallback, 16);
				}
			}
		}

		return _;

	}(_self));

	if (module.exports) {
		module.exports = Prism;
	}

	// hack for components to work correctly in node.js
	if (typeof commonjsGlobal !== 'undefined') {
		commonjsGlobal.Prism = Prism;
	}

	// some additional documentation/types

	/**
	 * The expansion of a simple `RegExp` literal to support additional properties.
	 *
	 * @typedef GrammarToken
	 * @property {RegExp} pattern The regular expression of the token.
	 * @property {boolean} [lookbehind=false] If `true`, then the first capturing group of `pattern` will (effectively)
	 * behave as a lookbehind group meaning that the captured text will not be part of the matched text of the new token.
	 * @property {boolean} [greedy=false] Whether the token is greedy.
	 * @property {string|string[]} [alias] An optional alias or list of aliases.
	 * @property {Grammar} [inside] The nested grammar of this token.
	 *
	 * The `inside` grammar will be used to tokenize the text value of each token of this kind.
	 *
	 * This can be used to make nested and even recursive language definitions.
	 *
	 * Note: This can cause infinite recursion. Be careful when you embed different languages or even the same language into
	 * each another.
	 * @global
	 * @public
	 */

	/**
	 * @typedef Grammar
	 * @type {Object<string, RegExp | GrammarToken | Array<RegExp | GrammarToken>>}
	 * @property {Grammar} [rest] An optional grammar object that will be appended to this grammar.
	 * @global
	 * @public
	 */

	/**
	 * A function which will invoked after an element was successfully highlighted.
	 *
	 * @callback HighlightCallback
	 * @param {Element} element The element successfully highlighted.
	 * @returns {void}
	 * @global
	 * @public
	 */

	/**
	 * @callback HookCallback
	 * @param {Object<string, any>} env The environment variables of the hook.
	 * @returns {void}
	 * @global
	 * @public
	 */


	/* **********************************************
	     Begin prism-markup.js
	********************************************** */

	Prism.languages.markup = {
		'comment': {
			pattern: /<!--(?:(?!<!--)[\s\S])*?-->/,
			greedy: true
		},
		'prolog': {
			pattern: /<\?[\s\S]+?\?>/,
			greedy: true
		},
		'doctype': {
			// https://www.w3.org/TR/xml/#NT-doctypedecl
			pattern: /<!DOCTYPE(?:[^>"'[\]]|"[^"]*"|'[^']*')+(?:\[(?:[^<"'\]]|"[^"]*"|'[^']*'|<(?!!--)|<!--(?:[^-]|-(?!->))*-->)*\]\s*)?>/i,
			greedy: true,
			inside: {
				'internal-subset': {
					pattern: /(^[^\[]*\[)[\s\S]+(?=\]>$)/,
					lookbehind: true,
					greedy: true,
					inside: null // see below
				},
				'string': {
					pattern: /"[^"]*"|'[^']*'/,
					greedy: true
				},
				'punctuation': /^<!|>$|[[\]]/,
				'doctype-tag': /^DOCTYPE/i,
				'name': /[^\s<>'"]+/
			}
		},
		'cdata': {
			pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i,
			greedy: true
		},
		'tag': {
			pattern: /<\/?(?!\d)[^\s>\/=$<%]+(?:\s(?:\s*[^\s>\/=]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))|(?=[\s/>])))+)?\s*\/?>/,
			greedy: true,
			inside: {
				'tag': {
					pattern: /^<\/?[^\s>\/]+/,
					inside: {
						'punctuation': /^<\/?/,
						'namespace': /^[^\s>\/:]+:/
					}
				},
				'special-attr': [],
				'attr-value': {
					pattern: /=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+)/,
					inside: {
						'punctuation': [
							{
								pattern: /^=/,
								alias: 'attr-equals'
							},
							{
								pattern: /^(\s*)["']|["']$/,
								lookbehind: true
							}
						]
					}
				},
				'punctuation': /\/?>/,
				'attr-name': {
					pattern: /[^\s>\/]+/,
					inside: {
						'namespace': /^[^\s>\/:]+:/
					}
				}

			}
		},
		'entity': [
			{
				pattern: /&[\da-z]{1,8};/i,
				alias: 'named-entity'
			},
			/&#x?[\da-f]{1,8};/i
		]
	};

	Prism.languages.markup['tag'].inside['attr-value'].inside['entity'] =
		Prism.languages.markup['entity'];
	Prism.languages.markup['doctype'].inside['internal-subset'].inside = Prism.languages.markup;

	// Plugin to make entity title show the real entity, idea by Roman Komarov
	Prism.hooks.add('wrap', function (env) {

		if (env.type === 'entity') {
			env.attributes['title'] = env.content.replace(/&amp;/, '&');
		}
	});

	Object.defineProperty(Prism.languages.markup.tag, 'addInlined', {
		/**
		 * Adds an inlined language to markup.
		 *
		 * An example of an inlined language is CSS with `<style>` tags.
		 *
		 * @param {string} tagName The name of the tag that contains the inlined language. This name will be treated as
		 * case insensitive.
		 * @param {string} lang The language key.
		 * @example
		 * addInlined('style', 'css');
		 */
		value: function addInlined(tagName, lang) {
			var includedCdataInside = {};
			includedCdataInside['language-' + lang] = {
				pattern: /(^<!\[CDATA\[)[\s\S]+?(?=\]\]>$)/i,
				lookbehind: true,
				inside: Prism.languages[lang]
			};
			includedCdataInside['cdata'] = /^<!\[CDATA\[|\]\]>$/i;

			var inside = {
				'included-cdata': {
					pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i,
					inside: includedCdataInside
				}
			};
			inside['language-' + lang] = {
				pattern: /[\s\S]+/,
				inside: Prism.languages[lang]
			};

			var def = {};
			def[tagName] = {
				pattern: RegExp(/(<__[^>]*>)(?:<!\[CDATA\[(?:[^\]]|\](?!\]>))*\]\]>|(?!<!\[CDATA\[)[\s\S])*?(?=<\/__>)/.source.replace(/__/g, function () { return tagName; }), 'i'),
				lookbehind: true,
				greedy: true,
				inside: inside
			};

			Prism.languages.insertBefore('markup', 'cdata', def);
		}
	});
	Object.defineProperty(Prism.languages.markup.tag, 'addAttribute', {
		/**
		 * Adds an pattern to highlight languages embedded in HTML attributes.
		 *
		 * An example of an inlined language is CSS with `style` attributes.
		 *
		 * @param {string} attrName The name of the tag that contains the inlined language. This name will be treated as
		 * case insensitive.
		 * @param {string} lang The language key.
		 * @example
		 * addAttribute('style', 'css');
		 */
		value: function (attrName, lang) {
			Prism.languages.markup.tag.inside['special-attr'].push({
				pattern: RegExp(
					/(^|["'\s])/.source + '(?:' + attrName + ')' + /\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))/.source,
					'i'
				),
				lookbehind: true,
				inside: {
					'attr-name': /^[^\s=]+/,
					'attr-value': {
						pattern: /=[\s\S]+/,
						inside: {
							'value': {
								pattern: /(^=\s*(["']|(?!["'])))\S[\s\S]*(?=\2$)/,
								lookbehind: true,
								alias: [lang, 'language-' + lang],
								inside: Prism.languages[lang]
							},
							'punctuation': [
								{
									pattern: /^=/,
									alias: 'attr-equals'
								},
								/"|'/
							]
						}
					}
				}
			});
		}
	});

	Prism.languages.html = Prism.languages.markup;
	Prism.languages.mathml = Prism.languages.markup;
	Prism.languages.svg = Prism.languages.markup;

	Prism.languages.xml = Prism.languages.extend('markup', {});
	Prism.languages.ssml = Prism.languages.xml;
	Prism.languages.atom = Prism.languages.xml;
	Prism.languages.rss = Prism.languages.xml;


	/* **********************************************
	     Begin prism-css.js
	********************************************** */

	(function (Prism) {

		var string = /(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/;

		Prism.languages.css = {
			'comment': /\/\*[\s\S]*?\*\//,
			'atrule': {
				pattern: RegExp('@[\\w-](?:' + /[^;{\s"']|\s+(?!\s)/.source + '|' + string.source + ')*?' + /(?:;|(?=\s*\{))/.source),
				inside: {
					'rule': /^@[\w-]+/,
					'selector-function-argument': {
						pattern: /(\bselector\s*\(\s*(?![\s)]))(?:[^()\s]|\s+(?![\s)])|\((?:[^()]|\([^()]*\))*\))+(?=\s*\))/,
						lookbehind: true,
						alias: 'selector'
					},
					'keyword': {
						pattern: /(^|[^\w-])(?:and|not|only|or)(?![\w-])/,
						lookbehind: true
					}
					// See rest below
				}
			},
			'url': {
				// https://drafts.csswg.org/css-values-3/#urls
				pattern: RegExp('\\burl\\((?:' + string.source + '|' + /(?:[^\\\r\n()"']|\\[\s\S])*/.source + ')\\)', 'i'),
				greedy: true,
				inside: {
					'function': /^url/i,
					'punctuation': /^\(|\)$/,
					'string': {
						pattern: RegExp('^' + string.source + '$'),
						alias: 'url'
					}
				}
			},
			'selector': {
				pattern: RegExp('(^|[{}\\s])[^{}\\s](?:[^{};"\'\\s]|\\s+(?![\\s{])|' + string.source + ')*(?=\\s*\\{)'),
				lookbehind: true
			},
			'string': {
				pattern: string,
				greedy: true
			},
			'property': {
				pattern: /(^|[^-\w\xA0-\uFFFF])(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*(?=\s*:)/i,
				lookbehind: true
			},
			'important': /!important\b/i,
			'function': {
				pattern: /(^|[^-a-z0-9])[-a-z0-9]+(?=\()/i,
				lookbehind: true
			},
			'punctuation': /[(){};:,]/
		};

		Prism.languages.css['atrule'].inside.rest = Prism.languages.css;

		var markup = Prism.languages.markup;
		if (markup) {
			markup.tag.addInlined('style', 'css');
			markup.tag.addAttribute('style', 'css');
		}

	}(Prism));


	/* **********************************************
	     Begin prism-clike.js
	********************************************** */

	Prism.languages.clike = {
		'comment': [
			{
				pattern: /(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,
				lookbehind: true,
				greedy: true
			},
			{
				pattern: /(^|[^\\:])\/\/.*/,
				lookbehind: true,
				greedy: true
			}
		],
		'string': {
			pattern: /(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,
			greedy: true
		},
		'class-name': {
			pattern: /(\b(?:class|extends|implements|instanceof|interface|new|trait)\s+|\bcatch\s+\()[\w.\\]+/i,
			lookbehind: true,
			inside: {
				'punctuation': /[.\\]/
			}
		},
		'keyword': /\b(?:break|catch|continue|do|else|finally|for|function|if|in|instanceof|new|null|return|throw|try|while)\b/,
		'boolean': /\b(?:false|true)\b/,
		'function': /\b\w+(?=\()/,
		'number': /\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,
		'operator': /[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/,
		'punctuation': /[{}[\];(),.:]/
	};


	/* **********************************************
	     Begin prism-javascript.js
	********************************************** */

	Prism.languages.javascript = Prism.languages.extend('clike', {
		'class-name': [
			Prism.languages.clike['class-name'],
			{
				pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$A-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\.(?:constructor|prototype))/,
				lookbehind: true
			}
		],
		'keyword': [
			{
				pattern: /((?:^|\})\s*)catch\b/,
				lookbehind: true
			},
			{
				pattern: /(^|[^.]|\.\.\.\s*)\b(?:as|assert(?=\s*\{)|async(?=\s*(?:function\b|\(|[$\w\xA0-\uFFFF]|$))|await|break|case|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally(?=\s*(?:\{|$))|for|from(?=\s*(?:['"]|$))|function|(?:get|set)(?=\s*(?:[#\[$\w\xA0-\uFFFF]|$))|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)\b/,
				lookbehind: true
			},
		],
		// Allow for all non-ASCII characters (See http://stackoverflow.com/a/2008444)
		'function': /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*(?:\.\s*(?:apply|bind|call)\s*)?\()/,
		'number': {
			pattern: RegExp(
				/(^|[^\w$])/.source +
				'(?:' +
				(
					// constant
					/NaN|Infinity/.source +
					'|' +
					// binary integer
					/0[bB][01]+(?:_[01]+)*n?/.source +
					'|' +
					// octal integer
					/0[oO][0-7]+(?:_[0-7]+)*n?/.source +
					'|' +
					// hexadecimal integer
					/0[xX][\dA-Fa-f]+(?:_[\dA-Fa-f]+)*n?/.source +
					'|' +
					// decimal bigint
					/\d+(?:_\d+)*n/.source +
					'|' +
					// decimal number (integer or float) but no bigint
					/(?:\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[Ee][+-]?\d+(?:_\d+)*)?/.source
				) +
				')' +
				/(?![\w$])/.source
			),
			lookbehind: true
		},
		'operator': /--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/
	});

	Prism.languages.javascript['class-name'][0].pattern = /(\b(?:class|extends|implements|instanceof|interface|new)\s+)[\w.\\]+/;

	Prism.languages.insertBefore('javascript', 'keyword', {
		'regex': {
			pattern: RegExp(
				// lookbehind
				// eslint-disable-next-line regexp/no-dupe-characters-character-class
				/((?:^|[^$\w\xA0-\uFFFF."'\])\s]|\b(?:return|yield))\s*)/.source +
				// Regex pattern:
				// There are 2 regex patterns here. The RegExp set notation proposal added support for nested character
				// classes if the `v` flag is present. Unfortunately, nested CCs are both context-free and incompatible
				// with the only syntax, so we have to define 2 different regex patterns.
				/\//.source +
				'(?:' +
				/(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}/.source +
				'|' +
				// `v` flag syntax. This supports 3 levels of nested character classes.
				/(?:\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.)*\])*\])*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}v[dgimyus]{0,7}/.source +
				')' +
				// lookahead
				/(?=(?:\s|\/\*(?:[^*]|\*(?!\/))*\*\/)*(?:$|[\r\n,.;:})\]]|\/\/))/.source
			),
			lookbehind: true,
			greedy: true,
			inside: {
				'regex-source': {
					pattern: /^(\/)[\s\S]+(?=\/[a-z]*$)/,
					lookbehind: true,
					alias: 'language-regex',
					inside: Prism.languages.regex
				},
				'regex-delimiter': /^\/|\/$/,
				'regex-flags': /^[a-z]+$/,
			}
		},
		// This must be declared before keyword because we use "function" inside the look-forward
		'function-variable': {
			pattern: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:async\s*)?(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/,
			alias: 'function'
		},
		'parameter': [
			{
				pattern: /(function(?:\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)?\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\))/,
				lookbehind: true,
				inside: Prism.languages.javascript
			},
			{
				pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=>)/i,
				lookbehind: true,
				inside: Prism.languages.javascript
			},
			{
				pattern: /(\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*=>)/,
				lookbehind: true,
				inside: Prism.languages.javascript
			},
			{
				pattern: /((?:\b|\s|^)(?!(?:as|async|await|break|case|catch|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)(?![$\w\xA0-\uFFFF]))(?:(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*)\(\s*|\]\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*\{)/,
				lookbehind: true,
				inside: Prism.languages.javascript
			}
		],
		'constant': /\b[A-Z](?:[A-Z_]|\dx?)*\b/
	});

	Prism.languages.insertBefore('javascript', 'string', {
		'hashbang': {
			pattern: /^#!.*/,
			greedy: true,
			alias: 'comment'
		},
		'template-string': {
			pattern: /`(?:\\[\s\S]|\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}|(?!\$\{)[^\\`])*`/,
			greedy: true,
			inside: {
				'template-punctuation': {
					pattern: /^`|`$/,
					alias: 'string'
				},
				'interpolation': {
					pattern: /((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,
					lookbehind: true,
					inside: {
						'interpolation-punctuation': {
							pattern: /^\$\{|\}$/,
							alias: 'punctuation'
						},
						rest: Prism.languages.javascript
					}
				},
				'string': /[\s\S]+/
			}
		},
		'string-property': {
			pattern: /((?:^|[,{])[ \t]*)(["'])(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2(?=\s*:)/m,
			lookbehind: true,
			greedy: true,
			alias: 'property'
		}
	});

	Prism.languages.insertBefore('javascript', 'operator', {
		'literal-property': {
			pattern: /((?:^|[,{])[ \t]*)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/m,
			lookbehind: true,
			alias: 'property'
		},
	});

	if (Prism.languages.markup) {
		Prism.languages.markup.tag.addInlined('script', 'javascript');

		// add attribute support for all DOM events.
		// https://developer.mozilla.org/en-US/docs/Web/Events#Standard_events
		Prism.languages.markup.tag.addAttribute(
			/on(?:abort|blur|change|click|composition(?:end|start|update)|dblclick|error|focus(?:in|out)?|key(?:down|up)|load|mouse(?:down|enter|leave|move|out|over|up)|reset|resize|scroll|select|slotchange|submit|unload|wheel)/.source,
			'javascript'
		);
	}

	Prism.languages.js = Prism.languages.javascript;


	/* **********************************************
	     Begin prism-file-highlight.js
	********************************************** */

	(function () {

		if (typeof Prism === 'undefined' || typeof document === 'undefined') {
			return;
		}

		// https://developer.mozilla.org/en-US/docs/Web/API/Element/matches#Polyfill
		if (!Element.prototype.matches) {
			Element.prototype.matches = Element.prototype.msMatchesSelector || Element.prototype.webkitMatchesSelector;
		}

		var LOADING_MESSAGE = 'Loading…';
		var FAILURE_MESSAGE = function (status, message) {
			return '✖ Error ' + status + ' while fetching file: ' + message;
		};
		var FAILURE_EMPTY_MESSAGE = '✖ Error: File does not exist or is empty';

		var EXTENSIONS = {
			'js': 'javascript',
			'py': 'python',
			'rb': 'ruby',
			'ps1': 'powershell',
			'psm1': 'powershell',
			'sh': 'bash',
			'bat': 'batch',
			'h': 'c',
			'tex': 'latex'
		};

		var STATUS_ATTR = 'data-src-status';
		var STATUS_LOADING = 'loading';
		var STATUS_LOADED = 'loaded';
		var STATUS_FAILED = 'failed';

		var SELECTOR = 'pre[data-src]:not([' + STATUS_ATTR + '="' + STATUS_LOADED + '"])'
			+ ':not([' + STATUS_ATTR + '="' + STATUS_LOADING + '"])';

		/**
		 * Loads the given file.
		 *
		 * @param {string} src The URL or path of the source file to load.
		 * @param {(result: string) => void} success
		 * @param {(reason: string) => void} error
		 */
		function loadFile(src, success, error) {
			var xhr = new XMLHttpRequest();
			xhr.open('GET', src, true);
			xhr.onreadystatechange = function () {
				if (xhr.readyState == 4) {
					if (xhr.status < 400 && xhr.responseText) {
						success(xhr.responseText);
					} else {
						if (xhr.status >= 400) {
							error(FAILURE_MESSAGE(xhr.status, xhr.statusText));
						} else {
							error(FAILURE_EMPTY_MESSAGE);
						}
					}
				}
			};
			xhr.send(null);
		}

		/**
		 * Parses the given range.
		 *
		 * This returns a range with inclusive ends.
		 *
		 * @param {string | null | undefined} range
		 * @returns {[number, number | undefined] | undefined}
		 */
		function parseRange(range) {
			var m = /^\s*(\d+)\s*(?:(,)\s*(?:(\d+)\s*)?)?$/.exec(range || '');
			if (m) {
				var start = Number(m[1]);
				var comma = m[2];
				var end = m[3];

				if (!comma) {
					return [start, start];
				}
				if (!end) {
					return [start, undefined];
				}
				return [start, Number(end)];
			}
			return undefined;
		}

		Prism.hooks.add('before-highlightall', function (env) {
			env.selector += ', ' + SELECTOR;
		});

		Prism.hooks.add('before-sanity-check', function (env) {
			var pre = /** @type {HTMLPreElement} */ (env.element);
			if (pre.matches(SELECTOR)) {
				env.code = ''; // fast-path the whole thing and go to complete

				pre.setAttribute(STATUS_ATTR, STATUS_LOADING); // mark as loading

				// add code element with loading message
				var code = pre.appendChild(document.createElement('CODE'));
				code.textContent = LOADING_MESSAGE;

				var src = pre.getAttribute('data-src');

				var language = env.language;
				if (language === 'none') {
					// the language might be 'none' because there is no language set;
					// in this case, we want to use the extension as the language
					var extension = (/\.(\w+)$/.exec(src) || [, 'none'])[1];
					language = EXTENSIONS[extension] || extension;
				}

				// set language classes
				Prism.util.setLanguage(code, language);
				Prism.util.setLanguage(pre, language);

				// preload the language
				var autoloader = Prism.plugins.autoloader;
				if (autoloader) {
					autoloader.loadLanguages(language);
				}

				// load file
				loadFile(
					src,
					function (text) {
						// mark as loaded
						pre.setAttribute(STATUS_ATTR, STATUS_LOADED);

						// handle data-range
						var range = parseRange(pre.getAttribute('data-range'));
						if (range) {
							var lines = text.split(/\r\n?|\n/g);

							// the range is one-based and inclusive on both ends
							var start = range[0];
							var end = range[1] == null ? lines.length : range[1];

							if (start < 0) { start += lines.length; }
							start = Math.max(0, Math.min(start - 1, lines.length));
							if (end < 0) { end += lines.length; }
							end = Math.max(0, Math.min(end, lines.length));

							text = lines.slice(start, end).join('\n');

							// add data-start for line numbers
							if (!pre.hasAttribute('data-start')) {
								pre.setAttribute('data-start', String(start + 1));
							}
						}

						// highlight code
						code.textContent = text;
						Prism.highlightElement(code);
					},
					function (error) {
						// mark as failed
						pre.setAttribute(STATUS_ATTR, STATUS_FAILED);

						code.textContent = error;
					}
				);
			}
		});

		Prism.plugins.fileHighlight = {
			/**
			 * Executes the File Highlight plugin for all matching `pre` elements under the given container.
			 *
			 * Note: Elements which are already loaded or currently loading will not be touched by this method.
			 *
			 * @param {ParentNode} [container=document]
			 */
			highlight: function highlight(container) {
				var elements = (container || document).querySelectorAll(SELECTOR);

				for (var i = 0, element; (element = elements[i++]);) {
					Prism.highlightElement(element);
				}
			}
		};

		var logged = false;
		/** @deprecated Use `Prism.plugins.fileHighlight.highlight` instead. */
		Prism.fileHighlight = function () {
			if (!logged) {
				console.warn('Prism.fileHighlight is deprecated. Use `Prism.plugins.fileHighlight.highlight` instead.');
				logged = true;
			}
			Prism.plugins.fileHighlight.highlight.apply(this, arguments);
		};

	}()); 
} (prism));

var prismExports = prism.exports;
var Prism = /*@__PURE__*/getDefaultExportFromCjs(prismExports);

var css = "code[class*=language-],pre[class*=language-]{word-wrap:normal;background:none;color:#ccc;font-family:Consolas,Monaco,Andale Mono,Ubuntu Mono,monospace;font-size:1em;-webkit-hyphens:none;hyphens:none;line-height:1.5;-moz-tab-size:4;-o-tab-size:4;tab-size:4;text-align:left;white-space:pre;word-break:normal;word-spacing:normal}pre[class*=language-]{margin:.5em 0;overflow:auto;padding:1em}:not(pre)>code[class*=language-],pre[class*=language-]{background:#2d2d2d}:not(pre)>code[class*=language-]{border-radius:.3em;padding:.1em;white-space:normal}.token.block-comment,.token.cdata,.token.comment,.token.doctype,.token.prolog{color:#999}.token.punctuation{color:#ccc}.token.attr-name,.token.deleted,.token.namespace,.token.tag{color:#e2777a}.token.function-name{color:#6196cc}.token.boolean,.token.function,.token.number{color:#f08d49}.token.class-name,.token.constant,.token.property,.token.symbol{color:#f8c555}.token.atrule,.token.builtin,.token.important,.token.keyword,.token.selector{color:#cc99cd}.token.attr-value,.token.char,.token.regex,.token.string,.token.variable{color:#7ec699}.token.entity,.token.operator,.token.url{color:#67cdcc}.token.bold,.token.important{font-weight:700}.token.italic{font-style:italic}.token.entity{cursor:help}.token.inserted{color:green}";
n(css,{});

var SyntaxHighlighter = function SyntaxHighlighter(_ref) {
  var className = _ref.className,
    code = _ref.code,
    language = _ref.language;
  useEffect(function () {
    Prism.highlightAll();
  }, [code]);
  return /*#__PURE__*/jsx("pre", {
    className: className,
    children: /*#__PURE__*/jsx("code", {
      className: "language-".concat(language),
      children: code
    })
  });
};
var SyntaxHighlighter$1 = /*#__PURE__*/memo(SyntaxHighlighter);

var CodeBlock = function CodeBlock(_ref) {
  var _ref$title = _ref.title,
    title = _ref$title === void 0 ? /*#__PURE__*/jsx("div", {
      children: /*#__PURE__*/jsx(Trans, {
        i18nKey: "neetoMolecules.codeblock.codeSnippet"
      })
    }) : _ref$title,
    codeString = _ref.codeString,
    _ref$showCopyButton = _ref.showCopyButton,
    showCopyButton = _ref$showCopyButton === void 0 ? true : _ref$showCopyButton,
    _ref$className = _ref.className,
    className = _ref$className === void 0 ? "" : _ref$className,
    _ref$sendViaEmail = _ref.sendViaEmail,
    sendViaEmail = _ref$sendViaEmail === void 0 ? undefined : _ref$sendViaEmail,
    _ref$frameworkProps = _ref.frameworkProps,
    frameworkProps = _ref$frameworkProps === void 0 ? {} : _ref$frameworkProps;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var _ref2 = frameworkProps !== null && frameworkProps !== void 0 ? frameworkProps : {},
    selectedFramework = _ref2.selectedFramework,
    setSelectedFramework = _ref2.setSelectedFramework;
  return /*#__PURE__*/jsxs("div", {
    className: classnames(["relative", className]),
    children: [/*#__PURE__*/jsxs("div", {
      className: "neeto-ui-rounded-lg neeto-ui-border-gray-200 neeto-ui-bg-gray-50 flex w-full flex-wrap items-center justify-between gap-2 rounded-b-none border p-3",
      children: [title && /*#__PURE__*/jsx(Typography, {
        className: "m-0 flex-shrink-0",
        "data-cy": "code-block-title-text",
        style: "h4",
        children: title
      }), selectedFramework && /*#__PURE__*/jsx(Select, {
        className: "w-40",
        "data-testid": "framework-select",
        options: FRAMEWORK_SELECT_OPTIONS,
        value: selectedFramework,
        onChange: setSelectedFramework
      }), /*#__PURE__*/jsxs("div", {
        className: "ml-auto flex flex-shrink-0 items-center justify-end gap-2",
        children: [sendViaEmail ? /*#__PURE__*/jsx(Button, {
          style: "text",
          label: t("neetoMolecules.widget.installation.snippet.sendViaEmail"),
          onClick: sendViaEmail
        }) : null, showCopyButton && /*#__PURE__*/jsx(CopyToClipboardButton, {
          label: t("neetoMolecules.widget.installation.snippet.copy"),
          style: "primary",
          value: codeString
        })]
      })]
    }), /*#__PURE__*/jsx(SyntaxHighlighter$1, {
      className: "neeto-ui-bg-gray-800 neeto-ui-rounded-lg m-0 rounded-t-none",
      code: codeString,
      language: "javascript"
    })]
  });
};

var buildEmbedWidgetScript = function buildEmbedWidgetScript() {
  var widgetScriptUrl = window.globalProps.railsEnv === RAILS_ENV.production ? NEETO_WIDGET_SCRIPT_URL.production : NEETO_WIDGET_SCRIPT_URL.staging;
  return "<script src=\"".concat(widgetScriptUrl, "\"></script>");
};
var indentAndFormat = function indentAndFormat(str) {
  var formatter = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : identity;
  return str.split("\n").map(formatter).join("\n  ");
};
var getCommentedCommand = function getCommentedCommand(command, isEnabled) {
  return isEnabled ? command : "/// ".concat(command);
};
var embedWidgetEnvironment = function embedWidgetEnvironment() {
  switch (window.globalProps.railsEnv) {
    case RAILS_ENV.production:
      return "";
    case RAILS_ENV.development:
      return "environment: \"".concat(RAILS_ENV.development, "\",");
    case RAILS_ENV.staging:
      return "environment: \"".concat(RAILS_ENV.staging, "\",");
    default:
      return "/* Unidentified RAILS_ENV, */";
  }
};
var embedWidgetApiKey = function embedWidgetApiKey(apiKey) {
  return "apiKey: \"".concat(apiKey, "\",");
};
var addEngageOptions = function addEngageOptions() {
  return "neetoEngageOptions: {\n  elementId: \"neetoengage-trigger\",\n},";
};
var wrapBlockInOnLoad = function wrapBlockInOnLoad(codeBlock) {
  return "window.addEventListener(\"load\", () => ".concat(codeBlock, ");");
};
var embedWidgetFunctionCall = function embedWidgetFunctionCall(enabledWidgets, apiKey) {
  return "embedNeetoWidget({\n  ".concat(embedWidgetEnvironment(), "\n  ").concat(indentAndFormat(embedWidgetApiKey(apiKey)), "\n  ").concat(indentAndFormat(addEngageOptions(), function (cmd) {
    return getCommentedCommand(cmd, enabledWidgets.engage);
  }), "\n})");
};
var filterMarkedCommands = function filterMarkedCommands(queryString) {
  return queryString.split("\n").filter(function (line) {
    return !line.includes("///") && line.trim();
  }).join("\n");
};
var getSampleUserIdentity = function getSampleUserIdentity(enabledWidgets, selectedFramework) {
  var splitCodeLines = SAMPLE_USER_IDENTITY_CODE_STRING[selectedFramework].split("\n");
  return filterMarkedCommands(splitCodeLines.map(function (cmd) {
    var isEmailKey = cmd.includes("email");
    var isObjectStartLine = cmd === splitCodeLines[0];
    var isObjectEndLine = cmd === last(splitCodeLines);
    var isLineHidden = !isEmailKey && !isObjectStartLine && !isObjectEndLine;
    if (!enabledWidgets.chat && isLineHidden || !enabledWidgets.chat && !enabledWidgets.replay) {
      return null;
    }
    return cmd;
  }).join("\n"));
};
var sampleConsolidatedCodeString = function sampleConsolidatedCodeString(enabledWidgets, apiKey) {
  return filterMarkedCommands("".concat(buildEmbedWidgetScript(), "\n<script>\n  ").concat(enabledWidgets.chat || enabledWidgets.replay ? "window.".concat(NEETO_WIDGET_USER_IDENTITY_KEY, " = {};") : "", "\n  ").concat(enabledWidgets.replay ? "window.".concat(SESSION_CONTEXT_KEY, " = {};") : "", "\n\n  ").concat(indentAndFormat(wrapBlockInOnLoad(embedWidgetFunctionCall(enabledWidgets, apiKey))), "\n</script>"));
};
var getEmailWidgetSnippetFormInitialValues = function getEmailWidgetSnippetFormInitialValues(subject) {
  return {
    emails: "",
    subject: subject
  };
};
var getSortedPrefixedWidgets = function getSortedPrefixedWidgets(widgets) {
  var sortedWidgets = widgets.sort().map(function (widget) {
    return "Neeto".concat(capitalize(widget));
  });
  return sortedWidgets.length === 1 ? sortedWidgets : t("neetoMolecules.widget.email.widgetList", {
    widgets: sortedWidgets
  });
};
var getWidgetDescriptions = function getWidgetDescriptions(widgets) {
  var values = Object.entries(WIDGET_DESCRIPTIONS).filter(function (_ref) {
    var _ref2 = _slicedToArray(_ref, 1),
      widget = _ref2[0];
    return widgets.includes(widget);
  });
  return pluck(1, values);
};
var getEmailWidgetSnippetValidationSchema = function getEmailWidgetSnippetValidationSchema() {
  return yup.object({
    emails: yup.array().required().label(i18next.t("neetoMolecules.widget.email.fields.emails.label")),
    subject: yup.string().required().label(i18next.t("neetoMolecules.widget.email.fields.subject.label"))
  });
};
var getWidgetApiKeyUrl = function getWidgetApiKeyUrl() {
  return "api/widget/v1/api_keys/".concat(window.globalProps.organization.subdomain);
};
var shouldShowSwitches = function shouldShowSwitches() {
  var _globalProps$user;
  var email = ((_globalProps$user = globalProps.user) === null || _globalProps$user === void 0 ? void 0 : _globalProps$user.email) || "";
  if (window.globalProps.railsEnv === RAILS_ENV.production) {
    return email.toLowerCase().endsWith("@bigbinary.com");
  }
  return true;
};

var queryWidgetApiKey = function queryWidgetApiKey() {
  return axios.get(getWidgetApiKeyUrl(), {
    showToastr: false
  });
};
var emailWidgetSnippet = function emailWidgetSnippet(data) {
  return axios.post(EMBED_CODE_EMAIL_URL, data);
};
var fetchWidgetConfiguration = function fetchWidgetConfiguration() {
  return axios.get(WIDGET_CONFIG_URL);
};
var updateWidgetConfiguration = function updateWidgetConfiguration(_ref) {
  var id = _ref.id,
    payload = _ref.payload;
  return axios.put("".concat(WIDGET_CONFIG_URL, "/").concat(id), payload);
};

var useEmailEmbedCode = function useEmailEmbedCode(onSuccess) {
  return useMutation({
    mutationFn: function mutationFn(emailData) {
      return emailWidgetSnippet(emailData);
    },
    onSuccess: onSuccess
  });
};

function ownKeys$3(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$3(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$3(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$3(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var CodeSnippet = function CodeSnippet(_ref) {
  var isPaneOpen = _ref.isPaneOpen,
    onClose = _ref.onClose,
    _ref$onSent = _ref.onSent,
    onSent = _ref$onSent === void 0 ? noop : _ref$onSent,
    codeString = _ref.codeString,
    _ref$subject = _ref.subject,
    subject = _ref$subject === void 0 ? "" : _ref$subject,
    _ref$body = _ref.body,
    body = _ref$body === void 0 ? "" : _ref$body,
    _ref$emailType = _ref.emailType,
    emailType = _ref$emailType === void 0 ? EMAIL_TYPES.embedCode : _ref$emailType,
    _ref$enabledWidgets = _ref.enabledWidgets,
    enabledWidgets = _ref$enabledWidgets === void 0 ? {} : _ref$enabledWidgets;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var _useState = useState(FRAMEWORK_SELECT_OPTIONS[0]),
    _useState2 = _slicedToArray(_useState, 2),
    selectedFramework = _useState2[0],
    setSelectedFramework = _useState2[1];
  var emailMutation = useEmailEmbedCode(onSent);
  var codeToDisplay = emailType === EMAIL_TYPES.userIdentity ? getSampleUserIdentity(enabledWidgets, selectedFramework.value) : codeString;
  var handleSubmit = function handleSubmit(formData) {
    var _body$ref$current$inn, _body$ref;
    if (any(function (_ref2) {
      var valid = _ref2.valid;
      return !valid;
    }, formData.emails)) {
      Toastr.error(t("neetoMolecules.widget.email.fields.emails.invalidError"));
      return;
    }
    emailMutation.mutate({
      subject: formData.subject,
      emails: pluck("value", formData.emails),
      message: (_body$ref$current$inn = (_body$ref = body.ref) === null || _body$ref === void 0 ? void 0 : _body$ref.current.innerHTML) !== null && _body$ref$current$inn !== void 0 ? _body$ref$current$inn : body,
      snippet: codeToDisplay
    });
  };
  var renderCodeBlockProps = function renderCodeBlockProps() {
    var props = {
      codeString: codeToDisplay,
      showCopyButton: false,
      className: "neeto-ui-rounded-lg"
    };
    if (emailType === EMAIL_TYPES.userIdentity) {
      props = assoc("frameworkProps", {
        selectedFramework: selectedFramework,
        setSelectedFramework: setSelectedFramework
      }, props);
    }
    return props;
  };
  return /*#__PURE__*/jsx(Pane, {
    onClose: onClose,
    isOpen: isPaneOpen,
    children: /*#__PURE__*/jsx(Formik, {
      initialValues: getEmailWidgetSnippetFormInitialValues(subject),
      validationSchema: getEmailWidgetSnippetValidationSchema(),
      onSubmit: handleSubmit,
      children: /*#__PURE__*/jsxs(Form, {
        children: [/*#__PURE__*/jsx(Pane.Header, {
          children: /*#__PURE__*/jsx(Typography, {
            style: "h2",
            children: t("neetoMolecules.widget.email.title")
          })
        }), /*#__PURE__*/jsx(Pane.Body, {
          children: /*#__PURE__*/jsxs("div", {
            className: "w-full space-y-4",
            children: [/*#__PURE__*/jsx(MultiEmailInput, {
              required: true,
              label: t("neetoMolecules.widget.email.fields.emails.label"),
              name: "emails",
              placeholder: t("neetoMolecules.widget.email.fields.emails.placeholder")
            }), /*#__PURE__*/jsx(Input, {
              required: true,
              label: t("neetoMolecules.widget.email.fields.subject.label"),
              name: "subject",
              type: "text"
            }), /*#__PURE__*/jsx(Typography, {
              style: "body2",
              children: body
            }), /*#__PURE__*/jsx(CodeBlock, _objectSpread$3({}, renderCodeBlockProps()))]
          })
        }), /*#__PURE__*/jsxs(Pane.Footer, {
          className: "gap-x-2",
          children: [/*#__PURE__*/jsx(Button, {
            disabled: emailMutation.isPending,
            label: t("neetoMolecules.widget.email.actions.send"),
            loading: emailMutation.isPending,
            type: "submit"
          }), /*#__PURE__*/jsx(Button, {
            label: t("neetoMolecules.widget.email.actions.cancel"),
            style: "text",
            onClick: onClose
          })]
        })]
      })
    })
  });
};

var useForceUpdate = function useForceUpdate() {
  // eslint-disable-next-line react/hook-use-state
  var _useState = useState(0),
    _useState2 = _slicedToArray(_useState, 2),
    setValue = _useState2[1];
  return function () {
    return setValue(function (value) {
      return value + 1;
    });
  };
};

function ownKeys$2(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$2(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$2(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$2(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var useFetchApiKey = function useFetchApiKey() {
  return useQuery({
    queryKey: [QUERY_KEYS.apiKey],
    queryFn: function queryFn() {
      if (window.globalProps.railsEnv === "heroku" || !window.globalProps.ssoEnabled) {
        return Promise.resolve({
          widgetApiKey: "placeholder-api-key"
        });
      }
      return queryWidgetApiKey();
    },
    staleTime: DEFAULT_QUERY_STALE_TIME
  });
};
var useFetchConfigurations = function useFetchConfigurations() {
  return useQuery({
    queryKey: [QUERY_KEYS.configuration],
    queryFn: fetchWidgetConfiguration,
    staleTime: DEFAULT_QUERY_STALE_TIME
  });
};
var useUpdateConfigurations = function useUpdateConfigurations() {
  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return useMutationWithInvalidation(updateWidgetConfiguration, _objectSpread$2({
    keysToInvalidate: [[QUERY_KEYS.configuration]]
  }, options));
};

var TooltipSwitch = withT(function (_ref) {
  var t = _ref.t,
    enabledClientApps = _ref.enabledClientApps,
    widget = _ref.widget,
    selectedWidgets = _ref.selectedWidgets,
    updateSelectedWidgets = _ref.updateSelectedWidgets;
  return /*#__PURE__*/jsx(Tooltip, {
    disabled: enabledClientApps.includes(widget),
    placement: "right",
    content: t("neetoMolecules.widget.tooltips.productIsDisabled", {
      productName: "Neeto".concat(capitalize(widget))
    }),
    children: /*#__PURE__*/jsx(Switch, {
      checked: selectedWidgets.includes(widget),
      disabled: !enabledClientApps.includes(widget),
      onChange: function onChange() {
        return updateSelectedWidgets(widget);
      }
    })
  });
});

var SelectionSwitches = function SelectionSwitches(_ref) {
  var selectedWidgets = _ref.selectedWidgets,
    updateSelectedWidgets = _ref.updateSelectedWidgets,
    primaryApp = _ref.primaryApp,
    enabledClientApps = _ref.enabledClientApps;
  var primaryWidget = WIDGET_TYPES_VALUES.includes(primaryApp) ? primaryApp : "";
  return /*#__PURE__*/jsxs("div", {
    className: "mb-4 flex w-full flex-wrap items-center justify-between gap-6",
    children: [/*#__PURE__*/jsxs("div", {
      className: "flex items-center space-x-2",
      children: [isNotEmpty(primaryWidget) && /*#__PURE__*/jsx(TooltipSwitch, {
        enabledClientApps: enabledClientApps,
        selectedWidgets: selectedWidgets,
        updateSelectedWidgets: updateSelectedWidgets,
        widget: primaryWidget
      }), /*#__PURE__*/jsxs(Label, {
        children: ["Neeto", capitalize(primaryWidget)]
      })]
    }), /*#__PURE__*/jsx("div", {
      className: "flex flex-wrap items-center gap-6 sm:justify-end",
      children: WIDGET_TYPES_VALUES.map(function (widget, index) {
        return primaryApp !== widget && /*#__PURE__*/jsxs("div", {
          className: "flex items-center space-x-2",
          children: [/*#__PURE__*/jsx(TooltipSwitch, {
            enabledClientApps: enabledClientApps,
            selectedWidgets: selectedWidgets,
            updateSelectedWidgets: updateSelectedWidgets,
            widget: widget
          }), /*#__PURE__*/jsxs(Label, {
            children: ["Neeto", capitalize(widget)]
          })]
        }, index);
      })
    })]
  });
};

function ownKeys$1(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$1(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$1(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$1(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var EmbedCode = function EmbedCode(_ref) {
  var showSessionContext = _ref.showSessionContext,
    showUserIdentity = _ref.showUserIdentity,
    _ref$primaryApp = _ref.primaryApp,
    primaryApp = _ref$primaryApp === void 0 ? "" : _ref$primaryApp,
    _ref$maxWidth = _ref.maxWidth,
    maxWidth = _ref$maxWidth === void 0 ? "max-w-3xl" : _ref$maxWidth;
  var _useState = useState(EMAIL_TYPES["null"]),
    _useState2 = _slicedToArray(_useState, 2),
    emailType = _useState2[0],
    setEmailType = _useState2[1];
  var _useState3 = useState(FRAMEWORK_SELECT_OPTIONS[0]),
    _useState4 = _slicedToArray(_useState3, 2),
    selectedFramework = _useState4[0],
    setSelectedFramework = _useState4[1];
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var bodyRef = useRef();
  var forceUpdate = useForceUpdate();
  useEffect(function () {
    forceUpdate();
  }, []);
  var _useFetchApiKey = useFetchApiKey(),
    _useFetchApiKey$data = _useFetchApiKey.data,
    _useFetchApiKey$data2 = _useFetchApiKey$data === void 0 ? {} : _useFetchApiKey$data,
    _useFetchApiKey$data3 = _useFetchApiKey$data2.widgetApiKey,
    widgetApiKey = _useFetchApiKey$data3 === void 0 ? "" : _useFetchApiKey$data3,
    isLoadingApiKey = _useFetchApiKey.isLoading;
  var _useFetchConfiguratio = useFetchConfigurations(),
    _useFetchConfiguratio2 = _useFetchConfiguratio.data,
    _useFetchConfiguratio3 = _useFetchConfiguratio2 === void 0 ? {} : _useFetchConfiguratio2,
    _useFetchConfiguratio4 = _useFetchConfiguratio3.neetoWidgetTokens,
    neetoWidgetTokens = _useFetchConfiguratio4 === void 0 ? [] : _useFetchConfiguratio4,
    isLoadingConfigurations = _useFetchConfiguratio.isLoading;
  var _useUpdateConfigurati = useUpdateConfigurations(),
    updateWidgetConfiguration = _useUpdateConfigurati.mutate;
  var previousEmailType = usePrevious(emailType);
  var selectedWidgets = neetoWidgetTokens.filter(function (item) {
    return item.enabled && (shouldShowSwitches() || item.clientApplicationName.toLowerCase() === primaryApp);
  }).map(function (item) {
    return item.clientApplicationName.toLowerCase();
  });
  var isOnlyChatWidgetSelected = selectedWidgets.length === 1 && selectedWidgets[0] === WIDGET_TYPES.chat;
  var enabledClientApps = neetoWidgetTokens.filter(prop("clientApplicationEnabled")).map(function (item) {
    return item.clientApplicationName.toLowerCase();
  });
  var enabledWidgets = fromPairs(selectedWidgets.map(function (widget) {
    return [widget, true];
  }));
  var shouldShowUserIdentity = showUserIdentity !== null && showUserIdentity !== void 0 ? showUserIdentity : enabledWidgets.chat || enabledWidgets.replay;
  var shouldShowSessionContext = showSessionContext !== null && showSessionContext !== void 0 ? showSessionContext : enabledWidgets.replay;
  var updateSelectedWidgets = function updateSelectedWidgets(widget) {
    var widgetId = neetoWidgetTokens.find(function (item) {
      return item.clientApplicationName.toLowerCase() === widget;
    }).id;
    var isEnabled = !selectedWidgets.includes(widget);
    updateWidgetConfiguration({
      id: widgetId,
      payload: {
        enabled: isEnabled
      }
    }, {
      onSuccess: function onSuccess() {
        var productName = "neeto".concat(capitalize(widget));
        var response = isEnabled ? "neetoMolecules.widget.installation.enabled" : "neetoMolecules.widget.installation.disabled";
        Toastr.success(t(response, {
          productName: productName
        }));
      }
    });
  };
  var getEmbedCodeString = function getEmbedCodeString() {
    return isNotEmpty(widgetApiKey) ? sampleConsolidatedCodeString(enabledWidgets, widgetApiKey) : "";
  };
  var _getSnippetProps = function getSnippetProps(selectedEmailType) {
    switch (selectedEmailType) {
      case EMAIL_TYPES.embedCode:
        return {
          codeString: getEmbedCodeString(),
          subject: t("neetoMolecules.widget.email.fields.subject.values.embedCode", {
            widgetList: getSortedPrefixedWidgets(selectedWidgets)
          }),
          body: /*#__PURE__*/jsxs("div", {
            ref: bodyRef,
            children: [/*#__PURE__*/jsx(Trans, {
              i18nKey: "neetoMolecules.widget.email.body.values.embedCode.mainText",
              components: {
                p: /*#__PURE__*/jsx(Typography, {
                  className: "mb-2",
                  style: "body2"
                })
              },
              values: {
                val: getWidgetDescriptions(selectedWidgets)
              }
            }), /*#__PURE__*/jsx(ChatWidgetBody, {
              widgets: selectedWidgets
            }), /*#__PURE__*/jsx(Trans, {
              i18nKey: "neetoMolecules.widget.email.body.values.embedCode.supportText",
              values: {
                helpEmail: INSTALLATION_HELP_EMAIL
              },
              components: {
                p: /*#__PURE__*/jsx(Typography, {
                  className: "mb-2",
                  style: "body2"
                }),
                mail: /*#__PURE__*/jsx(Button, {
                  href: "mailto:".concat(INSTALLATION_HELP_EMAIL),
                  rel: "noreferrer",
                  style: "link",
                  target: "_blank"
                })
              }
            })]
          })
        };
      case EMAIL_TYPES.userIdentity:
        return {
          emailType: EMAIL_TYPES.userIdentity,
          enabledWidgets: enabledWidgets,
          subject: t("neetoMolecules.widget.email.fields.subject.values.userIdentity"),
          body: /*#__PURE__*/jsx("div", {
            ref: bodyRef,
            children: /*#__PURE__*/jsx(Trans, {
              i18nKey: "neetoMolecules.widget.email.body.values.userIdentity",
              components: {
                p: /*#__PURE__*/jsx(Typography, {
                  className: "mb-2",
                  style: "body2"
                }),
                configureLink: /*#__PURE__*/jsx(Button, {
                  rel: "noreferrer",
                  style: "link",
                  target: "_blank",
                  href: enabledWidgets.chat ? NEETO_CHAT_USER_IDENTITY_URL : NEETO_REPLAY_CONFIGURE_URL
                })
              },
              values: {
                userIdentityKbUrl: enabledWidgets.chat ? NEETO_CHAT_USER_IDENTITY_URL : NEETO_REPLAY_CONFIGURE_URL
              }
            })
          })
        };
      case EMAIL_TYPES.sessionContext:
        return {
          codeString: SAMPLE_CONTEXT_CODE_STRING,
          subject: t("neetoMolecules.widget.email.fields.subject.values.sessionContext"),
          body: /*#__PURE__*/jsx("div", {
            ref: bodyRef,
            children: /*#__PURE__*/jsx(Trans, {
              i18nKey: "neetoMolecules.widget.email.body.values.sessionContext",
              values: {
                sessionContextKbUrl: NEETO_REPLAY_CONFIGURE_URL
              },
              components: {
                p: /*#__PURE__*/jsx(Typography, {
                  className: "mb-2",
                  style: "body2"
                }),
                configureLink: /*#__PURE__*/jsx(Button, {
                  href: NEETO_REPLAY_CONFIGURE_URL,
                  rel: "noreferrer",
                  style: "link",
                  target: "_blank"
                })
              }
            })
          })
        };
      case EMAIL_TYPES["null"]:
        return previousEmailType !== EMAIL_TYPES["null"] ? _getSnippetProps(previousEmailType) : {};
      default:
        throw new Error(t("neetoMolecules.widget.email.invalidType"));
    }
  };
  var handleSendViaEmail = function handleSendViaEmail(selectedEmail) {
    if (isEmpty(selectedWidgets)) {
      Toastr.error(t("neetoMolecules.widget.installation.snippet.disabledError"));
      return;
    }
    setEmailType(selectedEmail);
  };
  var getSelectedWidgetsInstructionsKey = function getSelectedWidgetsInstructionsKey() {
    if (isEmpty(selectedWidgets)) {
      return "neetoMolecules.widget.installation.instructions.placement.noneOfThese";
    }
    if (isOnlyChatWidgetSelected) {
      return "neetoMolecules.widget.installation.instructions.placement.selectedChatWidget";
    }
    return "neetoMolecules.widget.installation.instructions.placement.selectedWidgets";
  };
  var embedHelpTextTranslationComponents = {
    fontBold: /*#__PURE__*/jsx(Typography, {
      component: "span",
      style: "body2",
      weight: "semibold"
    }),
    widgetNpmLink: /*#__PURE__*/jsx(Button, {
      href: USE_NEETO_WIDGET_NPM_PAGE_URL,
      rel: "noreferrer",
      style: "link",
      target: "_blank"
    }),
    Link: /*#__PURE__*/jsx(Button, {
      href: WIDGET_KB_HELP_URL[primaryApp],
      rel: "noreferrer",
      style: "link",
      target: "_blank"
    })
  };
  if (isLoadingApiKey || isLoadingConfigurations) {
    return /*#__PURE__*/jsx("div", {
      className: "flex h-full w-full items-center justify-center",
      children: /*#__PURE__*/jsx(Spinner, {})
    });
  }
  return /*#__PURE__*/jsxs("div", {
    className: "mx-auto mb-10 w-full flex-col items-center justify-start",
    children: [/*#__PURE__*/jsxs("div", {
      className: classnames("mx-auto", maxWidth),
      children: [shouldShowSwitches() && /*#__PURE__*/jsx(SelectionSwitches, {
        enabledClientApps: enabledClientApps,
        primaryApp: primaryApp,
        selectedWidgets: selectedWidgets,
        updateSelectedWidgets: updateSelectedWidgets
      }), /*#__PURE__*/jsxs("div", {
        className: "mb-8 w-full flex-grow flex-col items-center justify-start",
        children: [/*#__PURE__*/jsx("div", {
          className: "mx-auto mb-2 w-full",
          "data-testid": "embed-code-block",
          children: /*#__PURE__*/jsx(CodeBlock, {
            className: "neeto-ui-rounded-lg",
            codeString: getEmbedCodeString(),
            sendViaEmail: function sendViaEmail() {
              return handleSendViaEmail(EMAIL_TYPES.embedCode);
            },
            title: /*#__PURE__*/jsx("div", {
              children: t("neetoMolecules.widget.title.embedCode")
            })
          })
        }), /*#__PURE__*/jsx("div", {
          className: "w-full",
          children: /*#__PURE__*/jsx(Trans, {
            components: embedHelpTextTranslationComponents,
            i18nKey: getSelectedWidgetsInstructionsKey(),
            values: {
              widgetList: getSortedPrefixedWidgets(selectedWidgets)
            }
          })
        })]
      }), shouldShowUserIdentity ? /*#__PURE__*/jsxs("div", {
        className: "mb-8 w-full flex-grow flex-col items-center justify-start",
        children: [/*#__PURE__*/jsx("div", {
          className: "mx-auto mb-2 w-full",
          children: /*#__PURE__*/jsx(CodeBlock, {
            className: "neeto-ui-rounded-lg",
            frameworkProps: {
              selectedFramework: selectedFramework,
              setSelectedFramework: setSelectedFramework
            },
            title: t("neetoMolecules.widget.title.userIdentity"),
            codeString: getSampleUserIdentity(enabledWidgets, selectedFramework.value),
            sendViaEmail: function sendViaEmail() {
              return handleSendViaEmail(EMAIL_TYPES.userIdentity);
            }
          })
        }), /*#__PURE__*/jsx(Trans, {
          i18nKey: "neetoMolecules.widget.installation.instructions.userIdentity",
          components: {
            p: /*#__PURE__*/jsx(Typography, {
              style: "body2"
            }),
            Link: /*#__PURE__*/jsx(Button, {
              rel: "noreferrer",
              style: "link",
              target: "_blank",
              href: enabledWidgets.chat ? NEETO_CHAT_USER_IDENTITY_URL : NEETO_REPLAY_CONFIGURE_URL
            })
          }
        })]
      }) : null, shouldShowSessionContext ? /*#__PURE__*/jsxs("div", {
        className: "w-full flex-grow flex-col items-center justify-start",
        children: [/*#__PURE__*/jsx("div", {
          className: "mx-auto mb-2 w-full",
          children: /*#__PURE__*/jsx(CodeBlock, {
            className: "neeto-ui-rounded-lg",
            codeString: SAMPLE_CONTEXT_CODE_STRING,
            title: t("neetoMolecules.widget.title.sessionContext"),
            sendViaEmail: function sendViaEmail() {
              return handleSendViaEmail(EMAIL_TYPES.sessionContext);
            }
          })
        }), /*#__PURE__*/jsx(Trans, {
          i18nKey: "neetoMolecules.widget.installation.instructions.sessionContext",
          components: {
            p: /*#__PURE__*/jsx(Typography, {
              style: "body2"
            }),
            Link: /*#__PURE__*/jsx(Button, {
              href: NEETO_REPLAY_CONFIGURE_URL,
              rel: "noreferrer",
              style: "link",
              target: "_blank"
            })
          }
        })]
      }) : null]
    }), /*#__PURE__*/jsx(CodeSnippet, _objectSpread$1({
      isPaneOpen: !!emailType && isNotEmpty(selectedWidgets),
      onClose: function onClose() {
        return setEmailType(EMAIL_TYPES["null"]);
      }
    }, _getSnippetProps(emailType)))]
  });
};
var EmbedCode$1 = /*#__PURE__*/memo(EmbedCode);

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var queryClient = new QueryClient();
var Main = function Main(props) {
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var shouldRenderEmbedCode = window.globalProps.ssoEnabled;
  return shouldRenderEmbedCode ? /*#__PURE__*/jsx(QueryClientProvider, {
    client: queryClient,
    children: /*#__PURE__*/jsx(EmbedCode$1, _objectSpread({}, props))
  }) : /*#__PURE__*/jsx(Callout, {
    icon: Info,
    style: "info",
    children: t("neetoMolecules.widget.developmentInfo")
  });
};

var NeetoWidget = {
  EmbedCode: Main,
  WIDGET_TYPES: WIDGET_TYPES
};

export { NeetoWidget as default };
//# sourceMappingURL=NeetoWidget.js.map
