import _defineProperty from '@babel/runtime/helpers/defineProperty';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import { useState, useEffect, createElement } from 'react';
import classnames from 'classnames';
import { filterBy, noop } from '@bigbinary/neeto-cist';
import LeftArrow from '@bigbinary/neeto-icons/LeftArrow';
import Button from '@bigbinary/neetoui/Button';
import Typography from '@bigbinary/neetoui/Typography';
import { toPairs, mergeDeepLeft, isEmpty, mergeLeft } from 'ramda';
import { useTranslation } from 'react-i18next';
import Codeblock from './Codeblock.js';
import { jsx, jsxs } from 'react/jsx-runtime';
import { t } from 'i18next';
import Code$1 from '@bigbinary/neeto-icons/Code';
import Input from '@bigbinary/neetoui/Input';
import Callout from '@bigbinary/neetoui/Callout';
import _toConsumableArray from '@babel/runtime/helpers/toConsumableArray';
import Delete from '@bigbinary/neeto-icons/Delete';
import Plus from '@bigbinary/neeto-icons/Plus';
import Label from '@bigbinary/neetoui/Label';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import Checkbox from '@bigbinary/neetoui/Checkbox';
import Select from '@bigbinary/neetoui/Select';
import ColorPicker from '@bigbinary/neetoui/ColorPicker';
import Tab from '@bigbinary/neetoui/Tab';
import Radio from '@bigbinary/neetoui/Radio';
import Spinner from '@bigbinary/neetoui/Spinner';
import BrowserPreview from './BrowserPreview.js';
import { n } from './inject-css-DmrvuTKK.js';
import 'react-syntax-highlighter/dist/esm/prism-light.js';
import 'react-syntax-highlighter/dist/esm/styles/prism';
import './CopyToClipboardButton.js';
import '@bigbinary/neeto-commons-frontend/utils/general';
import '@bigbinary/neeto-icons/Copy';
import '@bigbinary/neeto-icons/Check';

var Code = function Code(_ref) {
  var code = _ref.code,
    tab = _ref.tab;
  return /*#__PURE__*/jsx("div", {
    className: "neeto-molecules-embed__code-block relative w-full overflow-y-auto",
    "data-cy": "embed-code-block",
    "data-testid": "".concat(tab, "-code-block"),
    children: /*#__PURE__*/jsx(Codeblock, {
      code: code
    })
  });
};

var TAB_KEYS = {
  HTML: "html",
  REACT: "react"
};
var TABS = [{
  key: TAB_KEYS.HTML,
  label: t("neetoMolecules.productEmbed.tab.html"),
  icon: Code$1
}, {
  key: TAB_KEYS.REACT,
  label: t("neetoMolecules.productEmbed.tab.react"),
  icon: Code$1
}];
var EMBED_OPTIONS = {
  INLINE: "inline",
  FLOATING_POPUP: "floatingPopup",
  ELEMENT_POPUP: "elementPopup"
};
var DEFAULT_CUSTOMIZATION = _defineProperty(_defineProperty(_defineProperty({}, EMBED_OPTIONS.INLINE, {
  width: 100,
  height: 100,
  elementSelector: "inline-embed-container"
}), EMBED_OPTIONS.FLOATING_POPUP, {
  showIcon: false,
  btnText: "Open",
  btnColor: "#008068",
  btnTextColor: "#fff",
  btnPosition: "bottomRight"
}), EMBED_OPTIONS.ELEMENT_POPUP, {
  elementSelector: "open-popup-button"
});
var SCRIPT_ID = "embed-script";
var TAB_STRING = "    ";

var FLOATING_BUTTON_POSITIONS = [{
  label: t("neetoMolecules.productEmbed.customization.position.bottomLeft"),
  value: "bottomLeft"
}, {
  label: t("neetoMolecules.productEmbed.customization.position.bottomRight"),
  value: "bottomRight"
}];
var INITIAL_QUERY_PARAM = {
  name: "",
  value: ""
};

var camelCasedAppName$1 = globalProps.appName.replace(/^neeto/i, "neeto");
var embedBaseScript = function embedBaseScript(embedScriptLink) {
  return "<script>window.".concat(camelCasedAppName$1, " = window.").concat(camelCasedAppName$1, " || { embed: function(){(").concat(camelCasedAppName$1, ".q=").concat(camelCasedAppName$1, ".q||[]).push(arguments)} };</script>\n  <script async\n    src=\"").concat(embedScriptLink, "\">\n  </script>");
};
var embedEnv$1 = function embedEnv() {
  return globalProps.railsEnv !== "production" ? "\n".concat(TAB_STRING, "  env: \"").concat(globalProps.railsEnv, "\",") : "";
};
var embedQueryParam$1 = function embedQueryParam(queryParams) {
  return queryParams ? "\n".concat(TAB_STRING, "  queryParams: ").concat(queryParams, ",") : "";
};
var parseExtraArgs$1 = function parseExtraArgs(extraArgs) {
  return toPairs(extraArgs).map(function (_ref) {
    var _ref2 = _slicedToArray(_ref, 2),
      key = _ref2[0],
      value = _ref2[1];
    return "\n".concat(TAB_STRING, "  ").concat(key, ": \"").concat(value, "\"");
  });
};
var inlineEmbedCode$1 = function inlineEmbedCode(_ref3) {
  var customization = _ref3.customization,
    id = _ref3.id,
    embedScriptLink = _ref3.embedScriptLink,
    extraArgs = _ref3.extraArgs,
    inlineWrapperStyle = _ref3.inlineWrapperStyle;
  var elementSelector = customization.elementSelector,
    _customization$width = customization.width,
    width = _customization$width === void 0 ? 100 : _customization$width,
    _customization$height = customization.height,
    height = _customization$height === void 0 ? 100 : _customization$height,
    queryParams = customization.queryParams;
  return "\n  <!-- ".concat(globalProps.appName, " inline embed code begins -->\n  <div style=\"").concat(inlineWrapperStyle || "height: 90vh; width: 100%;", "\" id=\"").concat(elementSelector, "\">\n    <!-- ").concat(globalProps.appName, " widget will be added here -->\n  </div>\n  ").concat(embedBaseScript(embedScriptLink), "\n  <script>\n    ").concat(camelCasedAppName$1, ".embed({\n      type: \"inline\",\n      id: \"").concat(id, "\",\n      organization: \"").concat(globalProps.organization.subdomain, "\",\n      elementSelector: \"#").concat(elementSelector, "\",\n      styles: { height: \"").concat(height, "%\", width: \"").concat(width, "%\"},").concat(embedQueryParam$1(queryParams)).concat(embedEnv$1()).concat(parseExtraArgs$1(extraArgs), "\n    });\n  </script>\n  <!-- ").concat(globalProps.appName, " inline embed code ends -->");
};
var floatingPopupEmbedCode$1 = function floatingPopupEmbedCode(_ref4) {
  var customization = _ref4.customization,
    id = _ref4.id,
    embedScriptLink = _ref4.embedScriptLink,
    extraArgs = _ref4.extraArgs;
  var btnTextColor = customization.btnTextColor,
    showIcon = customization.showIcon,
    btnText = customization.btnText,
    btnPosition = customization.btnPosition,
    btnColor = customization.btnColor,
    icon = customization.icon,
    queryParams = customization.queryParams;
  return "\n  <!-- ".concat(globalProps.appName, " floating-popup embed code begins -->\n  ").concat(embedBaseScript(embedScriptLink), "\n  <script>\n    ").concat(camelCasedAppName$1, ".embed({\n      type: \"floatingPopup\",\n      id: \"").concat(id, "\",\n      organization: \"").concat(globalProps.organization.subdomain, "\",\n      styles: {\n        btnTextColor: \"").concat(btnTextColor, "\",\n        btnPosition: \"").concat(btnPosition, "\",\n        btnColor: \"").concat(btnColor, "\",\n        btnText: \"").concat(btnText, "\", ").concat(icon ? "\n".concat(TAB_STRING).concat(TAB_STRING, "showIcon: ").concat(showIcon, ",") : "", "\n      },").concat(embedQueryParam$1(queryParams)).concat(embedEnv$1()).concat(parseExtraArgs$1(extraArgs), "\n    });\n  </script>\n  <!-- ").concat(globalProps.appName, " floating-popup embed code ends -->");
};
var elementPopupEmbedCode$1 = function elementPopupEmbedCode(_ref5) {
  var customization = _ref5.customization,
    id = _ref5.id,
    embedScriptLink = _ref5.embedScriptLink,
    extraArgs = _ref5.extraArgs;
  var elementSelector = customization.elementSelector,
    queryParams = customization.queryParams;
  return "\n  <!-- This is a demo button, you can use any element on your website instead. -->\n  <button id=\"".concat(elementSelector, "\">Click to open popup</button>\n\n  <!-- ").concat(globalProps.appName, " element-click embed code begins -->\n  ").concat(embedBaseScript(embedScriptLink), "\n  <script>\n    ").concat(camelCasedAppName$1, ".embed({\n      type: \"elementClick\",\n      id: \"").concat(id, "\",\n      organization: \"").concat(globalProps.organization.subdomain, "\",\n      elementSelector: \"#").concat(elementSelector, "\",").concat(embedQueryParam$1(queryParams)).concat(embedEnv$1()).concat(parseExtraArgs$1(extraArgs), "\n    });\n  </script>\n  <!-- ").concat(globalProps.appName, " element-click embed code ends -->");
};
var htmlCodeGenerators = {
  inline: inlineEmbedCode$1,
  floatingPopup: floatingPopupEmbedCode$1,
  elementPopup: elementPopupEmbedCode$1
};

var camelCasedAppName = globalProps.appName.replace(/^neeto/i, "neeto");
var embedFunctionName = "embed".concat(globalProps.appName);
var baseScript = "const baseScript = document.createElement(\"script\");\n      baseScript.innerHTML = `window.".concat(camelCasedAppName, " = window.").concat(camelCasedAppName, " || { embed: function(){(").concat(camelCasedAppName, ".q=").concat(camelCasedAppName, ".q||[]).push(arguments)} };`\n      document.body.appendChild(baseScript);\n");
var embedScript = function embedScript(scriptLink) {
  return "const embedScript = document.createElement(\"script\");\n      embedScript.src = \"".concat(scriptLink, "\";\n      embedScript.async = true;\n      document.body.appendChild(embedScript);\n");
};
var cleanupFunction = "// Cleanup function\n      return () => {\n        document.body.removeChild(baseScript);\n        document.body.removeChild(embedScript);\n      };";
var embedEnv = function embedEnv() {
  return globalProps.railsEnv !== "production" ? "\n".concat(TAB_STRING).concat(TAB_STRING, "env: \"").concat(globalProps.railsEnv, "\",") : "";
};
var embedQueryParam = function embedQueryParam(queryParams) {
  return queryParams ? "\n".concat(TAB_STRING).concat(TAB_STRING, "queryParams: ").concat(queryParams, ",") : "";
};
var parseExtraArgs = function parseExtraArgs(extraArgs) {
  return toPairs(extraArgs).map(function (_ref) {
    var _ref2 = _slicedToArray(_ref, 2),
      key = _ref2[0],
      value = _ref2[1];
    return "\n".concat(TAB_STRING).concat(TAB_STRING).concat(key, ": \"").concat(value, "\"");
  });
};
var parseInlineStyle = function parseInlineStyle(styleString) {
  return styleString ? styleString.split(";").map(function (rule) {
    var _rule$split$map = rule.split(":").map(function (s) {
        return s.trim();
      }),
      _rule$split$map2 = _slicedToArray(_rule$split$map, 2),
      key = _rule$split$map2[0],
      value = _rule$split$map2[1];
    return key && value ? "".concat(key, ": \"").concat(value, "\"") : null;
  }).filter(Boolean).join(", ") : 'height: "90vh", width: "100%"';
};
var inlineEmbedCode = function inlineEmbedCode(_ref3) {
  var customization = _ref3.customization,
    id = _ref3.id,
    embedScriptLink = _ref3.embedScriptLink,
    extraArgs = _ref3.extraArgs,
    inlineWrapperStyle = _ref3.inlineWrapperStyle;
  var elementSelector = customization.elementSelector,
    _customization$width = customization.width,
    width = _customization$width === void 0 ? 100 : _customization$width,
    _customization$height = customization.height,
    height = _customization$height === void 0 ? 100 : _customization$height,
    queryParams = customization.queryParams;
  return "\n  import { useEffect } from \"react\";\n\n  const App = () => {\n    const ".concat(embedFunctionName, " = () => {\n      ").concat(baseScript, "\n      ").concat(embedScript(embedScriptLink), "\n      ").concat(camelCasedAppName, ".embed({\n        type: \"inline\",\n        id: \"").concat(id, "\",\n        organization: \"").concat(globalProps.organization.subdomain, "\",\n        elementSelector: \"#").concat(elementSelector, "\",\n        styles: { height: \"").concat(height, "%\", width: \"").concat(width, "%\" },").concat(embedQueryParam(queryParams)).concat(embedEnv()).concat(parseExtraArgs(extraArgs), "\n      });\n\n      ").concat(cleanupFunction, "\n    };\n\n    useEffect(() => ").concat(embedFunctionName, "(), []);\n\n    return (\n      <div\n        id=\"inline-embed-container\"\n        style={{ ").concat(parseInlineStyle(inlineWrapperStyle), " }}\n      />\n    );\n  };");
};
var floatingPopupEmbedCode = function floatingPopupEmbedCode(_ref4) {
  var customization = _ref4.customization,
    id = _ref4.id,
    embedScriptLink = _ref4.embedScriptLink,
    extraArgs = _ref4.extraArgs;
  var btnTextColor = customization.btnTextColor,
    showIcon = customization.showIcon,
    btnText = customization.btnText,
    btnPosition = customization.btnPosition,
    btnColor = customization.btnColor,
    icon = customization.icon,
    queryParams = customization.queryParams;
  return "\n  import { useEffect } from \"react\";\n\n  const App = () => {\n    const ".concat(embedFunctionName, " = () => {\n      ").concat(baseScript, "\n      ").concat(embedScript(embedScriptLink), "\n      ").concat(camelCasedAppName, ".embed({\n        type: \"floatingPopup\",\n        id: \"").concat(id, "\",\n        organization: \"").concat(globalProps.organization.subdomain, "\",\n        styles: {\n          btnTextColor: \"").concat(btnTextColor, "\",\n          btnPosition: \"").concat(btnPosition, "\",\n          btnColor: \"").concat(btnColor, "\",\n          btnText: \"").concat(btnText, "\",").concat(icon ? "\n".concat(TAB_STRING).concat(TAB_STRING, "  showIcon: ").concat(showIcon, ",") : "", "\n        },").concat(embedQueryParam(queryParams)).concat(embedEnv()).concat(parseExtraArgs(extraArgs), "\n      });\n\n      ").concat(cleanupFunction, "\n    };\n\n    useEffect(() => ").concat(embedFunctionName, "(), []);\n\n    return <div />;\n  };");
};
var elementPopupEmbedCode = function elementPopupEmbedCode(_ref5) {
  var customization = _ref5.customization,
    id = _ref5.id,
    embedScriptLink = _ref5.embedScriptLink,
    extraArgs = _ref5.extraArgs;
  var elementSelector = customization.elementSelector,
    queryParams = customization.queryParams;
  return "\n  import { useEffect } from \"react\";\n\n  const App = () => {\n    const ".concat(embedFunctionName, " = () => {\n      ").concat(baseScript, "\n      ").concat(embedScript(embedScriptLink), "\n      ").concat(camelCasedAppName, ".embed({\n        type: \"elementClick\",\n        id: \"").concat(id, "\",\n        organization: \"").concat(globalProps.organization.subdomain, "\",\n        elementSelector: \"#").concat(elementSelector, "\",").concat(embedQueryParam(queryParams)).concat(embedEnv()).concat(parseExtraArgs(extraArgs), "\n      });\n\n      ").concat(cleanupFunction, "\n    };\n\n    useEffect(() => ").concat(embedFunctionName, "(), []);\n\n    return <button id=\"").concat(elementSelector, "\">Click to open popup</button>;\n  };");
};
var reactCodeGenerators = {
  inline: inlineEmbedCode,
  floatingPopup: floatingPopupEmbedCode,
  elementPopup: elementPopupEmbedCode
};

var _excluded = ["tab", "type"];
var generateCode = function generateCode(options) {
  var _reactCodeGenerators$, _htmlCodeGenerators$t;
  var tab = options.tab,
    type = options.type,
    embeddedCodeOptions = _objectWithoutProperties(options, _excluded);
  return tab === "react" ? (_reactCodeGenerators$ = reactCodeGenerators[type]) === null || _reactCodeGenerators$ === void 0 ? void 0 : _reactCodeGenerators$.call(reactCodeGenerators, embeddedCodeOptions) : (_htmlCodeGenerators$t = htmlCodeGenerators[type]) === null || _htmlCodeGenerators$t === void 0 ? void 0 : _htmlCodeGenerators$t.call(htmlCodeGenerators, embeddedCodeOptions);
};
var buildDefaultCustomization = function buildDefaultCustomization(defaultCustomizations) {
  return mergeDeepLeft(defaultCustomizations, DEFAULT_CUSTOMIZATION);
};
var buildQueryParamsFromInputFields = function buildQueryParamsFromInputFields(inputFields) {
  var filteredInputFields = inputFields.filter(function (_ref) {
    var name = _ref.name,
      value = _ref.value;
    return name && value;
  });
  var queryParams = filteredInputFields.reduce(function (queryParams, _ref2) {
    var name = _ref2.name,
      value = _ref2.value;
    queryParams[name] = value;
    return queryParams;
  }, {});
  if (isEmpty(queryParams)) return "";
  var queryParamJsonString = JSON.stringify(queryParams, null, 2);
  return queryParamJsonString.replace(/\n/g, " ").replace(/\s\s+/g, " ");
};

function ownKeys$1(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$1(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$1(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$1(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var DynamicQueryParams = function DynamicQueryParams(_ref) {
  var updateCustomization = _ref.updateCustomization;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var _useState = useState([INITIAL_QUERY_PARAM]),
    _useState2 = _slicedToArray(_useState, 2),
    queryParams = _useState2[0],
    setQueryParams = _useState2[1];
  var handleAddQueryParam = function handleAddQueryParam() {
    setQueryParams([].concat(_toConsumableArray(queryParams), [INITIAL_QUERY_PARAM]));
  };
  var handleRemoveQueryParam = function handleRemoveQueryParam(index) {
    var newQueryParams = queryParams.filter(function (_, i) {
      return i !== index;
    });
    setQueryParams(newQueryParams);
  };
  var handleInputChange = function handleInputChange(index, field, value) {
    var newQueryParams = queryParams.map(function (param, i) {
      return i === index ? _objectSpread$1(_objectSpread$1({}, param), {}, _defineProperty({}, field, value)) : param;
    });
    setQueryParams(newQueryParams);
  };
  useEffect(function () {
    updateCustomization({
      queryParams: buildQueryParamsFromInputFields(queryParams)
    });
  }, [queryParams]);
  return /*#__PURE__*/jsxs("div", {
    children: [/*#__PURE__*/jsx(Label, {
      className: "mb-2",
      "data-cy": "dynamic-query-params-label",
      children: t("neetoMolecules.productEmbed.customization.queryParam.label")
    }), queryParams.map(function (param, index) {
      return /*#__PURE__*/jsxs("div", {
        className: "mb-1 flex gap-1",
        children: [/*#__PURE__*/jsx(Input, {
          "data-cy": "dynamic-query-key-name-input",
          "data-testid": "dynamic-query-key-name-input",
          name: "queryParams.".concat(index, ".name"),
          value: param.name,
          placeholder: t("neetoMolecules.productEmbed.customization.queryParam.keyNamePlaceholder"),
          onChange: function onChange(e) {
            return handleInputChange(index, "name", e.target.value);
          }
        }), /*#__PURE__*/jsx(Input, {
          "data-cy": "dynamic-query-key-value-input",
          "data-testid": "dynamic-query-key-value-input",
          name: "queryParams.".concat(index, ".value"),
          value: param.value,
          placeholder: t("neetoMolecules.productEmbed.customization.queryParam.keyValuePlaceholder"),
          onChange: function onChange(e) {
            return handleInputChange(index, "value", e.target.value);
          }
        }), /*#__PURE__*/jsx(Button, {
          "data-cy": "dynamic-query-delete-button",
          icon: Delete,
          style: "text",
          onClick: function onClick() {
            return handleRemoveQueryParam(index);
          }
        })]
      }, index);
    }), /*#__PURE__*/jsx(Button, {
      className: "my-2",
      "data-cy": "dynamic-query-add-new-button",
      icon: Plus,
      iconPosition: "left",
      style: "link",
      label: t("neetoMolecules.productEmbed.customization.queryParam.addQueryParam"),
      onClick: handleAddQueryParam
    })]
  });
};

var ElementPopup$1 = function ElementPopup(_ref) {
  var customization = _ref.customization,
    updateCustomization = _ref.updateCustomization,
    isQueryParamsEnabled = _ref.isQueryParamsEnabled,
    otherCustomizations = _ref.otherCustomizations;
  var elementSelector = customization.elementSelector;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  useEffect(function () {
    if (isQueryParamsEnabled) return;
    updateCustomization({
      queryParams: undefined
    });
  }, []);
  return /*#__PURE__*/jsxs("div", {
    className: "space-y-6",
    children: [/*#__PURE__*/jsx(Typography, {
      "data-cy": "element-popup-header",
      style: "h4",
      children: t("neetoMolecules.productEmbed.customization.elementPopup.title")
    }), /*#__PURE__*/jsx(Callout, {
      "data-cy": "element-popup-description",
      children: t("neetoMolecules.productEmbed.customization.elementPopup.description")
    }), /*#__PURE__*/jsx(Input, {
      className: "w-full",
      "data-cy": "element-id-input-field",
      "data-testid": "element-id-input-field",
      value: elementSelector,
      error: !elementSelector && t("neetoMolecules.productEmbed.customization.elementPopup.warning"),
      label: t("neetoMolecules.productEmbed.customization.elementPopup.elementId"),
      onChange: function onChange(e) {
        return updateCustomization({
          elementSelector: e.target.value
        });
      }
    }), otherCustomizations(), isQueryParamsEnabled && /*#__PURE__*/jsx(DynamicQueryParams, {
      updateCustomization: updateCustomization
    })]
  });
};

var FloatingPopup$1 = function FloatingPopup(_ref) {
  var customization = _ref.customization,
    updateCustomization = _ref.updateCustomization,
    isQueryParamsEnabled = _ref.isQueryParamsEnabled,
    otherCustomizations = _ref.otherCustomizations;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var btnTextColor = customization.btnTextColor,
    showIcon = customization.showIcon,
    btnText = customization.btnText,
    btnPosition = customization.btnPosition,
    btnColor = customization.btnColor,
    icon = customization.icon;
  useEffect(function () {
    if (isQueryParamsEnabled) return;
    updateCustomization({
      queryParams: undefined
    });
  }, []);
  return /*#__PURE__*/jsxs("div", {
    className: "space-y-6",
    children: [/*#__PURE__*/jsx(Typography, {
      "data-cy": "popup-customization-header",
      style: "h4",
      children: t("neetoMolecules.productEmbed.customization.floatingPopup.title")
    }), icon && /*#__PURE__*/jsx(Checkbox, {
      checked: showIcon,
      "data-cy": "show-icon-checkbox",
      "data-testid": "show-icon-checkbox",
      label: t("neetoMolecules.productEmbed.customization.floatingPopup.showCalIcon"),
      onChange: function onChange(e) {
        return updateCustomization({
          showIcon: e.target.checked
        });
      }
    }), /*#__PURE__*/jsx("div", {
      className: "space-y-2",
      children: /*#__PURE__*/jsx(Input, {
        "data-cy": "button-text-input-field",
        "data-testid": "button-text-input-field",
        value: btnText,
        label: t("neetoMolecules.productEmbed.customization.floatingPopup.button.text"),
        onChange: function onChange(e) {
          return updateCustomization({
            btnText: e.target.value
          });
        }
      })
    }), /*#__PURE__*/jsx("div", {
      className: "space-y-2",
      children: /*#__PURE__*/jsx(Select, {
        "data-cy": "button-position-select-field",
        "data-testid": "button-position-select-field",
        options: FLOATING_BUTTON_POSITIONS,
        value: btnPosition,
        getOptionValue: function getOptionValue(option) {
          return typeof option === "string" ? option : option.value;
        },
        label: t("neetoMolecules.productEmbed.customization.floatingPopup.button.pos"),
        onChange: function onChange(e) {
          return updateCustomization({
            btnPosition: e.value
          });
        }
      })
    }), /*#__PURE__*/jsxs("div", {
      className: "flex items-center justify-between gap-x-2",
      "data-cy": "button-color-label",
      children: [/*#__PURE__*/jsx(Label, {
        children: t("neetoMolecules.productEmbed.customization.floatingPopup.button.color")
      }), /*#__PURE__*/jsx(ColorPicker, {
        color: btnColor,
        onChange: function onChange(e) {
          return updateCustomization({
            btnColor: e.hex
          });
        }
      })]
    }), /*#__PURE__*/jsxs("div", {
      className: "flex items-center justify-between gap-x-2",
      "data-cy": "button-text-color-label",
      children: [/*#__PURE__*/jsx(Label, {
        children: t("neetoMolecules.productEmbed.customization.floatingPopup.button.textColor")
      }), /*#__PURE__*/jsx(ColorPicker, {
        color: btnTextColor,
        onChange: function onChange(e) {
          return updateCustomization({
            btnTextColor: e.hex
          });
        }
      })]
    }), otherCustomizations(), isQueryParamsEnabled && /*#__PURE__*/jsx(DynamicQueryParams, {
      updateCustomization: updateCustomization
    })]
  });
};

var Inline$1 = function Inline(_ref) {
  var customization = _ref.customization,
    updateCustomization = _ref.updateCustomization,
    isQueryParamsEnabled = _ref.isQueryParamsEnabled,
    otherCustomizations = _ref.otherCustomizations;
  var height = customization.height,
    width = customization.width,
    elementSelector = customization.elementSelector;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var handleInputChange = function handleInputChange(_ref2, attribute) {
    var value = _ref2.target.value;
    return updateCustomization(_defineProperty({}, attribute, value));
  };
  useEffect(function () {
    if (isQueryParamsEnabled) return;
    updateCustomization({
      queryParams: undefined
    });
  }, []);
  return /*#__PURE__*/jsxs("div", {
    className: "flex flex-col gap-y-6",
    children: [/*#__PURE__*/jsx(Typography, {
      "data-cy": "customization-text",
      style: "h4",
      children: t("neetoMolecules.productEmbed.customization.inline.title")
    }), /*#__PURE__*/jsxs("div", {
      className: "flex flex-col gap-2",
      children: [/*#__PURE__*/jsx(Label, {
        "data-cy": "window-size-text",
        children: t("neetoMolecules.productEmbed.customization.inline.sizeOfEmbedWindow")
      }), /*#__PURE__*/jsxs("div", {
        className: "flex justify-between gap-x-2",
        children: [/*#__PURE__*/jsx(Input, {
          className: "neeto-molecules-product-embed-size-input",
          "data-cy": "inline-width-input-field",
          "data-testid": "inline-width-input-field",
          max: 100,
          min: 0,
          prefix: "W",
          suffix: "%",
          type: "number",
          value: width,
          onChange: function onChange(e) {
            return handleInputChange(e, "width");
          }
        }), /*#__PURE__*/jsx(Input, {
          className: "neeto-molecules-product-embed-size-input",
          "data-cy": "inline-height-input-field",
          "data-testid": "inline-height-input-field",
          max: 100,
          min: 0,
          prefix: "H",
          suffix: "%",
          type: "number",
          value: height,
          onChange: function onChange(e) {
            return handleInputChange(e, "height");
          }
        })]
      })]
    }), /*#__PURE__*/jsxs("div", {
      className: "flex flex-col gap-2",
      children: [/*#__PURE__*/jsx(Label, {
        "data-cy": "inline-element-id-input-label",
        children: t("neetoMolecules.productEmbed.customization.inline.elementId")
      }), /*#__PURE__*/jsx(Input, {
        "data-cy": "inline-element-id-input-field",
        "data-testid": "inline-element-id-input-field",
        value: elementSelector,
        onChange: function onChange(e) {
          return handleInputChange(e, "elementSelector");
        }
      })]
    }), otherCustomizations(), isQueryParamsEnabled && /*#__PURE__*/jsx(DynamicQueryParams, {
      updateCustomization: updateCustomization
    })]
  });
};

var Customization = function Customization(_ref) {
  var option = _ref.option,
    customization = _ref.customization,
    updateCustomization = _ref.updateCustomization,
    isQueryParamsEnabled = _ref.isQueryParamsEnabled,
    otherCustomizations = _ref.otherCustomizations;
  var type = _defineProperty(_defineProperty(_defineProperty({}, EMBED_OPTIONS.INLINE, Inline$1), EMBED_OPTIONS.FLOATING_POPUP, FloatingPopup$1), EMBED_OPTIONS.ELEMENT_POPUP, ElementPopup$1);
  var Component = type[option];
  return /*#__PURE__*/jsx(Component, {
    customization: customization,
    isQueryParamsEnabled: isQueryParamsEnabled,
    otherCustomizations: otherCustomizations,
    updateCustomization: updateCustomization
  });
};

var Header = function Header(_ref) {
  var supportedLanguagesTabs = _ref.supportedLanguagesTabs,
    setTab = _ref.setTab,
    tab = _ref.tab;
  return /*#__PURE__*/jsx("div", {
    className: "flex w-full",
    children: /*#__PURE__*/jsx(Tab, {
      noUnderline: true,
      className: "neeto-molecules-product-embed-tab",
      children: supportedLanguagesTabs.map(function (_ref2) {
        var key = _ref2.key,
          label = _ref2.label,
          icon = _ref2.icon;
        return /*#__PURE__*/createElement(Tab.Item, {
          icon: icon,
          active: tab === key,
          "data-cy": "".concat(key, "-tab"),
          "data-testid": "".concat(key, "-tab"),
          key: key,
          onClick: function onClick() {
            return setTab(key);
          }
        }, label);
      })
    })
  });
};

var Options = function Options(_ref) {
  var options = _ref.options,
    selectedOption = _ref.selectedOption,
    setSelectedOption = _ref.setSelectedOption;
  return /*#__PURE__*/jsx(Radio, {
    stacked: true,
    containerClassName: "w-full flex flex-col gap-y-4",
    name: "options",
    children: Object.entries(options).map(function (_ref2) {
      var _ref3 = _slicedToArray(_ref2, 2),
        key = _ref3[0],
        _ref3$ = _ref3[1],
        label = _ref3$.label,
        description = _ref3$.description;
      return /*#__PURE__*/jsxs("label", {
        className: "neeto-ui-border-gray-300 neeto-ui-bg-white neeto-ui-rounded-lg w-full cursor-pointer border p-4",
        "data-cy": "".concat(key, "-embed-option-label"),
        "data-testid": "".concat(key, "-embed-option-label"),
        htmlFor: key,
        children: [/*#__PURE__*/jsx("div", {
          className: "flex items-center",
          children: /*#__PURE__*/jsx(Radio.Item, {
            label: label,
            checked: key === selectedOption,
            className: "mb-0",
            "data-cy": "".concat(key, "-embed-radio-button"),
            "data-testid": "".concat(key, "-embed-radio-button"),
            id: key,
            name: "options",
            value: key,
            onChange: function onChange(event) {
              return setSelectedOption(event.target.value);
            }
          })
        }), /*#__PURE__*/jsx(Typography, {
          className: "w-full pl-6 pt-1",
          "data-cy": "".concat(key, "-embed-option-description"),
          style: "body2",
          children: description
        })]
      }, key);
    })
  });
};

var ElementPopup = function ElementPopup(_ref) {
  var iframeURL = _ref.iframeURL,
    customization = _ref.customization;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var elementSelector = customization.elementSelector;
  useEffect(function () {
    var element = document.getElementById(elementSelector);
    if (element) {
      var _window$globalProps$a;
      (_window$globalProps$a = window[globalProps.appName.replace(/^neeto/i, "neeto")]) === null || _window$globalProps$a === void 0 || _window$globalProps$a.embed(element, iframeURL);
    }
  }, []);
  return /*#__PURE__*/jsx("div", {
    className: "relative flex h-full w-full items-center justify-center p-6",
    children: /*#__PURE__*/jsx(Button, {
      "data-cy": "preview-element-popup-button",
      "data-testid": "preview-element-popup-button",
      id: elementSelector,
      label: t("neetoMolecules.productEmbed.customization.elementPopup.label")
    })
  });
};

var FloatingPopup = function FloatingPopup(_ref) {
  var iframeURL = _ref.iframeURL,
    customization = _ref.customization;
  var btnTextColor = customization.btnTextColor,
    showIcon = customization.showIcon,
    btnText = customization.btnText,
    btnPosition = customization.btnPosition,
    btnColor = customization.btnColor,
    icon = customization.icon;
  useEffect(function () {
    var _window$globalProps$a;
    var btn = document.getElementById("embedBtn");
    (_window$globalProps$a = window[globalProps.appName.replace(/^neeto/i, "neeto")]) === null || _window$globalProps$a === void 0 || _window$globalProps$a.embed(btn, iframeURL);
  }, []);
  useEffect(function () {
    var btn = document.getElementById("embedBtn");
    btn.style.backgroundColor = btnColor;
    btn.style.color = btnTextColor;
  }, [btnColor, btnTextColor]);
  return /*#__PURE__*/jsx("div", {
    className: "relative h-full w-full",
    children: /*#__PURE__*/jsx(Button, {
      "data-cy": "popup-preview-button",
      icon: icon && showIcon ? icon : null,
      iconPosition: "left",
      id: "embedBtn",
      label: btnText,
      className: classnames("absolute bottom-0 m-4", {
        "left-0": btnPosition === "bottomLeft",
        "right-0": btnPosition === "bottomRight"
      })
    })
  });
};

var Inline = function Inline(_ref) {
  var iframeURL = _ref.iframeURL,
    customization = _ref.customization;
  var height = customization.height,
    width = customization.width;
  return /*#__PURE__*/jsx("iframe", {
    className: "m-auto",
    height: "".concat(height, "%"),
    src: iframeURL,
    width: "".concat(width, "%")
  });
};

var Preview = function Preview(_ref) {
  var isScriptLoading = _ref.isScriptLoading,
    selectedOption = _ref.selectedOption,
    id = _ref.id,
    customization = _ref.customization,
    _ref$customPreviewIfr = _ref.customPreviewIframeUrl,
    customPreviewIframeUrl = _ref$customPreviewIfr === void 0 ? "" : _ref$customPreviewIfr;
  var preview = _defineProperty(_defineProperty(_defineProperty({}, EMBED_OPTIONS.INLINE, Inline), EMBED_OPTIONS.FLOATING_POPUP, FloatingPopup), EMBED_OPTIONS.ELEMENT_POPUP, ElementPopup);
  var iframeURL = customPreviewIframeUrl || "".concat(location.origin, "/embed/").concat(id);
  var Component = preview[selectedOption];
  if (isScriptLoading) {
    return /*#__PURE__*/jsx("div", {
      className: "flex min-h-0 flex-grow items-center justify-center overflow-y-auto",
      children: /*#__PURE__*/jsx(Spinner, {})
    });
  }
  return /*#__PURE__*/jsx(BrowserPreview, {
    className: "h-full",
    wrapperClassName: "neeto-molecules-embed__browser-preview pointer-events-auto",
    children: /*#__PURE__*/jsx(Component, {
      customization: customization,
      iframeURL: iframeURL
    })
  });
};

var css = ".neeto-molecules-product-embed-size-input.neeto-ui-input__wrapper .neeto-ui-input__prefix{align-self:stretch;background-color:rgb(var(--neeto-ui-gray-200));margin-left:0!important;padding-left:.75rem;padding-right:.75rem}.neeto-molecules-product-embed-tab{gap:.5rem}.neeto-molecules-product-embed-tab .neeto-ui-tab{border-radius:var(--neeto-ui-btn-border-radius);color:rgb(var(--neeto-ui-gray-800))}.neeto-molecules-product-embed-tab .neeto-ui-tab:not(.active):hover{background-color:rgb(var(--neeto-ui-gray-100))}.neeto-molecules-product-embed-tab .neeto-ui-tab.active{background-color:rgb(var(--neeto-ui-gray-200))}.neeto-molecules-embed__left-sidebar{align-items:flex-start;display:flex;flex-direction:column;flex-shrink:0;overflow-y:auto;padding:1.5rem;width:100%}@media (min-width:768px){.neeto-molecules-embed__left-sidebar{border-right:1px solid rgb(var(--neeto-ui-gray-200));max-width:25rem}}@media (min-width:1024px){.neeto-molecules-embed__left-sidebar{max-width:27.5rem}}.neeto-molecules-embed__code-block .neeto-molecules-code-block{font-size:.875rem;height:15.625rem;margin-top:0!important}.neeto-molecules-embed__browser-preview{height:100%;min-height:18.75rem}.neeto-molecules-embed__browser-preview .neeto-molecules-browser-preview__body{position:relative}.neeto-molecules-embed__browser-preview .neeto-molecules-browser-preview__body iframe{height:100%;left:0;position:absolute;top:0;width:100%}";
n(css,{});

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var ProductEmbed = function ProductEmbed(_ref) {
  var _ref$className = _ref.className,
    className = _ref$className === void 0 ? "" : _ref$className,
    _ref$customEmbedScrip = _ref.customEmbedScriptPath,
    customEmbedScriptPath = _ref$customEmbedScrip === void 0 ? "" : _ref$customEmbedScrip,
    _ref$customPreviewIfr = _ref.customPreviewIframeUrl,
    customPreviewIframeUrl = _ref$customPreviewIfr === void 0 ? "" : _ref$customPreviewIfr,
    _ref$goBackLink = _ref.goBackLink,
    goBackLink = _ref$goBackLink === void 0 ? "" : _ref$goBackLink,
    id = _ref.id,
    _ref$isQueryParamsEna = _ref.isQueryParamsEnabled,
    isQueryParamsEnabled = _ref$isQueryParamsEna === void 0 ? false : _ref$isQueryParamsEna,
    _ref$options = _ref.options,
    options = _ref$options === void 0 ? {} : _ref$options,
    _ref$extraArgs = _ref.extraArgs,
    extraArgs = _ref$extraArgs === void 0 ? {} : _ref$extraArgs,
    _ref$otherCustomizati = _ref.otherCustomizations,
    otherCustomizations = _ref$otherCustomizati === void 0 ? noop : _ref$otherCustomizati,
    _ref$inlineWrapperSty = _ref.inlineWrapperStyle,
    inlineWrapperStyle = _ref$inlineWrapperSty === void 0 ? "" : _ref$inlineWrapperSty,
    _ref$supportedLanguag = _ref.supportedLanguages,
    supportedLanguages = _ref$supportedLanguag === void 0 ? ["html"] : _ref$supportedLanguag;
  var supportedLanguagesTabs = filterBy({
    key: function key(_key) {
      return supportedLanguages === null || supportedLanguages === void 0 ? void 0 : supportedLanguages.includes(_key);
    }
  }, TABS);
  var _useState = useState(true),
    _useState2 = _slicedToArray(_useState, 2),
    isScriptLoading = _useState2[0],
    setIsScriptLoading = _useState2[1];
  var _useState3 = useState(supportedLanguagesTabs[0].key),
    _useState4 = _slicedToArray(_useState3, 2),
    tab = _useState4[0],
    setTab = _useState4[1];
  var _useState5 = useState(EMBED_OPTIONS.INLINE),
    _useState6 = _slicedToArray(_useState5, 2),
    selectedOption = _useState6[0],
    setSelectedOption = _useState6[1];
  var _useState7 = useState(function () {
      return buildDefaultCustomization(options);
    }),
    _useState8 = _slicedToArray(_useState7, 2),
    customizations = _useState8[0],
    setCustomizations = _useState8[1];
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var embedScriptLink = customEmbedScriptPath || "".concat(window.location.protocol, "//").concat(window.location.host, "/javascript/embed.js");
  var code = generateCode({
    id: id,
    tab: tab,
    type: selectedOption,
    customization: customizations[selectedOption],
    embedScriptLink: embedScriptLink,
    extraArgs: extraArgs,
    inlineWrapperStyle: inlineWrapperStyle
  });
  var loadScript = function loadScript() {
    var script = document.createElement("script");
    script.id = SCRIPT_ID;
    script.src = embedScriptLink;
    document.head.appendChild(script);
    setIsScriptLoading(false);
  };
  var updateCustomization = function updateCustomization(props) {
    return setCustomizations(function (prevState) {
      return _objectSpread(_objectSpread({}, prevState), {}, _defineProperty({}, selectedOption, mergeLeft(props, prevState[selectedOption])));
    });
  };
  useEffect(function () {
    var isScriptLoaded = document.getElementById(SCRIPT_ID);
    if (isScriptLoaded) setIsScriptLoading(false);else loadScript();
  }, []);
  return /*#__PURE__*/jsxs("div", {
    "data-testid": "embed-product",
    className: classnames("neeto-molecules-embed flex w-full flex-grow flex-col md:flex-row", className),
    children: [/*#__PURE__*/jsxs("div", {
      className: "neeto-molecules-embed__left-sidebar",
      children: [goBackLink && /*#__PURE__*/jsx(Button, {
        className: "mb-4",
        "data-cy": "back-button",
        "data-testid": "back-button",
        icon: LeftArrow,
        iconPosition: "left",
        label: t("neetoMolecules.productEmbed.backToShare"),
        size: "small",
        style: "link",
        to: goBackLink
      }), /*#__PURE__*/jsx(Typography, {
        "data-cy": "embed-options-header-title",
        style: "h3",
        children: t("neetoMolecules.productEmbed.embedOptions.title")
      }), /*#__PURE__*/jsxs("div", {
        className: "mt-6 flex w-full flex-col gap-y-6 md:pb-20",
        children: [/*#__PURE__*/jsx(Options, {
          options: options,
          selectedOption: selectedOption,
          setSelectedOption: setSelectedOption
        }), /*#__PURE__*/jsx(Customization, {
          isQueryParamsEnabled: isQueryParamsEnabled,
          otherCustomizations: otherCustomizations,
          updateCustomization: updateCustomization,
          customization: customizations[selectedOption],
          option: selectedOption
        })]
      })]
    }), /*#__PURE__*/jsxs("div", {
      className: "neeto-molecules-embed__preview neeto-ui-bg-white flex min-h-screen w-full min-w-0 flex-col gap-3 overflow-y-auto p-6 md:min-h-0 md:flex-grow",
      children: [/*#__PURE__*/jsx(Header, {
        setTab: setTab,
        supportedLanguagesTabs: supportedLanguagesTabs,
        tab: tab
      }), /*#__PURE__*/jsxs("div", {
        className: "flex min-h-0 flex-grow flex-col gap-3",
        children: [/*#__PURE__*/jsx("div", {
          className: "flex-shrink-0",
          "data-testid": "embed-code-block",
          children: /*#__PURE__*/jsx(Code, {
            code: code,
            tab: tab
          })
        }), /*#__PURE__*/jsx("div", {
          className: "flex-grow",
          children: /*#__PURE__*/jsx(Preview, {
            customPreviewIframeUrl: customPreviewIframeUrl,
            id: id,
            isScriptLoading: isScriptLoading,
            selectedOption: selectedOption,
            customization: customizations[selectedOption]
          })
        })]
      })]
    })]
  });
};

export { ProductEmbed as default };
//# sourceMappingURL=ProductEmbed.js.map
