import _defineProperty from '@babel/runtime/helpers/defineProperty';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import { isNotEmpty } from '@bigbinary/neeto-cist';
import Pane from '@bigbinary/neetoui/Pane';
import Typography from '@bigbinary/neetoui/Typography';
import Spinner from '@bigbinary/neetoui/Spinner';
import { useTranslation } from 'react-i18next';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import { useState, useEffect } from 'react';
import { buildUrl } from '@bigbinary/neeto-commons-frontend/utils';
import Input from '@bigbinary/neetoui/Input';
import Checkbox from '@bigbinary/neetoui/Checkbox';
import Tooltip from '@bigbinary/neetoui/Tooltip';
import { not } from 'ramda';
import CopyToClipboardButton from './CopyToClipboardButton.js';
import { jsxs, Fragment, jsx } from 'react/jsx-runtime';
import 'classnames';
import '@bigbinary/neeto-commons-frontend/utils/general';
import '@bigbinary/neeto-icons/Copy';
import '@bigbinary/neeto-icons/Check';
import '@bigbinary/neetoui/Button';
import './inject-css-DmrvuTKK.js';

var ONE_SECOND = 1;
var ONE_MINUTE = 60 * ONE_SECOND;
var ONE_HOUR = 60 * ONE_MINUTE;

var padZero = function padZero(number) {
  var length = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 2;
  var string = String(number);
  var threshold = Math.pow(10, length - 1);
  if (number < threshold) {
    while (String(threshold).length > string.length) {
      string = "0".concat(number);
    }
  }
  return string;
};
var shouldRenderHoursInput = function shouldRenderHoursInput(duration) {
  var hours = Math.floor(duration / ONE_HOUR);
  return hours > 0;
};
var formatTime = function formatTime(timeInSeconds, showHours) {
  var hours = Math.floor(timeInSeconds / ONE_HOUR);
  var minutes = Math.floor(timeInSeconds % ONE_HOUR / ONE_MINUTE);
  var seconds = timeInSeconds % ONE_MINUTE;
  return showHours ? "".concat(padZero(hours), ":").concat(padZero(minutes), ":").concat(padZero(seconds)) : "".concat(padZero(minutes), ":").concat(padZero(seconds));
};
var parseTime = function parseTime(timeString) {
  var parts = timeString.split(":").map(function (part) {
    return part === "" ? NaN : parseInt(part, 10);
  });
  if (parts.some(isNaN) || parts.length > 3) {
    return 0;
  }
  if (parts.length === 1) {
    return parts[0];
  } else if (parts.length === 2) {
    return parts[0] * ONE_MINUTE + parts[1];
  } else if (parts.length === 3) {
    return parts[0] * ONE_HOUR + parts[1] * ONE_MINUTE + parts[2];
  }
  return 0;
};
var validateInput = function validateInput(input) {
  var regex = /^[0-9:]{0,8}$/;
  var colons = (input.match(/:/g) || []).length;
  return regex.test(input) && colons <= 2;
};

function ownKeys$1(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$1(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$1(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$1(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var SharePaneBody = function SharePaneBody(_ref) {
  var recordingUrls = _ref.recordingUrls,
    totalDuration = _ref.totalDuration,
    getCurrentTimestamp = _ref.getCurrentTimestamp,
    isOpen = _ref.isOpen;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var currentTimestamp = getCurrentTimestamp();
  var _useState = useState([]),
    _useState2 = _slicedToArray(_useState, 2),
    shareLinks = _useState2[0],
    setShareLinks = _useState2[1];
  var _useState3 = useState(currentTimestamp),
    _useState4 = _slicedToArray(_useState3, 2),
    currentPlaybackTime = _useState4[0],
    setCurrentPlaybackTime = _useState4[1];
  var _useState5 = useState(""),
    _useState6 = _slicedToArray(_useState5, 2),
    rawInput = _useState6[0],
    setRawInput = _useState6[1];
  var _useState7 = useState(currentTimestamp > 0),
    _useState8 = _slicedToArray(_useState7, 2),
    isPlaybackTimeCheckboxChecked = _useState8[0],
    setIsPlaybackTimeCheckboxChecked = _useState8[1];
  var showHours = shouldRenderHoursInput(totalDuration);
  var handlePlaybackTimestampChange = function handlePlaybackTimestampChange(e) {
    var input = e.target.value;
    if (validateInput(input)) {
      setRawInput(input);
    }
  };
  var formatAndSetTime = function formatAndSetTime() {
    var timeInSeconds = parseTime(rawInput);
    if (timeInSeconds > totalDuration) {
      timeInSeconds = totalDuration;
    }
    setCurrentPlaybackTime(timeInSeconds);
    setRawInput(formatTime(timeInSeconds, showHours));
  };
  var handleKeyDown = function handleKeyDown(e) {
    if (!(e.key === "Enter")) return;
    formatAndSetTime();
  };
  useEffect(function () {
    if (not(isOpen)) return;
    setIsPlaybackTimeCheckboxChecked(currentTimestamp > 0);
    setCurrentPlaybackTime(currentTimestamp > 0 ? currentTimestamp : 0);
    setRawInput(formatTime(currentTimestamp > 0 ? currentTimestamp : 0, showHours));
  }, [isOpen, showHours, currentTimestamp]);
  useEffect(function () {
    var playbackUrls = recordingUrls.map(function (recordingUrl) {
      return buildUrl(recordingUrl, _objectSpread$1({}, isPlaybackTimeCheckboxChecked && currentPlaybackTime > 0 && {
        time: currentPlaybackTime
      }));
    });
    setShareLinks(playbackUrls);
  }, [recordingUrls, isPlaybackTimeCheckboxChecked, currentPlaybackTime]);
  return /*#__PURE__*/jsxs(Fragment, {
    children: [shareLinks.map(function (shareLink, index) {
      return /*#__PURE__*/jsxs("div", {
        className: "neeto-ui-bg-gray-100 neeto-ui-rounded-lg mb-2 flex w-full items-center justify-between gap-1 p-2",
        children: [/*#__PURE__*/jsx(Tooltip, {
          content: shareLink,
          children: /*#__PURE__*/jsx(Typography, {
            className: "truncate",
            style: "body2",
            children: shareLink
          })
        }), /*#__PURE__*/jsx(CopyToClipboardButton, {
          className: "flex-shrink-0",
          style: "secondary",
          value: shareLink
        })]
      }, index);
    }), /*#__PURE__*/jsxs("div", {
      className: "flex items-center gap-x-2",
      children: [/*#__PURE__*/jsx(Checkbox, {
        checked: isPlaybackTimeCheckboxChecked,
        className: "grow-0",
        "data-cy": "time-checkbox",
        label: t("neetoMolecules.shareRecording.checkboxLabel"),
        onChange: function onChange(_ref2) {
          var checked = _ref2.target.checked;
          return setIsPlaybackTimeCheckboxChecked(checked);
        }
      }), /*#__PURE__*/jsx(Input, {
        className: "w-40",
        "data-cy": "time-input",
        disabled: not(isPlaybackTimeCheckboxChecked),
        placeholder: showHours ? "HH:MM:SS" : "MM:SS",
        value: rawInput,
        onBlur: formatAndSetTime,
        onChange: handlePlaybackTimestampChange,
        onKeyDown: handleKeyDown
      })]
    })]
  });
};

var _excluded = ["recordingUrl", "recordingUrls", "totalDuration", "getCurrentTimestamp", "isOpen", "onClose", "isLoading"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var ShareRecordingPane = function ShareRecordingPane(_ref) {
  var _ref$recordingUrl = _ref.recordingUrl,
    recordingUrl = _ref$recordingUrl === void 0 ? null : _ref$recordingUrl,
    _ref$recordingUrls = _ref.recordingUrls,
    recordingUrls = _ref$recordingUrls === void 0 ? [] : _ref$recordingUrls,
    totalDuration = _ref.totalDuration,
    getCurrentTimestamp = _ref.getCurrentTimestamp,
    isOpen = _ref.isOpen,
    onClose = _ref.onClose,
    _ref$isLoading = _ref.isLoading,
    isLoading = _ref$isLoading === void 0 ? false : _ref$isLoading,
    otherProps = _objectWithoutProperties(_ref, _excluded);
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var recordingUrlsToShare = isNotEmpty(recordingUrls) ? recordingUrls : [recordingUrl];
  return /*#__PURE__*/jsxs(Pane, _objectSpread(_objectSpread({}, _objectSpread({
    isOpen: isOpen,
    onClose: onClose
  }, otherProps)), {}, {
    "data-cy": "share-pane",
    size: "large",
    children: [/*#__PURE__*/jsx(Pane.Header, {
      children: /*#__PURE__*/jsx(Typography, {
        style: "h2",
        children: t("neetoMolecules.shareRecording.title")
      })
    }), /*#__PURE__*/jsx(Pane.Body, {
      className: "flex flex-col space-y-2",
      children: isLoading ? /*#__PURE__*/jsx(Spinner, {
        className: "mx-auto"
      }) : /*#__PURE__*/jsx(SharePaneBody, {
        getCurrentTimestamp: getCurrentTimestamp,
        isOpen: isOpen,
        totalDuration: totalDuration,
        recordingUrls: recordingUrlsToShare
      })
    })]
  }));
};

export { ShareRecordingPane as default };
//# sourceMappingURL=ShareRecordingPane.js.map
