import { isPresent, slugify, noop } from '@bigbinary/neeto-cist';
import { omit } from 'ramda';
import classnames from 'classnames';
import Typography from '@bigbinary/neetoui/Typography';
import { useTranslation, Trans } from 'react-i18next';
import { jsx, jsxs, Fragment } from 'react/jsx-runtime';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import React__default, { useRef, useCallback, useEffect, useState, createElement } from 'react';
import ExternalLink from '@bigbinary/neeto-icons/ExternalLink';
import Button from '@bigbinary/neetoui/Button';
import CopyToClipboardButton from './CopyToClipboardButton.js';
import MoreDropdown from './MoreDropdown.js';
import { Formik, Form } from 'formik';
import Pane from '@bigbinary/neetoui/Pane';
import Input from '@bigbinary/neetoui/formik/Input';
import ActionBlock from '@bigbinary/neetoui/formik/ActionBlock';
import { t } from 'i18next';
import Facebook from '@bigbinary/neeto-icons/Facebook';
import Linkedin from '@bigbinary/neeto-icons/Linkedin';
import Twitter from '@bigbinary/neeto-icons/Twitter';
import * as yup from 'yup';
import { buildUrl } from '@bigbinary/neeto-commons-frontend/utils/general';
import { n } from './inject-css-DmrvuTKK.js';
import { dayjs } from '@bigbinary/neeto-commons-frontend/utils';
import Help from '@bigbinary/neeto-icons/Help';
import Modal from '@bigbinary/neetoui/Modal';
import Input$1 from '@bigbinary/neetoui/Input';
import Select from '@bigbinary/neetoui/Select';
import DatePicker from '@bigbinary/neetoui/DatePicker';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { Link as Link$1 } from 'react-router-dom';
import '@babel/runtime/helpers/objectWithoutProperties';
import '@bigbinary/neeto-icons/Copy';
import '@bigbinary/neeto-icons/Check';
import '@bigbinary/neeto-icons/MenuHorizontal';
import '@bigbinary/neeto-icons/MenuVertical';
import '@bigbinary/neetoui/Dropdown';
import '@bigbinary/neetoui/Tooltip';

var ExpiryNotice = function ExpiryNotice(_ref) {
  var expiryConfiguration = _ref.expiryConfiguration;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var daysBeforeExpiry = expiryConfiguration.daysBeforeExpiry;
  var notice = t("neetoMolecules.shareViaLink.expiryNotice.daysRemaining", {
    count: daysBeforeExpiry
  });
  if (daysBeforeExpiry < 1) {
    notice = t("neetoMolecules.shareViaLink.expiryNotice.expiresToday");
  }
  if (daysBeforeExpiry <= 0) {
    notice = t("neetoMolecules.shareViaLink.expiryNotice.expired");
  }
  return /*#__PURE__*/jsx(Typography, {
    "data-testid": "expiry-notice",
    lineHeight: "normal",
    style: "body3",
    className: classnames("ml-1", {
      "neeto-ui-text-error-800": daysBeforeExpiry <= 1,
      "neeto-ui-text-gray-700": daysBeforeExpiry > 1
    }),
    children: notice
  });
};

var facebookShareLink = function facebookShareLink(_ref) {
  var url = _ref.url;
  return buildUrl("https://www.facebook.com/sharer/sharer.php", {
    u: url
  });
};
var linkedInShareLink = function linkedInShareLink(_ref2) {
  var url = _ref2.url,
    title = _ref2.title;
  return buildUrl("https://www.linkedin.com/sharing/share-offsite", {
    mini: true,
    text: "".concat(title, " ").concat(url)
  });
};
var twitterShareLink = function twitterShareLink(_ref3) {
  var url = _ref3.url,
    title = _ref3.title;
  return buildUrl("http://twitter.com/share", {
    text: title,
    url: url
  });
};
var downloadCanvas = function downloadCanvas(canvas) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var _options$name = options.name,
    name = _options$name === void 0 ? "image" : _options$name,
    _options$extension = options.extension,
    extension = _options$extension === void 0 ? "png" : _options$extension;
  var canvasUrl = canvas.toDataURL("image/".concat(extension));
  var element = document.createElement("a");
  element.href = canvasUrl;
  element.download = "".concat(name, ".").concat(extension);
  element.click();
  element.remove();
};
var getPathname = function getPathname(url) {
  return new URL(url).pathname.slice(1);
};
var getPrefixFromUrl = function getPrefixFromUrl(url) {
  return "".concat(new URL(url).origin, "/");
};
var truncatePrefix = function truncatePrefix(inputElement, prefixText) {
  var parentElement = inputElement.parentElement;
  var prefixElement = parentElement.querySelector(".neeto-ui-input__prefix");
  var _getComputedStyle = getComputedStyle(inputElement),
    fontSize = _getComputedStyle.fontSize;
  var averageCharWidth = parseFloat(fontSize) * 0.6;
  var requiredInputWidth = inputElement.value.length * averageCharWidth;
  var prefixWidth = parentElement.offsetWidth - requiredInputWidth;
  var maxPrefixChars = Math.max(Math.floor(prefixWidth / averageCharWidth), 5);
  prefixElement.textContent = maxPrefixChars < prefixText.length ? "...".concat(prefixText.slice(-maxPrefixChars)) : prefixText;
};

var SOCIAL_MEDIA_OPTIONS = {
  FACEBOOK: {
    label: t("neetoMolecules.shareViaLink.socialMediaShare.facebook"),
    icon: Facebook,
    generateShareUrl: facebookShareLink
  },
  LINKEDIN: {
    label: t("neetoMolecules.shareViaLink.socialMediaShare.linkedIn"),
    icon: Linkedin,
    generateShareUrl: linkedInShareLink
  },
  TWITTER: {
    label: t("neetoMolecules.shareViaLink.socialMediaShare.twitter"),
    icon: Twitter,
    generateShareUrl: twitterShareLink
  }
};
var PATH_VALIDATION_SCHEMA = yup.object().shape({
  path: yup.string().required(t("neetoMolecules.shareViaLink.editUrl.validationError")).matches(/^[A-Za-z0-9]([\w/-])*$/, t("neetoMolecules.shareViaLink.editUrl.validationError"))
});

var css = ".no-padding .neeto-ui-input.neeto-ui-input--medium input{padding:0}.no-padding .neeto-ui-input__prefix{color:rgb(var(--neeto-ui-gray-600))!important}";
n(css,{});

var Header = Pane.Header,
  Body = Pane.Body,
  Footer = Pane.Footer;
var EditURL = function EditURL(_ref) {
  var editUrlProps = _ref.editUrlProps,
    isOpen = _ref.isOpen,
    onClose = _ref.onClose,
    url = _ref.url,
    isLoading = _ref.isLoading,
    handleEdit = _ref.handleEdit;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var focusRef = useRef(null);
  var prevIsLoadingRef = useRef(isLoading);
  var prefixText = (editUrlProps === null || editUrlProps === void 0 ? void 0 : editUrlProps.prefix) || getPrefixFromUrl(url);
  var observerRef = useRef(new ResizeObserver(function (_ref2) {
    var _ref3 = _slicedToArray(_ref2, 1),
      entry = _ref3[0];
    return requestAnimationFrame(function () {
      return truncatePrefix(entry.target, prefixText);
    });
  }));
  var inputRef = useCallback(function (inputElement) {
    focusRef.current = inputElement;
    inputElement ? observerRef.current.observe(inputElement) : observerRef.current.disconnect();
  }, []);
  useEffect(function () {
    if (prevIsLoadingRef.current && !isLoading) onClose();
    prevIsLoadingRef.current = isLoading;
  }, [isLoading]);
  return /*#__PURE__*/jsxs(Pane, {
    isOpen: isOpen,
    onClose: onClose,
    "data-testid": "edit-url-modal",
    initialFocusRef: focusRef,
    size: "large",
    children: [/*#__PURE__*/jsx(Header, {
      children: /*#__PURE__*/jsx(Typography, {
        lineHeight: "normal",
        style: "h2",
        weight: "semibold",
        children: t("neetoMolecules.shareViaLink.editUrl.title")
      })
    }), /*#__PURE__*/jsx(Formik, {
      enableReinitialize: true,
      initialValues: {
        path: (editUrlProps === null || editUrlProps === void 0 ? void 0 : editUrlProps.editablePath) || getPathname(url)
      },
      validationSchema: PATH_VALIDATION_SCHEMA,
      onSubmit: function onSubmit(_ref4) {
        var path = _ref4.path;
        return handleEdit(path);
      },
      children: function children(_ref5) {
        var isSubmitting = _ref5.isSubmitting,
          dirty = _ref5.dirty;
        return /*#__PURE__*/jsxs(Form, {
          children: [/*#__PURE__*/jsxs(Body, {
            className: "space-y-6",
            children: [/*#__PURE__*/jsx(Input, {
              className: "no-padding w-full flex-grow-0",
              "data-testid": "edit-url-input",
              label: t("neetoMolecules.shareViaLink.editUrl.inputLabel"),
              maxLength: editUrlProps === null || editUrlProps === void 0 ? void 0 : editUrlProps.maxLength,
              name: "path",
              prefix: prefixText,
              ref: inputRef
            }), /*#__PURE__*/jsx(Typography, {
              className: "neeto-ui-text-gray-700",
              lineHeight: "normal",
              style: "body2",
              children: t("neetoMolecules.shareViaLink.editUrl.description")
            })]
          }), /*#__PURE__*/jsx(Footer, {
            className: "space-x-2",
            children: /*#__PURE__*/jsx(ActionBlock, {
              className: "flex items-center space-x-2",
              cancelButtonProps: {
                onClick: onClose,
                disabled: isSubmitting,
                "data-testid": "edit-url-cancel-button"
              },
              submitButtonProps: {
                disabled: isSubmitting || !dirty,
                loading: isLoading,
                "data-testid": "edit-url-confirm-button"
              }
            })
          })]
        });
      }
    })]
  });
};

var RegenerateURL = function RegenerateURL(_ref) {
  var _regenerateConfig$exp, _regenerateConfig$exp2, _globalProps$user$dat, _globalProps;
  var isOpen = _ref.isOpen,
    onClose = _ref.onClose,
    url = _ref.url,
    isLoading = _ref.isLoading,
    handleRegenerate = _ref.handleRegenerate,
    _ref$regenerateConfig = _ref.regenerateConfig,
    regenerateConfig = _ref$regenerateConfig === void 0 ? {
      expiresInOptions: [],
      helpUrl: null
    } : _ref$regenerateConfig;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var prevIsLoadingRef = useRef(isLoading);
  var regenerateStrategy = isPresent(regenerateConfig === null || regenerateConfig === void 0 ? void 0 : regenerateConfig.expiresInOptions) ? "expiryBased" : "basic";
  var defaultExpiresInOption = regenerateConfig === null || regenerateConfig === void 0 || (_regenerateConfig$exp = regenerateConfig.expiresInOptions) === null || _regenerateConfig$exp === void 0 || (_regenerateConfig$exp = _regenerateConfig$exp[0]) === null || _regenerateConfig$exp === void 0 ? void 0 : _regenerateConfig$exp.value;
  var _useState = useState(defaultExpiresInOption),
    _useState2 = _slicedToArray(_useState, 2),
    selectedExpiresInOption = _useState2[0],
    setSelectedExpiresInOption = _useState2[1];
  var defaultExpiresOnDate = dayjs().add(10, "day").toDate();
  var _useState3 = useState(defaultExpiresOnDate),
    _useState4 = _slicedToArray(_useState3, 2),
    selectedExpiresOnDate = _useState4[0],
    setSelectedExpiresOnDate = _useState4[1];
  var isSelectedExpiresInOptionNever = selectedExpiresInOption === "never";
  var isSelectedExpiresInOptionCustom = selectedExpiresInOption === "custom";
  var isSelectedExpiresInOptionValidNumberOfDays = isPresent(selectedExpiresInOption) && !isSelectedExpiresInOptionCustom && !isSelectedExpiresInOptionNever;
  var isValidExpiryConfig = isSelectedExpiresInOptionNever || isSelectedExpiresInOptionCustom && isPresent(selectedExpiresOnDate) || isSelectedExpiresInOptionValidNumberOfDays;
  var expiryConfigPayload = isSelectedExpiresInOptionValidNumberOfDays ? {
    expiresInDays: selectedExpiresInOption
  } : {
    expiresOnDate: selectedExpiresOnDate
  };
  var onSubmit = function onSubmit() {
    return regenerateStrategy === "basic" || isSelectedExpiresInOptionNever ? handleRegenerate() : handleRegenerate({
      payload: expiryConfigPayload
    });
  };
  useEffect(function () {
    if (prevIsLoadingRef.current && !isLoading) onClose();
    prevIsLoadingRef.current = isLoading;
  }, [isLoading]);
  useEffect(function () {
    if (!isOpen) return;
    setSelectedExpiresInOption(defaultExpiresInOption);
    setSelectedExpiresOnDate(defaultExpiresOnDate);
  }, [isOpen]);
  return /*#__PURE__*/jsxs(Modal, {
    isOpen: isOpen,
    onClose: onClose,
    "data-testid": "regenerate-url-modal",
    size: regenerateStrategy === "basic" ? "medium" : "large",
    children: [/*#__PURE__*/jsx(Modal.Header, {
      children: /*#__PURE__*/jsx(Typography, {
        lineHeight: "normal",
        style: "h2",
        weight: "semibold",
        children: regenerateStrategy === "expiryBased" ? t("neetoMolecules.shareViaLink.regenerateUrl.titleForExpiryBasedRegeneration") : t("neetoMolecules.shareViaLink.regenerateUrl.title")
      })
    }), /*#__PURE__*/jsx(Modal.Body, {
      children: /*#__PURE__*/jsxs("div", {
        className: "w-full space-y-6",
        children: [regenerateStrategy === "basic" && /*#__PURE__*/jsx(Input$1, {
          disabled: true,
          label: t("neetoMolecules.shareViaLink.regenerateUrl.inputLabel"),
          value: url
        }), regenerateStrategy === "expiryBased" && /*#__PURE__*/jsxs("div", {
          className: "flex flex-row gap-2",
          children: [/*#__PURE__*/jsx(Select, {
            "data-testid": "expires-in-select",
            defaultValue: (_regenerateConfig$exp2 = regenerateConfig.expiresInOptions) === null || _regenerateConfig$exp2 === void 0 ? void 0 : _regenerateConfig$exp2[0],
            options: regenerateConfig.expiresInOptions,
            className: classnames({
              "w-1/2": isSelectedExpiresInOptionCustom,
              "w-full": !isSelectedExpiresInOptionCustom
            }),
            label: t("neetoMolecules.shareViaLink.regenerateUrl.expiresInLabel"),
            labelProps: {
              helpIconProps: isPresent(regenerateConfig === null || regenerateConfig === void 0 ? void 0 : regenerateConfig.helpUrl) && {
                icon: Help,
                className: "cursor-pointer opacity-75 hover:opacity-100 transition-opacity duration-300 ease-in-out",
                popoverProps: {
                  title: t("neetoMolecules.shareViaLink.regenerateUrl.expiresInHelpTitle"),
                  helpLinkProps: {
                    label: t("neetoMolecules.shareViaLink.regenerateUrl.helpLinkLabel"),
                    href: regenerateConfig === null || regenerateConfig === void 0 ? void 0 : regenerateConfig.helpUrl,
                    target: "_blank"
                  }
                }
              }
            },
            onChange: function onChange(option) {
              return setSelectedExpiresInOption(option.value);
            }
          }), isSelectedExpiresInOptionCustom && /*#__PURE__*/jsx(DatePicker, {
            "data-testid": "expires-on-date-picker",
            dateFormat: (_globalProps$user$dat = (_globalProps = globalProps) === null || _globalProps === void 0 || (_globalProps = _globalProps.user) === null || _globalProps === void 0 ? void 0 : _globalProps.dateFormat) !== null && _globalProps$user$dat !== void 0 ? _globalProps$user$dat : undefined,
            disabledDate: function disabledDate(d) {
              return !d || d.isBefore(dayjs());
            },
            picker: "date",
            type: "date",
            value: selectedExpiresOnDate,
            label: t("neetoMolecules.shareViaLink.regenerateUrl.expiresOnLabel"),
            onChange: setSelectedExpiresOnDate
          })]
        }), /*#__PURE__*/jsx(Typography, {
          className: "neeto-ui-text-gray-700",
          lineHeight: "normal",
          style: "body2",
          children: t("neetoMolecules.shareViaLink.regenerateUrl.description")
        })]
      })
    }), /*#__PURE__*/jsxs(Modal.Footer, {
      className: "space-x-2",
      children: [/*#__PURE__*/jsx(Button, {
        "data-cy": "regenerate-url-confirm-button",
        "data-testid": "regenerate-url-confirm-button",
        loading: isLoading,
        disabled: regenerateStrategy === "expiryBased" && !isValidExpiryConfig,
        label: t("neetoMolecules.shareViaLink.regenerateUrl.submitButtonLabel"),
        onClick: onSubmit
      }), /*#__PURE__*/jsx(Button, {
        "data-cy": "regenerate-url-cancel-button",
        "data-testid": "regenerate-url-cancel-button",
        style: "text",
        label: t("neetoMolecules.shareViaLink.regenerateUrl.cancelButtonLabel"),
        onClick: onClose
      })]
    })]
  });
};

var Link = function Link(_ref) {
  var editUrlProps = _ref.editUrlProps,
    enabledOptions = _ref.enabledOptions,
    entityName = _ref.entityName,
    handleEdit = _ref.handleEdit,
    handleRegenerate = _ref.handleRegenerate,
    isLoading = _ref.isLoading,
    previewUrl = _ref.previewUrl,
    url = _ref.url;
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    isRegenerateURLModalOpen = _useState2[0],
    setIsRegenerateURLModalOpen = _useState2[1];
  var _useState3 = useState(false),
    _useState4 = _slicedToArray(_useState3, 2),
    isEditURLModalOpen = _useState4[0],
    setIsEditURLModalOpen = _useState4[1];
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var isDropdownEnabled = enabledOptions.regenerate || enabledOptions.edit;
  return /*#__PURE__*/jsx("div", {
    className: "space-y-4",
    "data-cy": "link-block",
    "data-testid": "link-block",
    children: /*#__PURE__*/jsxs("div", {
      className: "flex flex-col gap-2 sm:flex-row sm:items-center sm:gap-1",
      children: [/*#__PURE__*/jsx("div", {
        className: "neeto-ui-rounded-md neeto-ui-border-gray-200 relative min-w-0 flex-grow truncate border p-2 leading-none",
        "data-cy": "nui-input-field",
        children: url
      }), /*#__PURE__*/jsxs("div", {
        className: "flex w-full flex-shrink-0 items-center gap-1 sm:w-auto",
        children: [/*#__PURE__*/jsx(CopyToClipboardButton, {
          "data-cy": "link-copy-button",
          "data-testid": "link-copy-button",
          label: t("neetoMolecules.shareViaLink.copyLink"),
          value: url
        }), /*#__PURE__*/jsx(Button, {
          "data-cy": "preview-button",
          "data-testid": "preview-button",
          href: previewUrl || url,
          icon: ExternalLink,
          style: "secondary",
          target: "_blank",
          tooltipProps: {
            content: t("neetoMolecules.shareViaLink.view", {
              entity: entityName
            }),
            position: "top",
            touch: ["hold", 500]
          }
        }), isDropdownEnabled && /*#__PURE__*/jsxs(Fragment, {
          children: [/*#__PURE__*/jsx(MoreDropdown, {
            menuItems: [{
              isVisible: enabledOptions.regenerate || isPresent(enabledOptions.regenerate),
              "data-testid": "regenerate-url-button",
              "data-cy": "regenerate-url-button",
              onClick: function onClick() {
                return setIsRegenerateURLModalOpen(true);
              },
              label: t("neetoMolecules.shareViaLink.regenerateUrl.title"),
              key: "regenerate-url-option"
            }, {
              isVisible: enabledOptions.edit,
              "data-testid": "edit-url-button",
              "data-cy": "edit-url-button",
              onClick: function onClick() {
                return setIsEditURLModalOpen(true);
              },
              label: t("neetoMolecules.shareViaLink.editUrl.title"),
              key: "edit-url-option"
            }]
          }), /*#__PURE__*/jsx(RegenerateURL, {
            handleRegenerate: handleRegenerate,
            isLoading: isLoading,
            url: url,
            isOpen: isRegenerateURLModalOpen,
            regenerateConfig: enabledOptions.regenerate,
            onClose: function onClose() {
              return setIsRegenerateURLModalOpen(false);
            }
          }), /*#__PURE__*/jsx(EditURL, {
            editUrlProps: editUrlProps,
            handleEdit: handleEdit,
            isLoading: isLoading,
            url: url,
            isOpen: isEditURLModalOpen,
            onClose: function onClose() {
              return setIsEditURLModalOpen(false);
            }
          })]
        })]
      })]
    })
  });
};

var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};

// src/third-party/qrcodegen/index.ts
/**
 * @license QR Code generator library (TypeScript)
 * Copyright (c) Project Nayuki.
 * SPDX-License-Identifier: MIT
 */
var qrcodegen;
((qrcodegen2) => {
  const _QrCode = class {
    constructor(version, errorCorrectionLevel, dataCodewords, msk) {
      this.version = version;
      this.errorCorrectionLevel = errorCorrectionLevel;
      this.modules = [];
      this.isFunction = [];
      if (version < _QrCode.MIN_VERSION || version > _QrCode.MAX_VERSION)
        throw new RangeError("Version value out of range");
      if (msk < -1 || msk > 7)
        throw new RangeError("Mask value out of range");
      this.size = version * 4 + 17;
      let row = [];
      for (let i = 0; i < this.size; i++)
        row.push(false);
      for (let i = 0; i < this.size; i++) {
        this.modules.push(row.slice());
        this.isFunction.push(row.slice());
      }
      this.drawFunctionPatterns();
      const allCodewords = this.addEccAndInterleave(dataCodewords);
      this.drawCodewords(allCodewords);
      if (msk == -1) {
        let minPenalty = 1e9;
        for (let i = 0; i < 8; i++) {
          this.applyMask(i);
          this.drawFormatBits(i);
          const penalty = this.getPenaltyScore();
          if (penalty < minPenalty) {
            msk = i;
            minPenalty = penalty;
          }
          this.applyMask(i);
        }
      }
      assert(0 <= msk && msk <= 7);
      this.mask = msk;
      this.applyMask(msk);
      this.drawFormatBits(msk);
      this.isFunction = [];
    }
    static encodeText(text, ecl) {
      const segs = qrcodegen2.QrSegment.makeSegments(text);
      return _QrCode.encodeSegments(segs, ecl);
    }
    static encodeBinary(data, ecl) {
      const seg = qrcodegen2.QrSegment.makeBytes(data);
      return _QrCode.encodeSegments([seg], ecl);
    }
    static encodeSegments(segs, ecl, minVersion = 1, maxVersion = 40, mask = -1, boostEcl = true) {
      if (!(_QrCode.MIN_VERSION <= minVersion && minVersion <= maxVersion && maxVersion <= _QrCode.MAX_VERSION) || mask < -1 || mask > 7)
        throw new RangeError("Invalid value");
      let version;
      let dataUsedBits;
      for (version = minVersion; ; version++) {
        const dataCapacityBits2 = _QrCode.getNumDataCodewords(version, ecl) * 8;
        const usedBits = QrSegment.getTotalBits(segs, version);
        if (usedBits <= dataCapacityBits2) {
          dataUsedBits = usedBits;
          break;
        }
        if (version >= maxVersion)
          throw new RangeError("Data too long");
      }
      for (const newEcl of [_QrCode.Ecc.MEDIUM, _QrCode.Ecc.QUARTILE, _QrCode.Ecc.HIGH]) {
        if (boostEcl && dataUsedBits <= _QrCode.getNumDataCodewords(version, newEcl) * 8)
          ecl = newEcl;
      }
      let bb = [];
      for (const seg of segs) {
        appendBits(seg.mode.modeBits, 4, bb);
        appendBits(seg.numChars, seg.mode.numCharCountBits(version), bb);
        for (const b of seg.getData())
          bb.push(b);
      }
      assert(bb.length == dataUsedBits);
      const dataCapacityBits = _QrCode.getNumDataCodewords(version, ecl) * 8;
      assert(bb.length <= dataCapacityBits);
      appendBits(0, Math.min(4, dataCapacityBits - bb.length), bb);
      appendBits(0, (8 - bb.length % 8) % 8, bb);
      assert(bb.length % 8 == 0);
      for (let padByte = 236; bb.length < dataCapacityBits; padByte ^= 236 ^ 17)
        appendBits(padByte, 8, bb);
      let dataCodewords = [];
      while (dataCodewords.length * 8 < bb.length)
        dataCodewords.push(0);
      bb.forEach((b, i) => dataCodewords[i >>> 3] |= b << 7 - (i & 7));
      return new _QrCode(version, ecl, dataCodewords, mask);
    }
    getModule(x, y) {
      return 0 <= x && x < this.size && 0 <= y && y < this.size && this.modules[y][x];
    }
    getModules() {
      return this.modules;
    }
    drawFunctionPatterns() {
      for (let i = 0; i < this.size; i++) {
        this.setFunctionModule(6, i, i % 2 == 0);
        this.setFunctionModule(i, 6, i % 2 == 0);
      }
      this.drawFinderPattern(3, 3);
      this.drawFinderPattern(this.size - 4, 3);
      this.drawFinderPattern(3, this.size - 4);
      const alignPatPos = this.getAlignmentPatternPositions();
      const numAlign = alignPatPos.length;
      for (let i = 0; i < numAlign; i++) {
        for (let j = 0; j < numAlign; j++) {
          if (!(i == 0 && j == 0 || i == 0 && j == numAlign - 1 || i == numAlign - 1 && j == 0))
            this.drawAlignmentPattern(alignPatPos[i], alignPatPos[j]);
        }
      }
      this.drawFormatBits(0);
      this.drawVersion();
    }
    drawFormatBits(mask) {
      const data = this.errorCorrectionLevel.formatBits << 3 | mask;
      let rem = data;
      for (let i = 0; i < 10; i++)
        rem = rem << 1 ^ (rem >>> 9) * 1335;
      const bits = (data << 10 | rem) ^ 21522;
      assert(bits >>> 15 == 0);
      for (let i = 0; i <= 5; i++)
        this.setFunctionModule(8, i, getBit(bits, i));
      this.setFunctionModule(8, 7, getBit(bits, 6));
      this.setFunctionModule(8, 8, getBit(bits, 7));
      this.setFunctionModule(7, 8, getBit(bits, 8));
      for (let i = 9; i < 15; i++)
        this.setFunctionModule(14 - i, 8, getBit(bits, i));
      for (let i = 0; i < 8; i++)
        this.setFunctionModule(this.size - 1 - i, 8, getBit(bits, i));
      for (let i = 8; i < 15; i++)
        this.setFunctionModule(8, this.size - 15 + i, getBit(bits, i));
      this.setFunctionModule(8, this.size - 8, true);
    }
    drawVersion() {
      if (this.version < 7)
        return;
      let rem = this.version;
      for (let i = 0; i < 12; i++)
        rem = rem << 1 ^ (rem >>> 11) * 7973;
      const bits = this.version << 12 | rem;
      assert(bits >>> 18 == 0);
      for (let i = 0; i < 18; i++) {
        const color = getBit(bits, i);
        const a = this.size - 11 + i % 3;
        const b = Math.floor(i / 3);
        this.setFunctionModule(a, b, color);
        this.setFunctionModule(b, a, color);
      }
    }
    drawFinderPattern(x, y) {
      for (let dy = -4; dy <= 4; dy++) {
        for (let dx = -4; dx <= 4; dx++) {
          const dist = Math.max(Math.abs(dx), Math.abs(dy));
          const xx = x + dx;
          const yy = y + dy;
          if (0 <= xx && xx < this.size && 0 <= yy && yy < this.size)
            this.setFunctionModule(xx, yy, dist != 2 && dist != 4);
        }
      }
    }
    drawAlignmentPattern(x, y) {
      for (let dy = -2; dy <= 2; dy++) {
        for (let dx = -2; dx <= 2; dx++)
          this.setFunctionModule(x + dx, y + dy, Math.max(Math.abs(dx), Math.abs(dy)) != 1);
      }
    }
    setFunctionModule(x, y, isDark) {
      this.modules[y][x] = isDark;
      this.isFunction[y][x] = true;
    }
    addEccAndInterleave(data) {
      const ver = this.version;
      const ecl = this.errorCorrectionLevel;
      if (data.length != _QrCode.getNumDataCodewords(ver, ecl))
        throw new RangeError("Invalid argument");
      const numBlocks = _QrCode.NUM_ERROR_CORRECTION_BLOCKS[ecl.ordinal][ver];
      const blockEccLen = _QrCode.ECC_CODEWORDS_PER_BLOCK[ecl.ordinal][ver];
      const rawCodewords = Math.floor(_QrCode.getNumRawDataModules(ver) / 8);
      const numShortBlocks = numBlocks - rawCodewords % numBlocks;
      const shortBlockLen = Math.floor(rawCodewords / numBlocks);
      let blocks = [];
      const rsDiv = _QrCode.reedSolomonComputeDivisor(blockEccLen);
      for (let i = 0, k = 0; i < numBlocks; i++) {
        let dat = data.slice(k, k + shortBlockLen - blockEccLen + (i < numShortBlocks ? 0 : 1));
        k += dat.length;
        const ecc = _QrCode.reedSolomonComputeRemainder(dat, rsDiv);
        if (i < numShortBlocks)
          dat.push(0);
        blocks.push(dat.concat(ecc));
      }
      let result = [];
      for (let i = 0; i < blocks[0].length; i++) {
        blocks.forEach((block, j) => {
          if (i != shortBlockLen - blockEccLen || j >= numShortBlocks)
            result.push(block[i]);
        });
      }
      assert(result.length == rawCodewords);
      return result;
    }
    drawCodewords(data) {
      if (data.length != Math.floor(_QrCode.getNumRawDataModules(this.version) / 8))
        throw new RangeError("Invalid argument");
      let i = 0;
      for (let right = this.size - 1; right >= 1; right -= 2) {
        if (right == 6)
          right = 5;
        for (let vert = 0; vert < this.size; vert++) {
          for (let j = 0; j < 2; j++) {
            const x = right - j;
            const upward = (right + 1 & 2) == 0;
            const y = upward ? this.size - 1 - vert : vert;
            if (!this.isFunction[y][x] && i < data.length * 8) {
              this.modules[y][x] = getBit(data[i >>> 3], 7 - (i & 7));
              i++;
            }
          }
        }
      }
      assert(i == data.length * 8);
    }
    applyMask(mask) {
      if (mask < 0 || mask > 7)
        throw new RangeError("Mask value out of range");
      for (let y = 0; y < this.size; y++) {
        for (let x = 0; x < this.size; x++) {
          let invert;
          switch (mask) {
            case 0:
              invert = (x + y) % 2 == 0;
              break;
            case 1:
              invert = y % 2 == 0;
              break;
            case 2:
              invert = x % 3 == 0;
              break;
            case 3:
              invert = (x + y) % 3 == 0;
              break;
            case 4:
              invert = (Math.floor(x / 3) + Math.floor(y / 2)) % 2 == 0;
              break;
            case 5:
              invert = x * y % 2 + x * y % 3 == 0;
              break;
            case 6:
              invert = (x * y % 2 + x * y % 3) % 2 == 0;
              break;
            case 7:
              invert = ((x + y) % 2 + x * y % 3) % 2 == 0;
              break;
            default:
              throw new Error("Unreachable");
          }
          if (!this.isFunction[y][x] && invert)
            this.modules[y][x] = !this.modules[y][x];
        }
      }
    }
    getPenaltyScore() {
      let result = 0;
      for (let y = 0; y < this.size; y++) {
        let runColor = false;
        let runX = 0;
        let runHistory = [0, 0, 0, 0, 0, 0, 0];
        for (let x = 0; x < this.size; x++) {
          if (this.modules[y][x] == runColor) {
            runX++;
            if (runX == 5)
              result += _QrCode.PENALTY_N1;
            else if (runX > 5)
              result++;
          } else {
            this.finderPenaltyAddHistory(runX, runHistory);
            if (!runColor)
              result += this.finderPenaltyCountPatterns(runHistory) * _QrCode.PENALTY_N3;
            runColor = this.modules[y][x];
            runX = 1;
          }
        }
        result += this.finderPenaltyTerminateAndCount(runColor, runX, runHistory) * _QrCode.PENALTY_N3;
      }
      for (let x = 0; x < this.size; x++) {
        let runColor = false;
        let runY = 0;
        let runHistory = [0, 0, 0, 0, 0, 0, 0];
        for (let y = 0; y < this.size; y++) {
          if (this.modules[y][x] == runColor) {
            runY++;
            if (runY == 5)
              result += _QrCode.PENALTY_N1;
            else if (runY > 5)
              result++;
          } else {
            this.finderPenaltyAddHistory(runY, runHistory);
            if (!runColor)
              result += this.finderPenaltyCountPatterns(runHistory) * _QrCode.PENALTY_N3;
            runColor = this.modules[y][x];
            runY = 1;
          }
        }
        result += this.finderPenaltyTerminateAndCount(runColor, runY, runHistory) * _QrCode.PENALTY_N3;
      }
      for (let y = 0; y < this.size - 1; y++) {
        for (let x = 0; x < this.size - 1; x++) {
          const color = this.modules[y][x];
          if (color == this.modules[y][x + 1] && color == this.modules[y + 1][x] && color == this.modules[y + 1][x + 1])
            result += _QrCode.PENALTY_N2;
        }
      }
      let dark = 0;
      for (const row of this.modules)
        dark = row.reduce((sum, color) => sum + (color ? 1 : 0), dark);
      const total = this.size * this.size;
      const k = Math.ceil(Math.abs(dark * 20 - total * 10) / total) - 1;
      assert(0 <= k && k <= 9);
      result += k * _QrCode.PENALTY_N4;
      assert(0 <= result && result <= 2568888);
      return result;
    }
    getAlignmentPatternPositions() {
      if (this.version == 1)
        return [];
      else {
        const numAlign = Math.floor(this.version / 7) + 2;
        const step = this.version == 32 ? 26 : Math.ceil((this.version * 4 + 4) / (numAlign * 2 - 2)) * 2;
        let result = [6];
        for (let pos = this.size - 7; result.length < numAlign; pos -= step)
          result.splice(1, 0, pos);
        return result;
      }
    }
    static getNumRawDataModules(ver) {
      if (ver < _QrCode.MIN_VERSION || ver > _QrCode.MAX_VERSION)
        throw new RangeError("Version number out of range");
      let result = (16 * ver + 128) * ver + 64;
      if (ver >= 2) {
        const numAlign = Math.floor(ver / 7) + 2;
        result -= (25 * numAlign - 10) * numAlign - 55;
        if (ver >= 7)
          result -= 36;
      }
      assert(208 <= result && result <= 29648);
      return result;
    }
    static getNumDataCodewords(ver, ecl) {
      return Math.floor(_QrCode.getNumRawDataModules(ver) / 8) - _QrCode.ECC_CODEWORDS_PER_BLOCK[ecl.ordinal][ver] * _QrCode.NUM_ERROR_CORRECTION_BLOCKS[ecl.ordinal][ver];
    }
    static reedSolomonComputeDivisor(degree) {
      if (degree < 1 || degree > 255)
        throw new RangeError("Degree out of range");
      let result = [];
      for (let i = 0; i < degree - 1; i++)
        result.push(0);
      result.push(1);
      let root = 1;
      for (let i = 0; i < degree; i++) {
        for (let j = 0; j < result.length; j++) {
          result[j] = _QrCode.reedSolomonMultiply(result[j], root);
          if (j + 1 < result.length)
            result[j] ^= result[j + 1];
        }
        root = _QrCode.reedSolomonMultiply(root, 2);
      }
      return result;
    }
    static reedSolomonComputeRemainder(data, divisor) {
      let result = divisor.map((_) => 0);
      for (const b of data) {
        const factor = b ^ result.shift();
        result.push(0);
        divisor.forEach((coef, i) => result[i] ^= _QrCode.reedSolomonMultiply(coef, factor));
      }
      return result;
    }
    static reedSolomonMultiply(x, y) {
      if (x >>> 8 != 0 || y >>> 8 != 0)
        throw new RangeError("Byte out of range");
      let z = 0;
      for (let i = 7; i >= 0; i--) {
        z = z << 1 ^ (z >>> 7) * 285;
        z ^= (y >>> i & 1) * x;
      }
      assert(z >>> 8 == 0);
      return z;
    }
    finderPenaltyCountPatterns(runHistory) {
      const n = runHistory[1];
      assert(n <= this.size * 3);
      const core = n > 0 && runHistory[2] == n && runHistory[3] == n * 3 && runHistory[4] == n && runHistory[5] == n;
      return (core && runHistory[0] >= n * 4 && runHistory[6] >= n ? 1 : 0) + (core && runHistory[6] >= n * 4 && runHistory[0] >= n ? 1 : 0);
    }
    finderPenaltyTerminateAndCount(currentRunColor, currentRunLength, runHistory) {
      if (currentRunColor) {
        this.finderPenaltyAddHistory(currentRunLength, runHistory);
        currentRunLength = 0;
      }
      currentRunLength += this.size;
      this.finderPenaltyAddHistory(currentRunLength, runHistory);
      return this.finderPenaltyCountPatterns(runHistory);
    }
    finderPenaltyAddHistory(currentRunLength, runHistory) {
      if (runHistory[0] == 0)
        currentRunLength += this.size;
      runHistory.pop();
      runHistory.unshift(currentRunLength);
    }
  };
  let QrCode = _QrCode;
  QrCode.MIN_VERSION = 1;
  QrCode.MAX_VERSION = 40;
  QrCode.PENALTY_N1 = 3;
  QrCode.PENALTY_N2 = 3;
  QrCode.PENALTY_N3 = 40;
  QrCode.PENALTY_N4 = 10;
  QrCode.ECC_CODEWORDS_PER_BLOCK = [
    [-1, 7, 10, 15, 20, 26, 18, 20, 24, 30, 18, 20, 24, 26, 30, 22, 24, 28, 30, 28, 28, 28, 28, 30, 30, 26, 28, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30],
    [-1, 10, 16, 26, 18, 24, 16, 18, 22, 22, 26, 30, 22, 22, 24, 24, 28, 28, 26, 26, 26, 26, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28, 28],
    [-1, 13, 22, 18, 26, 18, 24, 18, 22, 20, 24, 28, 26, 24, 20, 30, 24, 28, 28, 26, 30, 28, 30, 30, 30, 30, 28, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30],
    [-1, 17, 28, 22, 16, 22, 28, 26, 26, 24, 28, 24, 28, 22, 24, 24, 30, 28, 28, 26, 28, 30, 24, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30]
  ];
  QrCode.NUM_ERROR_CORRECTION_BLOCKS = [
    [-1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 4, 4, 4, 4, 4, 6, 6, 6, 6, 7, 8, 8, 9, 9, 10, 12, 12, 12, 13, 14, 15, 16, 17, 18, 19, 19, 20, 21, 22, 24, 25],
    [-1, 1, 1, 1, 2, 2, 4, 4, 4, 5, 5, 5, 8, 9, 9, 10, 10, 11, 13, 14, 16, 17, 17, 18, 20, 21, 23, 25, 26, 28, 29, 31, 33, 35, 37, 38, 40, 43, 45, 47, 49],
    [-1, 1, 1, 2, 2, 4, 4, 6, 6, 8, 8, 8, 10, 12, 16, 12, 17, 16, 18, 21, 20, 23, 23, 25, 27, 29, 34, 34, 35, 38, 40, 43, 45, 48, 51, 53, 56, 59, 62, 65, 68],
    [-1, 1, 1, 2, 4, 4, 4, 5, 6, 8, 8, 11, 11, 16, 16, 18, 16, 19, 21, 25, 25, 25, 34, 30, 32, 35, 37, 40, 42, 45, 48, 51, 54, 57, 60, 63, 66, 70, 74, 77, 81]
  ];
  qrcodegen2.QrCode = QrCode;
  function appendBits(val, len, bb) {
    if (len < 0 || len > 31 || val >>> len != 0)
      throw new RangeError("Value out of range");
    for (let i = len - 1; i >= 0; i--)
      bb.push(val >>> i & 1);
  }
  function getBit(x, i) {
    return (x >>> i & 1) != 0;
  }
  function assert(cond) {
    if (!cond)
      throw new Error("Assertion error");
  }
  const _QrSegment = class {
    constructor(mode, numChars, bitData) {
      this.mode = mode;
      this.numChars = numChars;
      this.bitData = bitData;
      if (numChars < 0)
        throw new RangeError("Invalid argument");
      this.bitData = bitData.slice();
    }
    static makeBytes(data) {
      let bb = [];
      for (const b of data)
        appendBits(b, 8, bb);
      return new _QrSegment(_QrSegment.Mode.BYTE, data.length, bb);
    }
    static makeNumeric(digits) {
      if (!_QrSegment.isNumeric(digits))
        throw new RangeError("String contains non-numeric characters");
      let bb = [];
      for (let i = 0; i < digits.length; ) {
        const n = Math.min(digits.length - i, 3);
        appendBits(parseInt(digits.substr(i, n), 10), n * 3 + 1, bb);
        i += n;
      }
      return new _QrSegment(_QrSegment.Mode.NUMERIC, digits.length, bb);
    }
    static makeAlphanumeric(text) {
      if (!_QrSegment.isAlphanumeric(text))
        throw new RangeError("String contains unencodable characters in alphanumeric mode");
      let bb = [];
      let i;
      for (i = 0; i + 2 <= text.length; i += 2) {
        let temp = _QrSegment.ALPHANUMERIC_CHARSET.indexOf(text.charAt(i)) * 45;
        temp += _QrSegment.ALPHANUMERIC_CHARSET.indexOf(text.charAt(i + 1));
        appendBits(temp, 11, bb);
      }
      if (i < text.length)
        appendBits(_QrSegment.ALPHANUMERIC_CHARSET.indexOf(text.charAt(i)), 6, bb);
      return new _QrSegment(_QrSegment.Mode.ALPHANUMERIC, text.length, bb);
    }
    static makeSegments(text) {
      if (text == "")
        return [];
      else if (_QrSegment.isNumeric(text))
        return [_QrSegment.makeNumeric(text)];
      else if (_QrSegment.isAlphanumeric(text))
        return [_QrSegment.makeAlphanumeric(text)];
      else
        return [_QrSegment.makeBytes(_QrSegment.toUtf8ByteArray(text))];
    }
    static makeEci(assignVal) {
      let bb = [];
      if (assignVal < 0)
        throw new RangeError("ECI assignment value out of range");
      else if (assignVal < 1 << 7)
        appendBits(assignVal, 8, bb);
      else if (assignVal < 1 << 14) {
        appendBits(2, 2, bb);
        appendBits(assignVal, 14, bb);
      } else if (assignVal < 1e6) {
        appendBits(6, 3, bb);
        appendBits(assignVal, 21, bb);
      } else
        throw new RangeError("ECI assignment value out of range");
      return new _QrSegment(_QrSegment.Mode.ECI, 0, bb);
    }
    static isNumeric(text) {
      return _QrSegment.NUMERIC_REGEX.test(text);
    }
    static isAlphanumeric(text) {
      return _QrSegment.ALPHANUMERIC_REGEX.test(text);
    }
    getData() {
      return this.bitData.slice();
    }
    static getTotalBits(segs, version) {
      let result = 0;
      for (const seg of segs) {
        const ccbits = seg.mode.numCharCountBits(version);
        if (seg.numChars >= 1 << ccbits)
          return Infinity;
        result += 4 + ccbits + seg.bitData.length;
      }
      return result;
    }
    static toUtf8ByteArray(str) {
      str = encodeURI(str);
      let result = [];
      for (let i = 0; i < str.length; i++) {
        if (str.charAt(i) != "%")
          result.push(str.charCodeAt(i));
        else {
          result.push(parseInt(str.substr(i + 1, 2), 16));
          i += 2;
        }
      }
      return result;
    }
  };
  let QrSegment = _QrSegment;
  QrSegment.NUMERIC_REGEX = /^[0-9]*$/;
  QrSegment.ALPHANUMERIC_REGEX = /^[A-Z0-9 $%*+.\/:-]*$/;
  QrSegment.ALPHANUMERIC_CHARSET = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ $%*+-./:";
  qrcodegen2.QrSegment = QrSegment;
})(qrcodegen || (qrcodegen = {}));
((qrcodegen2) => {
  ((QrCode2) => {
    const _Ecc = class {
      constructor(ordinal, formatBits) {
        this.ordinal = ordinal;
        this.formatBits = formatBits;
      }
    };
    let Ecc = _Ecc;
    Ecc.LOW = new _Ecc(0, 1);
    Ecc.MEDIUM = new _Ecc(1, 0);
    Ecc.QUARTILE = new _Ecc(2, 3);
    Ecc.HIGH = new _Ecc(3, 2);
    QrCode2.Ecc = Ecc;
  })(qrcodegen2.QrCode || (qrcodegen2.QrCode = {}));
})(qrcodegen || (qrcodegen = {}));
((qrcodegen2) => {
  ((QrSegment2) => {
    const _Mode = class {
      constructor(modeBits, numBitsCharCount) {
        this.modeBits = modeBits;
        this.numBitsCharCount = numBitsCharCount;
      }
      numCharCountBits(ver) {
        return this.numBitsCharCount[Math.floor((ver + 7) / 17)];
      }
    };
    let Mode = _Mode;
    Mode.NUMERIC = new _Mode(1, [10, 12, 14]);
    Mode.ALPHANUMERIC = new _Mode(2, [9, 11, 13]);
    Mode.BYTE = new _Mode(4, [8, 16, 16]);
    Mode.KANJI = new _Mode(8, [8, 10, 12]);
    Mode.ECI = new _Mode(7, [0, 0, 0]);
    QrSegment2.Mode = Mode;
  })(qrcodegen2.QrSegment || (qrcodegen2.QrSegment = {}));
})(qrcodegen || (qrcodegen = {}));
var qrcodegen_default = qrcodegen;

// src/index.tsx
/**
 * @license qrcode.react
 * Copyright (c) Paul O'Shannessy
 * SPDX-License-Identifier: ISC
 */
var ERROR_LEVEL_MAP = {
  L: qrcodegen_default.QrCode.Ecc.LOW,
  M: qrcodegen_default.QrCode.Ecc.MEDIUM,
  Q: qrcodegen_default.QrCode.Ecc.QUARTILE,
  H: qrcodegen_default.QrCode.Ecc.HIGH
};
var DEFAULT_SIZE = 128;
var DEFAULT_LEVEL = "L";
var DEFAULT_BGCOLOR = "#FFFFFF";
var DEFAULT_FGCOLOR = "#000000";
var DEFAULT_INCLUDEMARGIN = false;
var MARGIN_SIZE = 4;
var DEFAULT_IMG_SCALE = 0.1;
function generatePath(modules, margin = 0) {
  const ops = [];
  modules.forEach(function(row, y) {
    let start = null;
    row.forEach(function(cell, x) {
      if (!cell && start !== null) {
        ops.push(`M${start + margin} ${y + margin}h${x - start}v1H${start + margin}z`);
        start = null;
        return;
      }
      if (x === row.length - 1) {
        if (!cell) {
          return;
        }
        if (start === null) {
          ops.push(`M${x + margin},${y + margin} h1v1H${x + margin}z`);
        } else {
          ops.push(`M${start + margin},${y + margin} h${x + 1 - start}v1H${start + margin}z`);
        }
        return;
      }
      if (cell && start === null) {
        start = x;
      }
    });
  });
  return ops.join("");
}
function excavateModules(modules, excavation) {
  return modules.slice().map((row, y) => {
    if (y < excavation.y || y >= excavation.y + excavation.h) {
      return row;
    }
    return row.map((cell, x) => {
      if (x < excavation.x || x >= excavation.x + excavation.w) {
        return cell;
      }
      return false;
    });
  });
}
function getImageSettings(cells, size, includeMargin, imageSettings) {
  if (imageSettings == null) {
    return null;
  }
  const margin = includeMargin ? MARGIN_SIZE : 0;
  const numCells = cells.length + margin * 2;
  const defaultSize = Math.floor(size * DEFAULT_IMG_SCALE);
  const scale = numCells / size;
  const w = (imageSettings.width || defaultSize) * scale;
  const h = (imageSettings.height || defaultSize) * scale;
  const x = imageSettings.x == null ? cells.length / 2 - w / 2 : imageSettings.x * scale;
  const y = imageSettings.y == null ? cells.length / 2 - h / 2 : imageSettings.y * scale;
  let excavation = null;
  if (imageSettings.excavate) {
    let floorX = Math.floor(x);
    let floorY = Math.floor(y);
    let ceilW = Math.ceil(w + x - floorX);
    let ceilH = Math.ceil(h + y - floorY);
    excavation = { x: floorX, y: floorY, w: ceilW, h: ceilH };
  }
  return { x, y, h, w, excavation };
}
var SUPPORTS_PATH2D = function() {
  try {
    new Path2D().addPath(new Path2D());
  } catch (e) {
    return false;
  }
  return true;
}();
function QRCodeCanvas(props) {
  const _a = props, {
    value,
    size = DEFAULT_SIZE,
    level = DEFAULT_LEVEL,
    bgColor = DEFAULT_BGCOLOR,
    fgColor = DEFAULT_FGCOLOR,
    includeMargin = DEFAULT_INCLUDEMARGIN,
    style,
    imageSettings
  } = _a, otherProps = __objRest(_a, [
    "value",
    "size",
    "level",
    "bgColor",
    "fgColor",
    "includeMargin",
    "style",
    "imageSettings"
  ]);
  const imgSrc = imageSettings == null ? void 0 : imageSettings.src;
  const _canvas = useRef(null);
  const _image = useRef(null);
  const [isImgLoaded, setIsImageLoaded] = useState(false);
  useEffect(() => {
    if (_canvas.current != null) {
      const canvas = _canvas.current;
      const ctx = canvas.getContext("2d");
      if (!ctx) {
        return;
      }
      let cells = qrcodegen_default.QrCode.encodeText(value, ERROR_LEVEL_MAP[level]).getModules();
      const margin = includeMargin ? MARGIN_SIZE : 0;
      const numCells = cells.length + margin * 2;
      const calculatedImageSettings = getImageSettings(cells, size, includeMargin, imageSettings);
      const image = _image.current;
      const haveImageToRender = calculatedImageSettings != null && image !== null && image.complete && image.naturalHeight !== 0 && image.naturalWidth !== 0;
      if (haveImageToRender) {
        if (calculatedImageSettings.excavation != null) {
          cells = excavateModules(cells, calculatedImageSettings.excavation);
        }
      }
      const pixelRatio = window.devicePixelRatio || 1;
      canvas.height = canvas.width = size * pixelRatio;
      const scale = size / numCells * pixelRatio;
      ctx.scale(scale, scale);
      ctx.fillStyle = bgColor;
      ctx.fillRect(0, 0, numCells, numCells);
      ctx.fillStyle = fgColor;
      if (SUPPORTS_PATH2D) {
        ctx.fill(new Path2D(generatePath(cells, margin)));
      } else {
        cells.forEach(function(row, rdx) {
          row.forEach(function(cell, cdx) {
            if (cell) {
              ctx.fillRect(cdx + margin, rdx + margin, 1, 1);
            }
          });
        });
      }
      if (haveImageToRender) {
        ctx.drawImage(image, calculatedImageSettings.x + margin, calculatedImageSettings.y + margin, calculatedImageSettings.w, calculatedImageSettings.h);
      }
    }
  });
  useEffect(() => {
    setIsImageLoaded(false);
  }, [imgSrc]);
  const canvasStyle = __spreadValues({ height: size, width: size }, style);
  let img = null;
  if (imgSrc != null) {
    img = /* @__PURE__ */ React__default.createElement("img", {
      src: imgSrc,
      key: imgSrc,
      style: { display: "none" },
      onLoad: () => {
        setIsImageLoaded(true);
      },
      ref: _image
    });
  }
  return /* @__PURE__ */ React__default.createElement(React__default.Fragment, null, /* @__PURE__ */ React__default.createElement("canvas", __spreadValues({
    style: canvasStyle,
    height: size,
    width: size,
    ref: _canvas
  }, otherProps)), img);
}
function QRCodeSVG(props) {
  const _a = props, {
    value,
    size = DEFAULT_SIZE,
    level = DEFAULT_LEVEL,
    bgColor = DEFAULT_BGCOLOR,
    fgColor = DEFAULT_FGCOLOR,
    includeMargin = DEFAULT_INCLUDEMARGIN,
    imageSettings
  } = _a, otherProps = __objRest(_a, [
    "value",
    "size",
    "level",
    "bgColor",
    "fgColor",
    "includeMargin",
    "imageSettings"
  ]);
  let cells = qrcodegen_default.QrCode.encodeText(value, ERROR_LEVEL_MAP[level]).getModules();
  const margin = includeMargin ? MARGIN_SIZE : 0;
  const numCells = cells.length + margin * 2;
  const calculatedImageSettings = getImageSettings(cells, size, includeMargin, imageSettings);
  let image = null;
  if (imageSettings != null && calculatedImageSettings != null) {
    if (calculatedImageSettings.excavation != null) {
      cells = excavateModules(cells, calculatedImageSettings.excavation);
    }
    image = /* @__PURE__ */ React__default.createElement("image", {
      xlinkHref: imageSettings.src,
      height: calculatedImageSettings.h,
      width: calculatedImageSettings.w,
      x: calculatedImageSettings.x + margin,
      y: calculatedImageSettings.y + margin,
      preserveAspectRatio: "none"
    });
  }
  const fgPath = generatePath(cells, margin);
  return /* @__PURE__ */ React__default.createElement("svg", __spreadValues({
    height: size,
    width: size,
    viewBox: `0 0 ${numCells} ${numCells}`
  }, otherProps), /* @__PURE__ */ React__default.createElement("path", {
    fill: bgColor,
    d: `M0,0 h${numCells}v${numCells}H0z`,
    shapeRendering: "crispEdges"
  }), /* @__PURE__ */ React__default.createElement("path", {
    fill: fgColor,
    d: fgPath,
    shapeRendering: "crispEdges"
  }), image);
}
var QRCode$1 = (props) => {
  const _a = props, { renderAs } = _a, otherProps = __objRest(_a, ["renderAs"]);
  if (renderAs === "svg") {
    return /* @__PURE__ */ React__default.createElement(QRCodeSVG, __spreadValues({}, otherProps));
  }
  return /* @__PURE__ */ React__default.createElement(QRCodeCanvas, __spreadValues({}, otherProps));
};

var QRCode = function QRCode(_ref) {
  var entity = _ref.entity,
    url = _ref.url;
  if (!entity) return null;
  var id = entity.id,
    name = entity.name;
  var canvasId = "qrcode-share-".concat(id);
  var handleDownload = function handleDownload() {
    var canvas = document.getElementById(canvasId);
    if (canvas) downloadCanvas(canvas, {
      name: slugify(name)
    });
  };
  return /*#__PURE__*/jsxs("div", {
    className: "neeto-ui-border-gray-200 flex flex-col justify-start space-y-2 border-t py-3 pl-8 sm:space-y-4 sm:border-l sm:py-2 sm:pl-6",
    "data-cy": "qr-download-block",
    "data-testid": "qr-download-block",
    children: [/*#__PURE__*/jsx(Typography, {
      lineHeight: "normal",
      style: "body2",
      weight: "medium",
      children: /*#__PURE__*/jsx(Trans, {
        i18nKey: "neetoMolecules.shareViaLink.socialMediaShare.qrCodeInfo",
        components: {
          button: /*#__PURE__*/jsx(Button, {
            "data-cy": "qr-code-download-button",
            "data-testid": "qr-code-download-button",
            style: "link",
            onClick: handleDownload
          })
        }
      })
    }), /*#__PURE__*/jsx(QRCode$1, {
      className: "cursor-pointer",
      "data-cy": "qr-code-image",
      "data-testid": canvasId,
      id: canvasId,
      size: 256,
      style: {
        width: 80,
        height: 80
      },
      value: url,
      onClick: handleDownload
    })]
  });
};

var Subtitle = function Subtitle(_ref) {
  var link = _ref.link,
    dataCy = _ref.dataCy,
    _onClick = _ref.onClick,
    subtitle = _ref.subtitle;
  var Component = isPresent(link) ? Link$1 : "div";
  return /*#__PURE__*/jsx(Component, {
    "data-cy": dataCy,
    to: link,
    onClick: function onClick(event) {
      event.preventDefault();
      _onClick === null || _onClick === void 0 || _onClick(event);
    },
    children: /*#__PURE__*/jsx(Typography, {
      style: "body3",
      weight: "medium",
      className: classnames("break-words", {
        "neeto-ui-text-accent-800": isPresent(_onClick) || isPresent(link)
      }),
      children: subtitle
    })
  });
};

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var ShareBlock = function ShareBlock(_ref) {
  var entity = _ref.entity,
    postTitle = _ref.postTitle,
    url = _ref.url,
    moreOptions = _ref.moreOptions,
    disableShareSocialMedia = _ref.disableShareSocialMedia,
    disableQRDownload = _ref.disableQRDownload;
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var socialMediaButtonClasses = "neeto-ui-bg-gray-200 hover:neeto-ui-bg-gray-300 flex h-10 w-10 cursor-pointer items-center justify-center neeto-ui-rounded-md transition-colors duration-300 ease-in-out";
  var hasMoreOptions = isPresent(moreOptions);
  return /*#__PURE__*/jsxs("div", {
    className: "flex flex-col divide-y sm:flex-row sm:gap-6 sm:divide-x sm:divide-y-0",
    children: [hasMoreOptions && /*#__PURE__*/jsx("div", {
      className: "max-w-md divide-y",
      children: moreOptions.map(function (_ref2, index) {
        var title = _ref2.title,
          link = _ref2.link,
          Icon = _ref2.icon,
          onClick = _ref2.onClick,
          dataCy = _ref2.dataCy,
          subtitleProps = _ref2.subtitleProps;
        var Component = isPresent(link) ? Link$1 : "div";
        return /*#__PURE__*/createElement(Component, {
          onClick: onClick,
          "data-cy": dataCy,
          key: link,
          to: link,
          className: classnames("neeto-ui-border-gray-200 flex cursor-pointer items-center gap-x-2 border-t py-3", {
            "border-none": index === 0
          })
        }, /*#__PURE__*/jsxs("div", {
          className: "flex flex-row gap-2",
          children: [/*#__PURE__*/jsx(Icon, {
            className: "neeto-ui-text-gray-500 flex-shrink-0",
            size: 24
          }), /*#__PURE__*/jsxs("div", {
            className: "flex flex-col gap-1",
            children: [/*#__PURE__*/jsx(Typography, {
              className: "group-hover:underline",
              style: "body2",
              weight: "medium",
              children: title
            }), subtitleProps && /*#__PURE__*/jsx(Subtitle, _objectSpread({}, subtitleProps))]
          })]
        }));
      })
    }), !disableShareSocialMedia && /*#__PURE__*/jsxs("div", {
      "data-cy": "social-media-block",
      "data-testid": "social-media-block",
      className: classnames("neeto-ui-border-gray-200 space-y-2 border-t py-3 sm:space-y-4 sm:border-l sm:py-2", {
        "pl-8 sm:pl-6": hasMoreOptions
      }),
      children: [/*#__PURE__*/jsx(Typography, {
        className: "neeto-ui-text-gray-800",
        lineHeight: "normal",
        style: "body2",
        weight: "medium",
        children: t("neetoMolecules.shareViaLink.socialMediaShare.title")
      }), /*#__PURE__*/jsx("div", {
        className: "flex gap-4",
        children: Object.entries(SOCIAL_MEDIA_OPTIONS).map(function (_ref3) {
          var _ref4 = _slicedToArray(_ref3, 2),
            key = _ref4[0],
            _ref4$ = _ref4[1],
            label = _ref4$.label,
            Icon = _ref4$.icon,
            generateShareUrl = _ref4$.generateShareUrl;
          return /*#__PURE__*/jsx("a", {
            className: socialMediaButtonClasses,
            "data-cy": "social-media-button-".concat(key),
            "data-testid": "social-media-button-".concat(key),
            href: generateShareUrl({
              url: url,
              title: postTitle
            }),
            rel: "noopener noreferrer",
            target: "_blank",
            title: label,
            children: /*#__PURE__*/jsx(Icon, {
              size: 24
            })
          }, key);
        })
      })]
    }), !disableQRDownload && /*#__PURE__*/jsx(QRCode, {
      entity: entity,
      url: url
    })]
  });
};

var ShareViaLink = function ShareViaLink(_ref) {
  var _ref$isLoading = _ref.isLoading,
    isLoading = _ref$isLoading === void 0 ? false : _ref$isLoading,
    _ref$enabledOptions = _ref.enabledOptions,
    enabledOptions = _ref$enabledOptions === void 0 ? {
      regenerate: false,
      edit: false
    } : _ref$enabledOptions,
    _ref$urls = _ref.urls,
    urls = _ref$urls === void 0 ? [] : _ref$urls,
    entity = _ref.entity,
    entityName = _ref.entityName,
    _ref$handleEdit = _ref.handleEdit,
    handleEdit = _ref$handleEdit === void 0 ? noop : _ref$handleEdit,
    _ref$handleRegenerate = _ref.handleRegenerate,
    handleRegenerate = _ref$handleRegenerate === void 0 ? noop : _ref$handleRegenerate,
    socialMediaPostTitle = _ref.socialMediaPostTitle,
    moreOptions = _ref.moreOptions,
    _ref$isOtherShareOpti = _ref.isOtherShareOptionsEnabled,
    isOtherShareOptionsEnabled = _ref$isOtherShareOpti === void 0 ? true : _ref$isOtherShareOpti,
    _ref$disableShareSoci = _ref.disableShareSocialMedia,
    disableShareSocialMedia = _ref$disableShareSoci === void 0 ? false : _ref$disableShareSoci,
    _ref$disableQRDownloa = _ref.disableQRDownload,
    disableQRDownload = _ref$disableQRDownloa === void 0 ? false : _ref$disableQRDownloa,
    _ref$publicLinkExpiry = _ref.publicLinkExpiryConfiguration,
    publicLinkExpiryConfiguration = _ref$publicLinkExpiry === void 0 ? {} : _ref$publicLinkExpiry;
  return /*#__PURE__*/jsxs("div", {
    className: "neeto-ui-border-gray-300 neeto-ui-rounded-lg neeto-ui-bg-white col-span-2 space-y-4 border p-6 sm:p-8",
    "data-testid": "share-via-link",
    children: [/*#__PURE__*/jsxs("div", {
      className: "space-y-1",
      children: [/*#__PURE__*/jsx("div", {
        className: "space-y-4",
        children: urls.map(function (urlOption) {
          return /*#__PURE__*/createElement(Link, {
            enabledOptions: enabledOptions,
            entityName: entityName,
            handleEdit: handleEdit,
            handleRegenerate: handleRegenerate,
            isLoading: isLoading,
            editUrlProps: omit(["url"], urlOption),
            key: urlOption.url,
            previewUrl: urlOption.previewUrl,
            url: urlOption.url
          });
        })
      }), isPresent(publicLinkExpiryConfiguration) && /*#__PURE__*/jsx(ExpiryNotice, {
        expiryConfiguration: publicLinkExpiryConfiguration
      })]
    }), isOtherShareOptionsEnabled && /*#__PURE__*/jsx(ShareBlock, {
      disableQRDownload: disableQRDownload,
      disableShareSocialMedia: disableShareSocialMedia,
      entity: entity,
      moreOptions: moreOptions,
      postTitle: socialMediaPostTitle,
      url: urls[0].url
    })]
  });
};

export { ShareViaLink as default };
//# sourceMappingURL=ShareViaLink.js.map
