import _toConsumableArray from '@babel/runtime/helpers/toConsumableArray';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import { shallow } from 'zustand/shallow';
import { useState, useEffect } from 'react';
import { useLocalStorage } from '@bigbinary/neeto-commons-frontend/react-utils';
import { useErrorDisplayStore } from '@bigbinary/neeto-commons-frontend/react-utils/useDisplayErrorPage';
import EditorContent from '@bigbinary/neeto-editor/EditorContent';
import Button from '@bigbinary/neetoui/Button';
import Tag from '@bigbinary/neetoui/Tag';
import { pluck } from 'ramda';
import { Trans } from 'react-i18next';
import { n } from './inject-css-DmrvuTKK.js';
import _asyncToGenerator from '@babel/runtime/helpers/asyncToGenerator';
import _regeneratorRuntime from '@babel/runtime/regenerator';
import { useQuery } from '@tanstack/react-query';
import { noop } from '@bigbinary/neeto-cist';
import axios from 'axios';
import { BASE_API_V1_URL } from '@bigbinary/neeto-commons-frontend/constants';
import { jsxs, Fragment, jsx } from 'react/jsx-runtime';

var QUERY_KEYS = {
  APP_STICKY_RIBBONS_LIST: "APP_STICKY_RIBBONS_LIST"
};
var STICKY_RIBBON_KIND_TO_STYLE = {
  info: "info",
  warning: "warning",
  error: "danger"
};
var STICKY_RIBBONS_LOCAL_STORAGE_KEY = "dismissedStickyRibbons";
var POLLING_INTERVAL = 5000;
var MAX_POLLING_TIME = 60000;

var css = ".neeto-molecules-sticky-ribbon{border-radius:0}";
n(css,{});

var fetchStickyRibbons = function fetchStickyRibbons() {
  return axios.get("".concat(BASE_API_V1_URL, "/sticky_ribbons"), {
    includeMetadataInResponse: true
  });
};
var stickyRibbonsApi = {
  fetchStickyRibbons: fetchStickyRibbons
};

var APP_STICKY_RIBBONS_LIST = QUERY_KEYS.APP_STICKY_RIBBONS_LIST;
var useFetchStickyRibbons = function useFetchStickyRibbons() {
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    isPolling = _useState2[0],
    setIsPolling = _useState2[1];
  useEffect(function () {
    if (!isPolling) return noop;
    var timer = setTimeout(function () {
      setIsPolling(false);
    }, MAX_POLLING_TIME);
    return function () {
      clearTimeout(timer);
    };
  }, [isPolling]);
  return useQuery({
    queryKey: [APP_STICKY_RIBBONS_LIST],
    queryFn: function () {
      var _queryFn = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        var response;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return stickyRibbonsApi.fetchStickyRibbons();
            case 2:
              response = _context.sent;
              if (response.status === 202) {
                setIsPolling(true);
              } else if (response.status === 200) {
                setIsPolling(false);
              }
              return _context.abrupt("return", response.data);
            case 5:
            case "end":
              return _context.stop();
          }
        }, _callee);
      }));
      function queryFn() {
        return _queryFn.apply(this, arguments);
      }
      return queryFn;
    }(),
    refetchInterval: isPolling ? POLLING_INTERVAL : false
  });
};

var StickyRibbonsContainer = function StickyRibbonsContainer() {
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    isRefreshRibbonDismissed = _useState2[0],
    setIsRefreshRibbonDismissed = _useState2[1];
  var _useLocalStorage = useLocalStorage(STICKY_RIBBONS_LOCAL_STORAGE_KEY, []),
    _useLocalStorage2 = _slicedToArray(_useLocalStorage, 2),
    dismissedRibbons = _useLocalStorage2[0],
    setDismissedRibbons = _useLocalStorage2[1];
  var _useErrorDisplayStore = useErrorDisplayStore(function (store) {
      return {
        showRefreshRibbon: store["showRefreshRibbon"]
      };
    }, shallow),
    showRefreshRibbon = _useErrorDisplayStore.showRefreshRibbon;
  var _useFetchStickyRibbon = useFetchStickyRibbons(),
    _useFetchStickyRibbon2 = _useFetchStickyRibbon.data,
    _useFetchStickyRibbon3 = _useFetchStickyRibbon2 === void 0 ? {} : _useFetchStickyRibbon2,
    _useFetchStickyRibbon4 = _useFetchStickyRibbon3.stickyRibbons,
    stickyRibbons = _useFetchStickyRibbon4 === void 0 ? [] : _useFetchStickyRibbon4;
  var handleDismiss = function handleDismiss(ribbonId) {
    var validRibbonIds = pluck("id", stickyRibbons);
    var updatedDismissedRibbons = dismissedRibbons.filter(function (id) {
      return validRibbonIds.includes(id);
    });
    setDismissedRibbons([].concat(_toConsumableArray(updatedDismissedRibbons), [ribbonId]));
  };
  var visibleRibbons = stickyRibbons.filter(function (ribbon) {
    return !dismissedRibbons.includes(ribbon.id);
  });
  return /*#__PURE__*/jsxs(Fragment, {
    children: [showRefreshRibbon && !isRefreshRibbonDismissed && /*#__PURE__*/jsx(Tag, {
      className: "neeto-molecules-sticky-ribbon w-full p-2.5 text-center",
      size: "large",
      style: STICKY_RIBBON_KIND_TO_STYLE["error"],
      onClose: function onClose() {
        return setIsRefreshRibbonDismissed(true);
      },
      children: /*#__PURE__*/jsx("span", {
        className: "w-full",
        children: /*#__PURE__*/jsx(Trans, {
          i18nKey: "neetoMolecules.stickyRibbonsContainer.refreshRibbon",
          components: {
            button: /*#__PURE__*/jsx(Button, {
              style: "link",
              onClick: function onClick() {
                return window.location.reload();
              }
            })
          }
        })
      })
    }), visibleRibbons.map(function (_ref) {
      var id = _ref.id,
        kind = _ref.kind,
        message = _ref.message;
      return /*#__PURE__*/jsx(Tag, {
        className: "neeto-molecules-sticky-ribbon w-full p-2.5 text-center",
        size: "large",
        style: STICKY_RIBBON_KIND_TO_STYLE[kind],
        onClose: function onClose() {
          return handleDismiss(id);
        },
        children: /*#__PURE__*/jsx(EditorContent, {
          className: "w-full",
          content: message
        })
      }, id);
    })]
  });
};

export { StickyRibbonsContainer as default };
//# sourceMappingURL=StickyRibbonsContainer.js.map
