'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var EmailPreview = require('./EmailPreview.js');
var _defineProperty = require('@babel/runtime/helpers/defineProperty');
var React = require('react');
var classnames = require('classnames');
var formik = require('formik');
var neetoCist = require('@bigbinary/neeto-cist');
var FormikEditor = require('@bigbinary/neeto-editor/FormikEditor');
var Typography = require('@bigbinary/neetoui/Typography');
var ActionBlock = require('@bigbinary/neetoui/formik/ActionBlock');
var Radio = require('@bigbinary/neetoui/formik/Radio');
var reactI18next = require('react-i18next');
var i18next = require('i18next');
var utils = require('@bigbinary/neeto-editor/utils');
var ramda = require('ramda');
var yup = require('yup');
var Select = require('@bigbinary/neetoui/formik/Select');
var Input = require('@bigbinary/neetoui/formik/Input');
var jsxRuntime = require('react/jsx-runtime');
var SendToFields = require('./SendToFields.js');
var _slicedToArray = require('@babel/runtime/helpers/slicedToArray');
var general = require('@bigbinary/neeto-commons-frontend/utils/general');
var Input$1 = require('@bigbinary/neetoui/Input');
var DynamicVariables = require('./DynamicVariables.js');
var Tooltip = require('@bigbinary/neetoui/Tooltip');
var BlockNavigation = require('@bigbinary/neetoui/formik/BlockNavigation');
var Switch = require('@bigbinary/neetoui/formik/Switch');
var Header = require('./Header.js');
var MobilePreviewHeader = require('./MobilePreviewHeader.js');
var injectCss = require('./inject-css-vQvjPR2x.js');
var Form = require('@bigbinary/neetoui/formik/Form');
require('@bigbinary/neeto-commons-frontend/react-utils/withT');
require('@bigbinary/neeto-editor/EditorContent');
require('@bigbinary/neetoui/Button');
require('./index-JY2zVpnv.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('@babel/runtime/helpers/toConsumableArray');
require('@bigbinary/neeto-icons/Upload');
require('@bigbinary/neetoui/Toastr');
require('@bigbinary/neetoui/formik/MultiEmailInput');
require('@bigbinary/neetoui/Pane');
require('react-dropzone');
require('@bigbinary/neeto-icons/Download');
require('@bigbinary/neetoui/Callout');
require('stream');
require('@babel/runtime/helpers/objectWithoutProperties');
require('@bigbinary/neeto-icons/Braces');
require('@bigbinary/neetoui/Dropdown');
require('./Breadcrumbs.js');
require('react-router-dom');
require('./HelpPopover.js');
require('@bigbinary/neeto-icons/Help');
require('@bigbinary/neetoui/Popover');
require('./MoreDropdown.js');
require('@bigbinary/neeto-icons/MenuHorizontal');
require('@bigbinary/neeto-icons/MenuVertical');
require('./Search.js');
require('@bigbinary/neeto-commons-frontend/react-utils/useFuncDebounce');
require('@bigbinary/neeto-commons-frontend/react-utils/useQueryParams');
require('@bigbinary/neeto-commons-frontend/react-utils/useUpdateEffect');
require('@bigbinary/neeto-icons/Search');
require('@bigbinary/neeto-commons-frontend/utils');

function _interopNamespaceDefault(e) {
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () { return e[k]; }
        });
      }
    });
  }
  n.default = e;
  return Object.freeze(n);
}

var yup__namespace = /*#__PURE__*/_interopNamespaceDefault(yup);

var INITIAL_FORM_VALUES = {
  sendTo: [],
  sendToId: "",
  sendToCc: [],
  sendToBcc: [],
  replyTo: "",
  showCopyEmails: false,
  subject: "",
  message: "",
  isEnabled: false
};
var EMAIL_FORM_VALIDATION_SCHEMA = yup__namespace.object({
  subject: yup__namespace.string().required(i18next.t("neetoMolecules.emailForm.errors.subjectRequired")),
  message: yup__namespace.string().test("message", i18next.t("neetoMolecules.emailForm.errors.messageRequired"), function (value) {
    return !utils.isEditorEmpty(value);
  })
});
var sendToFieldValidation = function sendToFieldValidation(maxEmails) {
  var validation = yup__namespace.array().test("all-emails-valid", i18next.t("neetoMolecules.emailForm.errors.invalidEmailAddress"), function (emails) {
    return emails === null || emails === void 0 ? void 0 : emails.every(ramda.prop("valid"));
  }).test("max-email-count", i18next.t("neetoMolecules.emailForm.errors.maxEmails", {
    count: maxEmails
  }), function (emails) {
    return (emails === null || emails === void 0 ? void 0 : emails.length) <= maxEmails;
  });
  return yup__namespace.object({
    sendTo: validation.min(1, i18next.t("neetoMolecules.emailForm.errors.required", {
      entity: i18next.t("neetoMolecules.emailForm.fields.sendToEmailAddress")
    })).nullable(),
    sendToCc: validation,
    sendToBcc: validation
  });
};
var SEND_TO_ID_FIELD_VALIDATION = yup__namespace.object({
  sendToId: yup__namespace.string().required(i18next.t("neetoMolecules.emailForm.errors.required", {
    entity: i18next.t("neetoMolecules.emailForm.labels.sendTo")
  }))
});
var REPLY_TO_FIELD_VALIDATION = yup__namespace.object({
  replyTo: yup__namespace.string().nullable().email(i18next.t("neetoMolecules.emailForm.errors.invalidEmailAddress")).required(i18next.t("neetoMolecules.emailForm.errors.required", {
    entity: i18next.t("neetoMolecules.emailForm.fields.replyToEmailAddress")
  }))
});
var EDITOR_ADDONS = ["highlight", "emoji", "code-block", "block-quote", "image-upload", "divider", "video-embed"];

/* eslint-disable @bigbinary/neeto/use-zustand-for-global-state-management */
var EmailFormContext = /*#__PURE__*/React.createContext({
  showSendToField: false,
  showSendToAsRadio: false,
  showReplyToField: false
});

function ownKeys$3(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$3(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$3(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$3(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var getValidationSchema = function getValidationSchema(_ref) {
  var showSendToField = _ref.showSendToField,
    showReplyToField = _ref.showReplyToField,
    showSendToAsRadio = _ref.showSendToAsRadio,
    customValidations = _ref.customValidations,
    maxEmails = _ref.maxEmails;
  var schema = EMAIL_FORM_VALIDATION_SCHEMA.clone();
  if (showSendToField) {
    schema = schema.concat(showSendToAsRadio ? SEND_TO_ID_FIELD_VALIDATION : sendToFieldValidation(maxEmails));
  }
  if (showReplyToField) schema = schema.concat(REPLY_TO_FIELD_VALIDATION);
  return schema.shape(customValidations);
};
var getReplyToFieldLabelProps = function getReplyToFieldLabelProps(_ref2) {
  var popoverProps = _ref2.popoverProps;
  return {
    helpIconProps: _defineProperty(_defineProperty(_defineProperty({}, "data-testid", "reply-to-tooltip"), "tooltipProps", !neetoCist.isPresent(popoverProps) && {
      content: i18next.t("neetoMolecules.emailForm.tooltips.replyTo"),
      touch: ["hold", 500]
    }), "popoverProps", neetoCist.isPresent(popoverProps) && _objectSpread$3(_objectSpread$3({}, popoverProps), {}, {
      appendTo: "parent",
      description: popoverProps.description || i18next.t("neetoMolecules.emailForm.tooltips.replyTo")
    }))
  };
};
var resolveContent = function resolveContent(content, func, variable) {
  if (typeof func === "function") {
    return func(content, variable);
  }
  return content;
};

var ReplyToField = function ReplyToField(_ref) {
  var _ref$options = _ref.options,
    options = _ref$options === void 0 ? [] : _ref$options,
    _ref$popoverProps = _ref.popoverProps,
    popoverProps = _ref$popoverProps === void 0 ? {} : _ref$popoverProps;
  var _useTranslation = reactI18next.useTranslation(),
    t = _useTranslation.t;
  var _useFormikContext = formik.useFormikContext(),
    setFieldValue = _useFormikContext.setFieldValue;
  var isDropdownField = neetoCist.isNotEmpty(options);
  var labelProps = getReplyToFieldLabelProps({
    popoverProps: popoverProps
  });
  if (isDropdownField) {
    return /*#__PURE__*/jsxRuntime.jsx(Select, {
      labelProps: labelProps,
      options: options,
      isClearable: true,
      className: "w-full",
      "data-testid": "replyToOptions",
      label: t("neetoMolecules.emailForm.labels.replyTo"),
      name: "replyTo",
      onChange: function onChange(data) {
        var _data$value;
        return setFieldValue("replyTo", (_data$value = data === null || data === void 0 ? void 0 : data.value) !== null && _data$value !== void 0 ? _data$value : "");
      }
    });
  }
  return /*#__PURE__*/jsxRuntime.jsx(Input, {
    labelProps: labelProps,
    autoFocus: true,
    required: true,
    className: "w-full",
    "data-testid": "replyToInput",
    label: t("neetoMolecules.emailForm.labels.replyTo"),
    name: "replyTo",
    placeholder: t("neetoMolecules.emailForm.placeholders.emailPlaceholder"),
    size: "large",
    onChange: function onChange(event) {
      var _event$target$value;
      return setFieldValue("replyTo", (_event$target$value = event.target.value) === null || _event$target$value === void 0 ? void 0 : _event$target$value.toLowerCase());
    }
  });
};

var SendToField = function SendToField(_ref) {
  var showBccField = _ref.showBccField,
    showCcField = _ref.showCcField,
    showSendToTextField = _ref.showSendToTextField;
  var _useTranslation = reactI18next.useTranslation(),
    t = _useTranslation.t;
  if (!showSendToTextField && !showBccField && !showCcField) return null;
  return /*#__PURE__*/jsxRuntime.jsx(SendToFields, {
    showCcBccButton: true,
    showBccField: showSendToTextField ? false : showBccField,
    showCcField: showSendToTextField ? false : showCcField,
    showSendToField: showSendToTextField,
    bccInputProps: {
      label: t("neetoMolecules.emailForm.labels.bCc"),
      name: "sendToBcc",
      placeholder: t("neetoMolecules.emailForm.placeholders.commaSeparatedEmails")
    },
    ccInputProps: {
      label: t("neetoMolecules.emailForm.labels.cc"),
      name: "sendToCc",
      placeholder: t("neetoMolecules.emailForm.placeholders.commaSeparatedEmails")
    },
    emailInputProps: {
      id: "sendTo",
      name: "sendTo",
      label: t("neetoMolecules.emailForm.labels.sendTo"),
      placeholder: t("neetoMolecules.emailForm.placeholders.commaSeparatedEmails"),
      required: true
    }
  });
};

var SubjectField = function SubjectField(_ref) {
  var name = _ref.name,
    text = _ref.text,
    updateText = _ref.updateText,
    _ref$subjectVariables = _ref.subjectVariables,
    subjectVariables = _ref$subjectVariables === void 0 ? [] : _ref$subjectVariables,
    error = _ref.error,
    _ref$required = _ref.required,
    required = _ref$required === void 0 ? false : _ref$required;
  var _useState = React.useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    isFieldFocusedOnce = _useState2[0],
    setIsFieldFocusedOnce = _useState2[1];
  var _useTranslation = reactI18next.useTranslation(),
    t = _useTranslation.t;
  var tagClickHandler = function tagClickHandler(_ref2) {
    var slug = _ref2.key;
    var textAreaElement = document.querySelector("textarea[name=".concat(name, "]"));
    var splitIndex = isFieldFocusedOnce && textAreaElement ? textAreaElement.selectionEnd : text.length;
    var updatedSubject = [text.slice(0, splitIndex), " {{".concat(slug, "}}"), text.slice(splitIndex)].join("");
    updateText(updatedSubject);
  };
  return /*#__PURE__*/jsxRuntime.jsxs(jsxRuntime.Fragment, {
    children: [/*#__PURE__*/jsxRuntime.jsx(Input$1, {
      error: error,
      name: name,
      required: required,
      label: t("neetoMolecules.emailForm.labels.subject"),
      size: "large",
      value: text,
      suffix: /*#__PURE__*/jsxRuntime.jsx(DynamicVariables, {
        variables: subjectVariables,
        dropdownProps: {
          className: "neeto-ui-dropdown__popup overflow-y-auto",
          buttonSize: "small"
        },
        onVariableClick: tagClickHandler
      }),
      onChange: general.withEventTargetValue(updateText),
      onFocus: function onFocus() {
        return setIsFieldFocusedOnce(true);
      }
    }), /*#__PURE__*/jsxRuntime.jsx(Typography, {
      className: "neeto-ui-text-gray-600 mt-2",
      "data-cy": "subject-input-variable-label",
      style: "body3",
      children: /*#__PURE__*/jsxRuntime.jsx(reactI18next.Trans, {
        components: {
          span: /*#__PURE__*/jsxRuntime.jsx("span", {
            className: "font-semibold"
          })
        },
        i18nKey: "neetoMolecules.emailForm.helpText",
        values: {
          type: "subject"
        }
      })
    })]
  });
};

function ownKeys$2(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$2(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$2(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$2(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var EmailForm = function EmailForm(_ref) {
  var _ref$messageVariables = _ref.messageVariables,
    messageVariables = _ref$messageVariables === void 0 ? [] : _ref$messageVariables,
    _ref$subjectVariables = _ref.subjectVariables,
    subjectVariables = _ref$subjectVariables === void 0 ? [] : _ref$subjectVariables,
    handleCancel = _ref.handleCancel,
    isLoading = _ref.isLoading,
    replyToFieldProps = _ref.replyToFieldProps,
    sendToFieldProps = _ref.sendToFieldProps,
    replyToOptions = _ref.replyToOptions,
    _ref$sendToOptions = _ref.sendToOptions,
    sendToOptions = _ref$sendToOptions === void 0 ? [] : _ref$sendToOptions,
    _ref$isUpdating = _ref.isUpdating,
    isUpdating = _ref$isUpdating === void 0 ? false : _ref$isUpdating,
    _ref$showFields = _ref.showFields,
    showFields = _ref$showFields === void 0 ? true : _ref$showFields,
    _ref$className = _ref.className,
    className = _ref$className === void 0 ? "" : _ref$className,
    _ref$editorAddons = _ref.editorAddons,
    editorAddons = _ref$editorAddons === void 0 ? EDITOR_ADDONS : _ref$editorAddons;
  var _useTranslation = reactI18next.useTranslation(),
    t = _useTranslation.t;
  var _useContext = React.useContext(EmailFormContext),
    showSendToField = _useContext.showSendToField,
    showSendToAsRadio = _useContext.showSendToAsRadio,
    showReplyToField = _useContext.showReplyToField,
    showCcField = _useContext.showCcField,
    showBccField = _useContext.showBccField;
  var _useFormikContext = formik.useFormikContext(),
    setFieldValue = _useFormikContext.setFieldValue;
  var sendToFieldOptions = (sendToFieldProps === null || sendToFieldProps === void 0 ? void 0 : sendToFieldProps.options) || sendToOptions;
  var showSendToRadioField = showSendToField && showSendToAsRadio && neetoCist.isNotEmpty(sendToFieldOptions);
  var showSendToTextField = showSendToField && !showSendToRadioField;
  return /*#__PURE__*/jsxRuntime.jsxs("div", {
    "data-cy": "email-form",
    "data-testid": "email-form",
    className: classnames("flex flex-1 flex-col items-start gap-2 !pb-0", _defineProperty({}, className, className)),
    children: [showFields && /*#__PURE__*/jsxRuntime.jsxs("div", {
      className: "flex w-full flex-col items-start justify-start gap-6",
      children: [/*#__PURE__*/jsxRuntime.jsx(formik.Field, {
        name: "subject",
        children: function children(_ref2) {
          var value = _ref2.field.value,
            error = _ref2.meta.error;
          return /*#__PURE__*/jsxRuntime.jsx("div", {
            className: "w-full",
            children: /*#__PURE__*/jsxRuntime.jsx(SubjectField, {
              subjectVariables: subjectVariables,
              required: true,
              error: t(error),
              name: "subject",
              text: value,
              updateText: function updateText(text) {
                return setFieldValue("subject", text);
              }
            })
          });
        }
      }), showSendToRadioField && /*#__PURE__*/jsxRuntime.jsx(Radio, {
        "data-testid": "send-to-id",
        label: t("neetoMolecules.emailForm.labels.sendTo"),
        labelProps: {
          required: true
        },
        name: "sendToId",
        children: sendToFieldOptions.map(function (_ref3) {
          var label = _ref3.label,
            value = _ref3.value;
          return /*#__PURE__*/React.createElement(Radio.Item, {
            label: label,
            value: value,
            key: value
          });
        })
      }), /*#__PURE__*/jsxRuntime.jsx(SendToField, {
        showBccField: showBccField,
        showCcField: showCcField,
        showSendToTextField: showSendToTextField
      }), showReplyToField && /*#__PURE__*/jsxRuntime.jsx(ReplyToField, _objectSpread$2({
        options: replyToOptions
      }, replyToFieldProps)), /*#__PURE__*/jsxRuntime.jsxs("div", {
        className: "w-full",
        children: [/*#__PURE__*/jsxRuntime.jsx(FormikEditor, {
          required: true,
          addons: editorAddons,
          "data-cy": "message-input-field",
          id: "form_message",
          label: t("neetoMolecules.emailForm.labels.message"),
          name: "message",
          variables: messageVariables,
          shouldUpdate: function shouldUpdate(nextProps, prevProps) {
            return neetoCist.notEqualsDeep(nextProps.variables, prevProps.variables);
          }
        }), /*#__PURE__*/jsxRuntime.jsx(Typography, {
          className: "neeto-ui-text-gray-500 mt-2",
          "data-cy": "message-input-variable-label",
          style: "body3",
          children: /*#__PURE__*/jsxRuntime.jsx(reactI18next.Trans, {
            i18nKey: "neetoMolecules.emailForm.helpText",
            values: {
              type: "message"
            },
            components: {
              span: /*#__PURE__*/jsxRuntime.jsx("span", {
                className: "font-semibold"
              })
            }
          })
        })]
      })]
    }), /*#__PURE__*/jsxRuntime.jsx(ActionBlock, {
      cancelButtonProps: {
        onClick: handleCancel
      },
      className: "neeto-ui-bg-white z-10 w-full justify-start py-6 lg:sticky lg:bottom-0",
      isSubmitting: isLoading || isUpdating
    })]
  });
};

var css = ".neeto-notification-email-wrapper{height:calc(100vh - 64px)}";
injectCss.n(css,{});

function ownKeys$1(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$1(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$1(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$1(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var EmailFormComponent = function EmailFormComponent(_ref) {
  var _ref$onSubmit = _ref.onSubmit,
    onSubmit = _ref$onSubmit === void 0 ? neetoCist.noop : _ref$onSubmit,
    _ref$initialValues = _ref.initialValues,
    initialValues = _ref$initialValues === void 0 ? INITIAL_FORM_VALUES : _ref$initialValues,
    _children = _ref.children,
    formikProps = _ref.formikProps,
    validationSchema = _ref.validationSchema,
    _ref$showSendToField = _ref.showSendToField,
    showSendToField = _ref$showSendToField === void 0 ? false : _ref$showSendToField,
    _ref$showReplyToField = _ref.showReplyToField,
    showReplyToField = _ref$showReplyToField === void 0 ? false : _ref$showReplyToField,
    _ref$showSendToAsRadi = _ref.showSendToAsRadio,
    showSendToAsRadio = _ref$showSendToAsRadi === void 0 ? false : _ref$showSendToAsRadi,
    _ref$showCcField = _ref.showCcField,
    showCcField = _ref$showCcField === void 0 ? false : _ref$showCcField,
    _ref$showBccField = _ref.showBccField,
    showBccField = _ref$showBccField === void 0 ? false : _ref$showBccField,
    _ref$isLoading = _ref.isLoading,
    isLoading = _ref$isLoading === void 0 ? false : _ref$isLoading,
    _ref$maxEmails = _ref.maxEmails,
    maxEmails = _ref$maxEmails === void 0 ? 10 : _ref$maxEmails,
    _ref$emailFormProps = _ref.emailFormProps,
    emailFormProps = _ref$emailFormProps === void 0 ? {} : _ref$emailFormProps,
    _ref$emailPreviewProp = _ref.emailPreviewProps,
    emailPreviewProps = _ref$emailPreviewProp === void 0 ? {} : _ref$emailPreviewProp,
    _ref$headerProps = _ref.headerProps,
    headerProps = _ref$headerProps === void 0 ? {} : _ref$headerProps,
    _ref$tooltipProps = _ref.tooltipProps,
    tooltipProps = _ref$tooltipProps === void 0 ? {} : _ref$tooltipProps,
    _ref$switchProps = _ref.switchProps,
    switchProps = _ref$switchProps === void 0 ? {} : _ref$switchProps,
    _ref$mobilePreviewPro = _ref.mobilePreviewProps,
    mobilePreviewProps = _ref$mobilePreviewPro === void 0 ? {} : _ref$mobilePreviewPro;
  var formatBody = emailPreviewProps.formatBody,
    formatSubject = emailPreviewProps.formatSubject,
    bodyVariables = emailPreviewProps.bodyVariables,
    subjectVariables = emailPreviewProps.subjectVariables;
  var shouldShowFields = function shouldShowFields(values) {
    return ramda.isEmpty(switchProps) || values.isEnabled;
  };
  return /*#__PURE__*/jsxRuntime.jsx(EmailFormProvider, {
    formikProps: formikProps,
    initialValues: initialValues,
    maxEmails: maxEmails,
    onSubmit: onSubmit,
    showBccField: showBccField,
    showCcField: showCcField,
    showReplyToField: showReplyToField,
    showSendToAsRadio: showSendToAsRadio,
    showSendToField: showSendToField,
    validationSchema: validationSchema,
    children: function children(_ref2) {
      var _values$sendTo;
      var values = _ref2.values,
        isSubmitting = _ref2.isSubmitting;
      return /*#__PURE__*/jsxRuntime.jsxs("div", {
        className: "neeto-notification-email-wrapper flex flex-grow flex-col overflow-y-auto lg:flex-row",
        children: [/*#__PURE__*/jsxRuntime.jsxs("div", {
          className: "flex w-full flex-col px-6 lg:h-full lg:w-1/2 lg:overflow-y-auto",
          children: [/*#__PURE__*/jsxRuntime.jsx(BlockNavigation, {}), neetoCist.isNotEmpty(headerProps) && /*#__PURE__*/jsxRuntime.jsx(Header, _objectSpread$1({
            className: "px-0",
            size: "small"
          }, headerProps)), neetoCist.isNotEmpty(switchProps) && /*#__PURE__*/jsxRuntime.jsx("div", {
            className: "flex items-center justify-between space-y-0.5 pb-6",
            children: /*#__PURE__*/jsxRuntime.jsx(Tooltip, _objectSpread$1(_objectSpread$1({
              disabled: !(switchProps !== null && switchProps !== void 0 && switchProps.disabled),
              position: "top"
            }, tooltipProps), {}, {
              children: /*#__PURE__*/jsxRuntime.jsx("div", {
                className: "flex items-center gap-2",
                children: /*#__PURE__*/jsxRuntime.jsx(Switch, _objectSpread$1({
                  "data-testid": "switch",
                  name: "isEnabled"
                }, switchProps))
              })
            }))
          }), shouldShowFields(values) && _children, /*#__PURE__*/jsxRuntime.jsx(EmailForm, _objectSpread$1({
            isLoading: isSubmitting || isLoading,
            isUpdating: isSubmitting || isLoading,
            showFields: shouldShowFields(values)
          }, emailFormProps))]
        }), shouldShowFields(values) && /*#__PURE__*/jsxRuntime.jsx(MobilePreviewHeader, _objectSpread$1({
          className: "lg:hidden"
        }, mobilePreviewProps)), shouldShowFields(values) && /*#__PURE__*/jsxRuntime.jsx("div", {
          className: "neeto-ui-bg-gray-100 w-full px-6 py-10 lg:w-1/2 lg:overflow-y-auto",
          children: /*#__PURE__*/jsxRuntime.jsx(EmailPreview, _objectSpread$1({
            body: resolveContent(values.message, formatBody, bodyVariables),
            from: values.sendFrom,
            to: ramda.pluck("value", (_values$sendTo = values === null || values === void 0 ? void 0 : values.sendTo) !== null && _values$sendTo !== void 0 ? _values$sendTo : []),
            subject: resolveContent(values.subject, formatSubject, subjectVariables)
          }, emailPreviewProps))
        })]
      });
    }
  });
};

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var EmailFormProvider = function EmailFormProvider(_ref) {
  var _ref$onSubmit = _ref.onSubmit,
    onSubmit = _ref$onSubmit === void 0 ? neetoCist.noop : _ref$onSubmit,
    _ref$initialValues = _ref.initialValues,
    initialValues = _ref$initialValues === void 0 ? INITIAL_FORM_VALUES : _ref$initialValues,
    children = _ref.children,
    formikProps = _ref.formikProps,
    _ref$validationSchema = _ref.validationSchema,
    customValidations = _ref$validationSchema === void 0 ? {} : _ref$validationSchema,
    _ref$showSendToField = _ref.showSendToField,
    showSendToField = _ref$showSendToField === void 0 ? false : _ref$showSendToField,
    _ref$showReplyToField = _ref.showReplyToField,
    showReplyToField = _ref$showReplyToField === void 0 ? false : _ref$showReplyToField,
    _ref$showSendToAsRadi = _ref.showSendToAsRadio,
    showSendToAsRadio = _ref$showSendToAsRadi === void 0 ? false : _ref$showSendToAsRadi,
    _ref$showCcField = _ref.showCcField,
    showCcField = _ref$showCcField === void 0 ? false : _ref$showCcField,
    _ref$showBccField = _ref.showBccField,
    showBccField = _ref$showBccField === void 0 ? false : _ref$showBccField,
    _ref$maxEmails = _ref.maxEmails,
    maxEmails = _ref$maxEmails === void 0 ? 10 : _ref$maxEmails;
  return /*#__PURE__*/jsxRuntime.jsx("div", {
    "data-testid": "email-form-provider",
    children: /*#__PURE__*/jsxRuntime.jsx(EmailFormContext.Provider, {
      value: {
        showSendToField: showSendToField,
        showSendToAsRadio: showSendToAsRadio,
        showReplyToField: showReplyToField,
        showCcField: showCcField,
        showBccField: showBccField
      },
      children: /*#__PURE__*/jsxRuntime.jsx(Form, {
        formikProps: _objectSpread({
          enableReinitialize: true,
          validationSchema: getValidationSchema({
            showSendToField: showSendToField,
            showReplyToField: showReplyToField,
            showSendToAsRadio: showSendToAsRadio,
            customValidations: customValidations,
            maxEmails: maxEmails
          }),
          initialValues: _objectSpread(_objectSpread({}, initialValues), {}, {
            replyTo: initialValues.replyTo || globalProps.user.email
          }),
          onSubmit: onSubmit
        }, formikProps),
        children: children
      })
    })
  });
};

exports.EmailPreview = EmailPreview;
exports.EmailForm = EmailForm;
exports.EmailFormProvider = EmailFormProvider;
exports.default = EmailFormComponent;
//# sourceMappingURL=EmailForm.js.map
