'use strict';

var _toConsumableArray = require('@babel/runtime/helpers/toConsumableArray');
var _slicedToArray = require('@babel/runtime/helpers/slicedToArray');
var shallow = require('zustand/shallow');
var React = require('react');
var reactUtils = require('@bigbinary/neeto-commons-frontend/react-utils');
var useDisplayErrorPage = require('@bigbinary/neeto-commons-frontend/react-utils/useDisplayErrorPage');
var EditorContent = require('@bigbinary/neeto-editor/EditorContent');
var Button = require('@bigbinary/neetoui/Button');
var Tag = require('@bigbinary/neetoui/Tag');
var ramda = require('ramda');
var reactI18next = require('react-i18next');
var injectCss = require('./inject-css-vQvjPR2x.js');
var _asyncToGenerator = require('@babel/runtime/helpers/asyncToGenerator');
var _regeneratorRuntime = require('@babel/runtime/regenerator');
var reactQuery = require('@tanstack/react-query');
var neetoCist = require('@bigbinary/neeto-cist');
var axios = require('axios');
var constants = require('@bigbinary/neeto-commons-frontend/constants');
var jsxRuntime = require('react/jsx-runtime');

var QUERY_KEYS = {
  APP_STICKY_RIBBONS_LIST: "APP_STICKY_RIBBONS_LIST"
};
var STICKY_RIBBON_KIND_TO_STYLE = {
  info: "info",
  warning: "warning",
  error: "danger"
};
var STICKY_RIBBONS_LOCAL_STORAGE_KEY = "dismissedStickyRibbons";
var POLLING_INTERVAL = 5000;
var MAX_POLLING_TIME = 60000;

var css = ".neeto-molecules-sticky-ribbon{border-radius:0}";
injectCss.n(css,{});

var fetchStickyRibbons = function fetchStickyRibbons() {
  return axios.get("".concat(constants.BASE_API_V1_URL, "/sticky_ribbons"), {
    includeMetadataInResponse: true
  });
};
var stickyRibbonsApi = {
  fetchStickyRibbons: fetchStickyRibbons
};

var APP_STICKY_RIBBONS_LIST = QUERY_KEYS.APP_STICKY_RIBBONS_LIST;
var useFetchStickyRibbons = function useFetchStickyRibbons() {
  var _useState = React.useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    isPolling = _useState2[0],
    setIsPolling = _useState2[1];
  React.useEffect(function () {
    if (!isPolling) return neetoCist.noop;
    var timer = setTimeout(function () {
      setIsPolling(false);
    }, MAX_POLLING_TIME);
    return function () {
      clearTimeout(timer);
    };
  }, [isPolling]);
  return reactQuery.useQuery({
    queryKey: [APP_STICKY_RIBBONS_LIST],
    queryFn: function () {
      var _queryFn = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        var response;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return stickyRibbonsApi.fetchStickyRibbons();
            case 2:
              response = _context.sent;
              if (response.status === 202) {
                setIsPolling(true);
              } else if (response.status === 200) {
                setIsPolling(false);
              }
              return _context.abrupt("return", response.data);
            case 5:
            case "end":
              return _context.stop();
          }
        }, _callee);
      }));
      function queryFn() {
        return _queryFn.apply(this, arguments);
      }
      return queryFn;
    }(),
    refetchInterval: isPolling ? POLLING_INTERVAL : false
  });
};

var StickyRibbonsContainer = function StickyRibbonsContainer() {
  var _useState = React.useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    isRefreshRibbonDismissed = _useState2[0],
    setIsRefreshRibbonDismissed = _useState2[1];
  var _useLocalStorage = reactUtils.useLocalStorage(STICKY_RIBBONS_LOCAL_STORAGE_KEY, []),
    _useLocalStorage2 = _slicedToArray(_useLocalStorage, 2),
    dismissedRibbons = _useLocalStorage2[0],
    setDismissedRibbons = _useLocalStorage2[1];
  var _useErrorDisplayStore = useDisplayErrorPage.useErrorDisplayStore(function (store) {
      return {
        showRefreshRibbon: store["showRefreshRibbon"]
      };
    }, shallow.shallow),
    showRefreshRibbon = _useErrorDisplayStore.showRefreshRibbon;
  var _useFetchStickyRibbon = useFetchStickyRibbons(),
    _useFetchStickyRibbon2 = _useFetchStickyRibbon.data,
    _useFetchStickyRibbon3 = _useFetchStickyRibbon2 === void 0 ? {} : _useFetchStickyRibbon2,
    _useFetchStickyRibbon4 = _useFetchStickyRibbon3.stickyRibbons,
    stickyRibbons = _useFetchStickyRibbon4 === void 0 ? [] : _useFetchStickyRibbon4;
  var handleDismiss = function handleDismiss(ribbonId) {
    var validRibbonIds = ramda.pluck("id", stickyRibbons);
    var updatedDismissedRibbons = dismissedRibbons.filter(function (id) {
      return validRibbonIds.includes(id);
    });
    setDismissedRibbons([].concat(_toConsumableArray(updatedDismissedRibbons), [ribbonId]));
  };
  var visibleRibbons = stickyRibbons.filter(function (ribbon) {
    return !dismissedRibbons.includes(ribbon.id);
  });
  return /*#__PURE__*/jsxRuntime.jsxs(jsxRuntime.Fragment, {
    children: [showRefreshRibbon && !isRefreshRibbonDismissed && /*#__PURE__*/jsxRuntime.jsx(Tag, {
      className: "neeto-molecules-sticky-ribbon w-full p-2.5 text-center",
      size: "large",
      style: STICKY_RIBBON_KIND_TO_STYLE["error"],
      onClose: function onClose() {
        return setIsRefreshRibbonDismissed(true);
      },
      children: /*#__PURE__*/jsxRuntime.jsx("span", {
        className: "w-full",
        children: /*#__PURE__*/jsxRuntime.jsx(reactI18next.Trans, {
          i18nKey: "neetoMolecules.stickyRibbonsContainer.refreshRibbon",
          components: {
            button: /*#__PURE__*/jsxRuntime.jsx(Button, {
              style: "link",
              onClick: function onClick() {
                return window.location.reload();
              }
            })
          }
        })
      })
    }), visibleRibbons.map(function (_ref) {
      var id = _ref.id,
        kind = _ref.kind,
        message = _ref.message;
      return /*#__PURE__*/jsxRuntime.jsx(Tag, {
        className: "neeto-molecules-sticky-ribbon w-full p-2.5 text-center",
        size: "large",
        style: STICKY_RIBBON_KIND_TO_STYLE[kind],
        onClose: function onClose() {
          return handleDismiss(id);
        },
        children: /*#__PURE__*/jsxRuntime.jsx(EditorContent, {
          className: "w-full",
          content: message
        })
      }, id);
    })]
  });
};

module.exports = StickyRibbonsContainer;
//# sourceMappingURL=StickyRibbonsContainer.js.map
