import _defineProperty from '@babel/runtime/helpers/defineProperty';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import { useEffect, forwardRef, useState, useImperativeHandle } from 'react';
import i18next from 'i18next';
import { removeBy, existsBy, isNotEmpty } from '@bigbinary/neeto-cist';
import Search from '@bigbinary/neeto-icons/Search';
import Checkbox from '@bigbinary/neetoui/Checkbox';
import Dropdown from '@bigbinary/neetoui/Dropdown';
import Input from '@bigbinary/neetoui/Input';
import Label from '@bigbinary/neetoui/Label';
import Typography from '@bigbinary/neetoui/Typography';
import { filter, includes, trim, toLower, union, without, __, isEmpty, equals, identity, pipe } from 'ramda';
import { useTranslation } from 'react-i18next';
import { n } from './inject-css-DmrvuTKK.js';
import { jsx, jsxs, Fragment } from 'react/jsx-runtime';
import { create } from 'zustand';
import { persist } from 'zustand/middleware';
import { getFromLocalStorage, removeFromLocalStorage } from '@bigbinary/neeto-commons-frontend/utils/general';

var css = ":root{--neeto-molecules-columns-menu-max-width:31.25rem}.neeto-molecules-columns__container{max-width:31.25rem;max-width:var(--neeto-molecules-columns-menu-max-width)}";
n(css,{});

var HIDDEN_COLUMNS_STORAGE_KEY = "neeto-molecules-hidden-columns";
var COLUMNS_ORDER_STORAGE_KEY = "neeto-molecules-columns-order";

var getHidableColumns = function getHidableColumns(columnData) {
  return removeBy({
    isHidable: false
  }, columnData);
};
var filterBySearchTerm = function filterBySearchTerm(searchTerm, columns) {
  return filter(function (_ref) {
    var title = _ref.title;
    return includes(trim(toLower(searchTerm)), trim(toLower(title)));
  }, columns);
};
var removeDeletedColumns = function removeDeletedColumns(hiddenColumns, columnData) {
  return hiddenColumns.filter(function (hiddenColumn) {
    return existsBy({
      dataIndex: hiddenColumn
    }, columnData);
  });
};

/** @type {import("neetocommons/react-utils").ZustandStoreHook} */
var useHiddenColumnStore = create(persist(function () {
  return {};
}, {
  name: HIDDEN_COLUMNS_STORAGE_KEY
}));
var useHiddenColumns = function useHiddenColumns(localStorageKey) {
  var initialValue = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var hiddenColumns = useHiddenColumnStore(function (state) {
    return state[localStorageKey];
  });
  var setHiddenColumns = function setHiddenColumns(columns) {
    return useHiddenColumnStore.setState(_defineProperty({}, localStorageKey, columns));
  };

  // Migrates values from old location to new zustand location.
  useEffect(function () {
    var oldValue = getFromLocalStorage(localStorageKey);
    if (oldValue) {
      setHiddenColumns(oldValue);
      removeFromLocalStorage(localStorageKey);
    } else if (!hiddenColumns) {
      setHiddenColumns(initialValue);
    }
  }, [localStorageKey]);
  var hideColumn = function hideColumn(columns) {
    return setHiddenColumns(union(hiddenColumns, Array.isArray(columns) ? columns : [columns]));
  };
  var showColumn = function showColumn(columns) {
    return setHiddenColumns(without(Array.isArray(columns) ? columns : [columns], hiddenColumns));
  };
  var getVisibleColumnData = function getVisibleColumnData(columnData) {
    return removeBy({
      dataIndex: includes(__, hiddenColumns || [])
    }, columnData);
  };
  var onColumnDataChange = function onColumnDataChange(columnData) {
    if (isEmpty(columnData) || !hiddenColumns) return;
    var newHiddenColumns = removeDeletedColumns(hiddenColumns, columnData);
    if (!equals(newHiddenColumns, hiddenColumns)) {
      setHiddenColumns(newHiddenColumns);
    }
  };
  return {
    hiddenColumns: hiddenColumns,
    hideColumn: hideColumn,
    showColumn: showColumn,
    getVisibleColumnData: getVisibleColumnData,
    onColumnDataChange: onColumnDataChange
  };
};

var _excluded$1 = ["actionBlock", "checkboxProps", "columnData", "isSearchable", "localStorageKey", "initialValue", "noColumnMessage", "onChange", "searchProps"];
function ownKeys$1(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$1(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$1(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$1(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var Columns = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var actionBlock = _ref.actionBlock,
    _ref$checkboxProps = _ref.checkboxProps,
    checkboxProps = _ref$checkboxProps === void 0 ? {} : _ref$checkboxProps,
    _ref$columnData = _ref.columnData,
    columnData = _ref$columnData === void 0 ? [] : _ref$columnData,
    _ref$isSearchable = _ref.isSearchable,
    isSearchable = _ref$isSearchable === void 0 ? false : _ref$isSearchable,
    _ref$localStorageKey = _ref.localStorageKey,
    localStorageKey = _ref$localStorageKey === void 0 ? "" : _ref$localStorageKey,
    _ref$initialValue = _ref.initialValue,
    initialValue = _ref$initialValue === void 0 ? [] : _ref$initialValue,
    _ref$noColumnMessage = _ref.noColumnMessage,
    noColumnMessage = _ref$noColumnMessage === void 0 ? i18next.t("neetoMolecules.columns.noColumns") : _ref$noColumnMessage,
    _ref$onChange = _ref.onChange,
    onChange = _ref$onChange === void 0 ? identity : _ref$onChange,
    _ref$searchProps = _ref.searchProps,
    searchProps = _ref$searchProps === void 0 ? {} : _ref$searchProps,
    dropdownProps = _objectWithoutProperties(_ref, _excluded$1);
  var Divider = Dropdown.Divider,
    Menu = Dropdown.Menu,
    MenuItem = Dropdown.MenuItem;
  var _useState = useState(""),
    _useState2 = _slicedToArray(_useState, 2),
    searchTerm = _useState2[0],
    setSearchTerm = _useState2[1];
  var _useTranslation = useTranslation(),
    t = _useTranslation.t;
  var _useHiddenColumns = useHiddenColumns(localStorageKey, initialValue),
    _useHiddenColumns$hid = _useHiddenColumns.hiddenColumns,
    hiddenColumns = _useHiddenColumns$hid === void 0 ? [] : _useHiddenColumns$hid,
    hideColumn = _useHiddenColumns.hideColumn,
    showColumn = _useHiddenColumns.showColumn,
    getVisibleColumnData = _useHiddenColumns.getVisibleColumnData,
    onColumnDataChange = _useHiddenColumns.onColumnDataChange;
  useEffect(function () {
    onChange(getVisibleColumnData(columnData), hiddenColumns);
  }, [hiddenColumns]);
  useEffect(function () {
    onColumnDataChange(columnData);
  }, [columnData]);

  /**
   * @deprecated Use showColumn|hideColumn from useHiddenColumns
   */
  useImperativeHandle(ref, function () {
    return {
      hideColumn: hideColumn,
      showColumn: showColumn
    };
  }, []);
  var handleChange = function handleChange(_ref2) {
    var _ref2$target = _ref2.target,
      dataIndex = _ref2$target.name,
      checked = _ref2$target.checked;
    if (checked) showColumn(dataIndex);else hideColumn(dataIndex);
  };
  var handleSearch = function handleSearch(_ref3) {
    var value = _ref3.target.value;
    return setSearchTerm(value);
  };
  var columns = getHidableColumns(columnData);
  var filteredColumns = filterBySearchTerm(searchTerm, columns);
  return /*#__PURE__*/jsx(Dropdown, _objectSpread$1(_objectSpread$1({
    appendTo: document.body,
    buttonSize: "medium",
    buttonStyle: "text",
    closeOnSelect: false,
    label: t("neetoMolecules.columns.columns"),
    position: "bottom-end",
    onClose: function onClose() {
      return setSearchTerm("");
    }
  }, dropdownProps), {}, {
    children: /*#__PURE__*/jsx(Menu, {
      children: /*#__PURE__*/jsxs("div", {
        className: "neeto-molecules-columns__container",
        children: [isSearchable && /*#__PURE__*/jsx(Input, _objectSpread$1({
          className: "px-4 py-2",
          "data-cy": "neeto-ui-columns-search",
          "data-testid": "neeto-ui-columns-search",
          placeholder: t("neetoMolecules.columns.search"),
          prefix: /*#__PURE__*/jsx(Search, {}),
          type: "search",
          value: searchTerm,
          onChange: handleSearch
        }, searchProps)), /*#__PURE__*/jsx(Typography, {
          className: "neeto-ui-text-gray-600 px-4 py-2",
          style: "body2",
          weight: "semibold",
          children: t("neetoMolecules.columns.columns")
        }), isNotEmpty(filteredColumns) ? filteredColumns.map(function (_ref4) {
          var dataIndex = _ref4.dataIndex,
            key = _ref4.key,
            title = _ref4.title;
          return /*#__PURE__*/jsx(MenuItem, {
            children: /*#__PURE__*/jsx(Label, {
              className: "neeto-ui-flex neeto-ui-w-full hover:neeto-ui-bg-gray-200 neeto-ui-cursor-pointer px-4 py-2",
              htmlFor: dataIndex,
              children: /*#__PURE__*/jsx(Checkbox, _objectSpread$1({
                checked: !hiddenColumns.includes(dataIndex),
                "data-cy": "neeto-ui-columns-checkbox",
                id: dataIndex,
                label: title,
                name: dataIndex,
                onChange: handleChange
              }, checkboxProps))
            })
          }, key);
        }) : /*#__PURE__*/jsx("span", {
          className: "neeto-ui-flex neeto-ui-flex-col neeto-ui-items-center neeto-ui-p-2",
          children: noColumnMessage
        }), !!actionBlock && /*#__PURE__*/jsxs(Fragment, {
          children: [/*#__PURE__*/jsx(Divider, {}), actionBlock]
        })]
      })
    })
  }));
});
Columns.displayName = "Columns";

var _excluded = ["hiddenColumns", "getVisibleColumnData"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }

/** @type {import("neetocommons/react-utils").ZustandStoreHook} */
var useColumnOrderStore = create(persist(function () {
  return {};
}, {
  name: COLUMNS_ORDER_STORAGE_KEY
}));
var useColumns = function useColumns(_ref) {
  var localStorageKey = _ref.localStorageKey,
    initialHiddenColumns = _ref.initialHiddenColumns,
    _ref$initialOrder = _ref.initialOrder,
    initialOrder = _ref$initialOrder === void 0 ? [] : _ref$initialOrder;
  var columnOrder = useColumnOrderStore(function (state) {
    return state[localStorageKey];
  }) || initialOrder;
  var setColumnOrder = function setColumnOrder(columns) {
    return useColumnOrderStore.setState(_defineProperty({}, localStorageKey, columns));
  };
  var _useHiddenColumns = useHiddenColumns(localStorageKey, initialHiddenColumns),
    hiddenColumns = _useHiddenColumns.hiddenColumns,
    getVisibleColumnData = _useHiddenColumns.getVisibleColumnData,
    hiddenColumnHelpers = _objectWithoutProperties(_useHiddenColumns, _excluded);
  var orderColumns = function orderColumns(columnData) {
    if (isEmpty(columnOrder)) return columnData;
    return columnData.sort(function (a, b) {
      if (!columnOrder.includes(a.dataIndex) || !columnOrder.includes(b.dataIndex)) {
        return 0;
      }
      return columnOrder.indexOf(a.dataIndex) - columnOrder.indexOf(b.dataIndex);
    });
  };
  var getColumnData = function getColumnData(_ref2) {
    var columnData = _ref2.columnData,
      _ref2$isHidable = _ref2.isHidable,
      isHidable = _ref2$isHidable === void 0 ? true : _ref2$isHidable,
      _ref2$isReOrderable = _ref2.isReOrderable,
      isReOrderable = _ref2$isReOrderable === void 0 ? false : _ref2$isReOrderable;
    return pipe(isHidable ? getVisibleColumnData : identity, isReOrderable ? orderColumns : identity)(columnData);
  };
  return _objectSpread(_objectSpread({}, hiddenColumnHelpers), {}, {
    hiddenColumns: hiddenColumns,
    columnOrder: columnOrder,
    getVisibleColumnData: getVisibleColumnData,
    setColumnOrder: setColumnOrder,
    getColumnData: getColumnData
  });
};

export { Columns as C, HIDDEN_COLUMNS_STORAGE_KEY as H, useHiddenColumnStore as a, COLUMNS_ORDER_STORAGE_KEY as b, useColumns as c, useColumnOrderStore as d, useHiddenColumns as u };
//# sourceMappingURL=useColumns-Db5uic1-.js.map
