import { ButtonProps } from '@bigbinary/neetoui';
import React from 'react';

interface Button extends ButtonProps {
  key: string;
  isActive?: boolean;
}
interface ButtonGroupProps {
  size?: "small" | "medium" | "large";
  buttons: Button[];
}
/**
 *
 * ButtonGroup component is a wrapper component that groups icon only buttons and
 *
 * highlights the active button.
 *
 * @example 
 *
 * import ButtonGroup from "@bigbinary/neeto-molecules/ButtonGroup";
 * 
 * const Component = () => (
 *   <ButtonGroup
 *     buttons={[
 *       {
 *         key: "calendar",
 *         icon: Calendar,
 *         onClick: () => handleSwitch(),
 *       },
 *       {
 *         key: "list",
 *         icon: List,
 *         onClick: () => handleSwitch(),
 *       },
 *     ]}
 *     size="medium"
 *   />
 * );
 * @endexample
*/
declare const ButtonGroup: React.FC<ButtonGroupProps>;

export { type ButtonGroupProps, ButtonGroup as default };
