import React from 'react';
import { SyntaxHighlighterProps } from 'react-syntax-highlighter';
import { CopyToClipboardButtonProps } from './CopyToClipboardButton.js';

/**
 *
 * Codeblock can be used to render a block of code, with appropriate syntax
 *
 * highlighting, and a copy code button.
 *
 * Note: To use this component, you should install
 *
 * react-syntax-highlighter@^15.5.0 package.
 *
 * ![image](https://github.com/bigbinary/neeto-molecules/assets/66865722/ed5c589f-7086-46b9-b8b2-2746afa7e750|height=200|width=300)
 *
 * @example 
 *
 * import Codeblock from "@bigbinary/neeto-molecules/Codeblock";
 * import { generateEmbedCode } from "./utils";
 * 
 * const EmbedPage = () => (
 *   <Codeblock
 *     code={generateEmbedCode()}
 *     codeblockProps={{ showLineNumbers: true }}
 *   />
 * );
 * @endexample
*/
declare const Codeblock: React.FC<{
  code: string;
  showCopyButton?: boolean;
  codeblockProps?: Partial<SyntaxHighlighterProps>;
  copyButtonProps?: Partial<CopyToClipboardButtonProps>;
}>;

export { Codeblock as default };
