import React from 'react';

type NavLinkItemType = {
  to: string;
  label?: React.ReactNode;
  isActive: () => boolean;
  items: NavLinkItemType[];
} & React.PropsWithoutRef<NavLinkProps<any>> & React.RefAttributes<HTMLAnchorElement>;
/**
 *
 * The ConfigurePageSidebar component is used in Neeto products to display
 *
 * navigation links on configure pages with simplified UI for navigation. An
 *
 * example of its usage is the NeetoForm Configure page within the form builder.
 *
 * ![Screenshot](https://github.com/bigbinary/neeto-molecules/assets/12969853/3e3f16f0-7296-476a-90c3-2f95846dae62|height=200|width=300)
 *
 * @example 
 *
 * import ConfigurePageSidebar from "@bigbinary/neeto-molecules/ConfigurePageSidebar";
 * import { SIDEBAR_LINKS } from "components/constants";
 * 
 * const App = ({ children }) => {
 *   // custom app logic
 *   return (
 *     <div>
 *       <ConfigurePageSidebar
 *         configurePageRoute={buildUrl(routes.form.configure.index, { formId })}
 *         label="Configure"
 *         navLinks={SIDEBAR_LINKS}
 *       />
 *       {children}
 *     </div>
 *   );
 * };
 * @endexample
*/
declare const ConfigurePageSidebar: React.FC<{
  label: React.ReactNode;
  navLinks: NavLinkItemType[];
  configurePageRoute: string;
}>;

export { ConfigurePageSidebar as default };
