import React from 'react';

/**
 *
 * A container component to be used as a wrapper for the page content.
 *
 * @example 
 *
 * import Container from "@bigbinary/neeto-molecules/Container";
 * 
 * const App = () => (
 *   <Container>
 *     <div>Page content</div>
 *   </Container>
 * );
 * @endexample
 * When we are using the container with the header we can use the isHeaderFixed
 *
 * prop to remove the side padding.
 *
 * @example 
 *
 * import Container from "@bigbinary/neeto-molecules/Container";
 * 
 * const App = () => (
 *   <Container isHeaderFixed>
 *     <Header title="Title" />
 *     <div>Page content</div>
 *   </Container>
 * );
 * @endexample
*/
declare const Container: React.FC<{
  isHeaderFixed?: boolean;
  className?: string;
}>;

export { Container as default };
