import React from 'react';
import { SelectProps } from '@bigbinary/neetoui';

type CurrencyProps = {
  allowedCurrencies?: string[];
} & SelectProps;
/**
 *
 * A component that allows you to select a currency.
 *
 * ![Screenshot](https://github.com/bigbinary/neeto-molecules/assets/10956193/422f706f-8873-4091-866f-f09c24958b69|height=200|width=300)
 *
 * @example 
 *
 * import { useState } from "react";
 * import { Currency } from "@bigbinary/neeto-molecules/Currency";
 * 
 * const CurrencyContainer = () => {
 *   const [currency, setCurrency] = useState();
 *   return <Currency onChange={setCurrency} />;
 * };
 * @endexample
 * The Currency component wrapped in Formik.
 *
 * @example 
 *
 * import * as yup from "yup";
 * import { FormikCurrency } from "@bigbinary/neeto-molecules/Currency";
 * 
 * const FormikCurrencyContainer = () => {
 *   return (
 *     <Form
 *       formikProps={{
 *         initialValues: { currency: null },
 *         validationSchema: yup.object().shape({
 *           currency: yup.object().required(),
 *         }),
 *       }}
 *     >
 *       <FormikCurrency />
 *       <Button className="mt-5" label="Submit" type="submit" />
 *     </Form>
 *   );
 * };
 * @endexample
*/
declare const Currency: React.FC<CurrencyProps>;
declare const FormikCurrency: React.FC<CurrencyProps>;

export { Currency, FormikCurrency };
