import React from 'react';

/**
 *
 * A component to render warning callout when the application is accessed from a
 *
 * mobile browser.
 *
 * @example 
 *
 * import DownloadMobileAppCallout from "@bigbinary/neeto-molecules/DownloadMobileAppCallout";
 * 
 * const App = () => (
 *   <DownloadMobileAppCallout />
 *   <Main />
 * )
 * @endexample
 * The excludePathRegex can be specified like this:
 *
 * @example 
 *
 * const PUBLIC_ROUTE_REGEX = new RegExp(/^\/public/)
 * 
 * <DownloadMobileAppCallout excludePathRegex={PUBLIC_ROUTE_REGEX} />
 * @endexample
 * With this change, the DownloadMobileAppCallout component won't display callout
 *
 * for any path that starts with "/public".
 *
*/
declare const DownloadMobileAppCallout: React.FC<{
  excludePathRegex?: RegExp;
}>;

export { DownloadMobileAppCallout as default };
