import React from 'react';

interface EmailPreviewProps {
  to?: string[];
  subject?: string;
  body?: string;
  from?: string;
  logo?: string;
  actionButtonText?: string;
  className?: string;
  customContent?: React.ReactNode;
}
/**
 *
 * A common component to preview emails.
 *
 * ![EmailPreview](https://user-images.githubusercontent.com/66865722/222370228-cda4ac74-8ec9-4288-ab88-a49b21cab284.png|height=200|width=300)
 *
 * @example 
 *
 * import { useFormikContext } from "formik";
 * import EmailPreview from "@bigbinary/neeto-molecules/EmailPreview";
 * const EmailShare = () => {
 *   const { values } = useFormikContext();
 *   return (
 *     <div>
 *       <EmailPreview
 *         actionButtonText={values.startSurveyButtonText}
 *         body={values.emailBody}
 *         subject={values.emailSubject}
 *         logo={values.logo}
 *         to={values.notifyEmails}
 *         from={values.emailsFrom}
 *       />
 *     </div>
 *   );
 * };
 * export default EmailShare;
 * @endexample
*/
declare const EmailPreview: React.FC<EmailPreviewProps>;

export { type EmailPreviewProps, EmailPreview as default };
