import React from 'react';
import { DropdownProps } from 'neetoui';

type Emoji = {
  native: string;
  unified: string;
};
/**
 *
 * A component to pick emojis.
 *
 * ![Screenshot](https://github.com/bigbinary/neeto-ui/assets/10956193/6238f165-3a55-4e66-bf4f-101971f80c80|height=200|width=300)
 *
 * @example 
 *
 * import EmojiPicker from "@bigbinary/neeto-molecules/EmojiPicker";
 * 
 * const EmojiPickerContainer = () => {
 *   const [emoji, setEmoji] = useState();
 *   return (
 *     <div>
 *       <div>Selected Emoji: {emoji}</div>
 *       <EmojiPicker onSelect={obj => setEmoji(obj.native)} />
 *     </div>
 *   );
 * };
 * @endexample
*/
declare const EmojiPicker: React.FC<{
  onSelect?: (emoji: Emoji) => void;
  open?: boolean;
  dropdownProps?: DropdownProps;
}>;

export { EmojiPicker as default };
