import React from 'react';

interface Data {
  [key: string]: Array<{
    id: string;
    url: string;
    content?: string;
    body?: string;
    name?: string;
  }>;
}
interface IconComponentMap {
  [key: string]: React.ComponentType;
}
/**
 *
 * FinderModal is a component that can be used to search for items across the
 *
 * workspace.
 *
 * ![Screenshot](https://github.com/user-attachments/assets/0078c794-ba20-4657-91d1-89c2c761e31c|height=200|width=300)
 *
 * @example 
 *
 * import { useState } from "react";
 * 
 * import { Tickets, UserCircle } from "@bigbinary/neeto-icons";
 * import FinderModal from "@bigbinary/neeto-molecules/FinderModal";
 * 
 * const App = () => {
 *   const [searchTerm, setSearchTerm] = useState("");
 *   const [isFinderModalOpen, setIsFinderModalOpen] = useState(false);
 * 
 *   const iconComponentMap = { tickets: Tickets, contacts: UserCircle };
 * 
 *   const { data: searchResults, isFetching } = useSearchApi({ searchTerm });
 * 
 *   return (
 *     <FinderModal
 *       data={searchResults}
 *       iconComponentMap={iconComponentMap}
 *       isFetching={isFetching}
 *       isOpen={isFinderModalOpen}
 *       setSearchTerm={setSearchTerm}
 *       onClose={() => setIsFinderModalOpen(false)}
 *       onGoToAdvanced={() => {
 *         history.push("/advanced-search");
 *       }}
 *     />
 *   );
 * };
 * @endexample
*/
declare const FinderModal: React.FC<{
  enableAdvancedSearch?: boolean;
  data: Data;
  iconComponentMap: IconComponentMap;
  isFetching: boolean;
  isOpen: boolean;
  searchTerm: string;
  setSearchTerm: (searchTerm: string) => void;
  onClose: () => void;
  onGoToAdvanced?: () => void;
}>;

export { FinderModal as default };
