import React from 'react';

/**
 *
 * A dropdown component that allows you to select an icon from a list of
 *
 * Google icons.
 *
 * ![image](https://user-images.githubusercontent.com/35304653/243669467-148585f0-5499-4914-ba84-4284bda8e2d8.png|height=200|width=300)
 *
 * We make use of a feature called ligatures that convert the snake cased name of
 *
 * an icon to an actual icon. It is achieved like so. Note that the classname
 *
 * "material-symbols-rounded" is necessary for this conversion to work.
 *
 * @example 
 *
 * <span className="material-symbols-rounded">icon_name</span>
 * @endexample
 * @example 
 *
 * import IconPicker from "@bigbinary/neeto-molecules/IconPicker";
 * 
 * const App = () => {
 *   const [value, setValue] = useState("home");
 *   return (
 *     <IconPicker
 *       value={value}
 *       label="Select an icon"
 *       onClick={value => setValue(value)}
 *     />
 *   );
 * };
 * @endexample
*/
declare const IconPicker: React.FC<{
  filled?: boolean;
  value?: string;
  label?: string;
  onClick?: Function;
  className?: string;
}>;

export { IconPicker as default };
