import { DropdownProps, ButtonProps } from '@bigbinary/neetoui';
import React from 'react';

type MenuItems = {
  label: string;
  onClick: () => void;
  key: string;
  isVisible?: boolean;
  hasSubItems?: boolean;
  dropdownProps?: DropdownProps;
  menuItems?: MenuItems[];
};
type DropdownButtonProps = {
  isRounded?: boolean;
} & ButtonProps;
/**
 *
 * Dropdown menu with a 3 dot trigger button, can be used as a more menu.
 *
 * @example 
 *
 * import MoreDropdown from "@bigbinary/neeto-molecules/MoreDropdown";
 * 
 * const Component = () => (
 *   <MoreDropdown
 *     menuItems={[
 *       {
 *         key: "edit-menu",
 *         label: "Edit",
 *         onClick: () => setIsEditMenuVisible(true),
 *       },
 *       {
 *         key: "delete-menu",
 *         label: "Delete",
 *         onClick: () => setIsDeleteMenuVisible(true),
 *       },
 *     ]}
 *   />
 * );
 * @endexample
*/
declare const MoreDropdown: React.FC<{
  dropdownButtonProps?: DropdownButtonProps;
  isVertical?: boolean;
  isDisabled?: boolean;
  dropdownProps?: DropdownProps;
  menuTopChildren: React.ReactNode;
  menuBottomChildren: React.ReactNode;
  menuItems: MenuItems[];
}>;

export { MoreDropdown as default };
