import React from 'react';

/**
 *
 * Used in neeto products as the page loader to indicate that the page is being
 *
 * loaded.
 *
 * ![image](https://user-images.githubusercontent.com/12969853/225239088-f78bd7b4-ba46-404c-896c-e9e5104f824c.png|height=200|width=300)
 *
 * @example 
 *
 * import PageLoader from "@bigbinary/neeto-molecules/PageLoader";
 * const PageLoaderContainer = ({ children }) => {
 *   return (
 *     <div>
 *       <PageLoader />
 *     </div>
 *   );
 * };
 * @endexample
 * PageLoader with custom text
 *
 * @example 
 *
 * import PageLoader from "@bigbinary/neeto-molecules/PageLoader";
 * const PageLoaderContainer = ({ children }) => {
 *   return (
 *     <div>
 *       <PageLoader text="Loading..." />
 *     </div>
 *   );
 * };
 * @endexample
*/
declare const PageLoader: React.FC<{
  text?: string;
}>;

export { PageLoader as default };
