import React from 'react';

interface InlineProps {
  label: string;
  description: string;
  width?: number;
  height?: number;
  elementSelector?: string;
}
interface FloatingPopupProps {
  label: string;
  description: string;
  btnText?: string;
  btnColor?: string;
  btnTextColor?: string;
  btnPosition?: string;
  icon?: React.FC;
  showIcon?: boolean;
}
interface ElementPopupProps {
  label: string;
  description: string;
  elementSelector?: string;
}
type CodeSampleType = "html" | "react";
/**
 *
 * A component to generate and display the embed code for a product, which can then
 *
 * be pasted into a host application where the product should be embedded. Please
 *
 * note that this component does not embed the product itself but provides the
 *
 * necessary code and a preview to facilitate embedding.
 *
 * Here’s how you can use the ProductEmbed component in your React application:
 *
 * @example 
 *
 * import ProductEmbed from "@bigbinary/neeto-molecules/ProductEmbed";
 * 
 * const EmbedPage = () => (
 *   <ProductEmbed
 *     id="123"
 *     goBackLink="/share"
 *     options={{
 *       inline: {
 *         label: "Inline",
 *         description: "An inline component",
 *         width: 90,
 *         height: 100,
 *         elementSelector: "#inline-embed",
 *       },
 *       floatingPopup: {
 *         label: "Floating Popup",
 *         description: "A floating popup",
 *         btnText: "Schedule meeting",
 *         showIcon: true,
 *         icon: Calendar,
 *       },
 *       elementPopup: {
 *         label: "Element Popup",
 *         description: "An element popup",
 *         elementSelector: "element-id",
 *       },
 *     }}
 *     isQueryParamsEnabled={true}
 *     supportedLanguages={["html", "react"]}
 *   />
 * );
 * 
 * export default EmbedPage;
 * @endexample
*/
declare const ProductEmbed: React.FC<{
  className?: string;
  goBackLink?: string;
  customEmbedScriptPath?: string;
  customPreviewIframeUrl?: string;
  extraArgs?: object;
  id: string;
  options?: {
    inline?: InlineProps;
    floatingPopup?: FloatingPopupProps;
    elementPopup?: ElementPopupProps;
  };
  isQueryParamsEnabled?: boolean;
  otherCustomizations?: Function;
  inlineWrapperStyle?: string;
  supportedLanguages?: CodeSampleType[];
}>;

export { ProductEmbed as default };
