import React from 'react';

type SelectedDeviceState = "desktop" | "tablet" | "mobile";
/**
 *
 * A common component to switch between different device resolutions.
 *
 * ![image](https://user-images.githubusercontent.com/24496302/230879938-43f4a9bc-cb36-496a-be18-79d85fbffb3a.png|height=200|width=300)
 *
 * @example 
 *
 * import ResponsiveDevicePicker from "@bigbinary/neeto-molecules/ResponsiveDevicePicker";
 * 
 * const ResponsiveDevicePickerContainer = ({}) => {
 *   const [selectedDevice, setSelectedDevice] = useState("desktop");
 * 
 *   return (
 *     <ResponsiveDevicePicker
 *       selectedDevice={selectedDevice}
 *       onDeviceChange={setSelectedDevice}
 *     />
 *   );
 * };
 * @endexample
*/
declare const ResponsiveDevicePicker: React.FC<{
  className?: string;
  selectedDevice?: SelectedDeviceState;
  onDeviceChange?: (device: SelectedDeviceState) => void;
}>;

export { ResponsiveDevicePicker as default };
