import { SIZES } from 'components/Scrollable/constants';
import React from 'react';

/**
 *
 * The Scrollable component can be used along with the Header and SubHeader to show
 *
 * large tables or UI that needs scrolling. It provides a scrollable container in
 *
 * the remaining space.
 *
 * @example 
 *
 * import Scrollable from "@bigbinary/neeto-molecules/Scrollable";
 * 
 * const App = () => (
 *   <Scrollable>
 *     {[...Array(20)].map((_, i) => (
 *       <DummyCard key={i} />
 *     ))}
 *   </Scrollable>
 * );
 * @endexample
*/
declare const Scrollable: React.FC<{
  className?: string;
  size?: keyof typeof SIZES;
} & React.DetailedHTMLProps<React.HTMLAttributes<HTMLDivElement>, HTMLDivElement>>;

export { Scrollable as default };
