import React from 'react';
import { InputProps } from 'neetoui';

/**
 *
 * This email input component comes with the capability to include recipients in
 *
 * the Blind Carbon Copy (BCC) and Carbon Copy (CC) fields. The 'showCopyEmail'
 *
 * formik key is used to toggle the visibility of the Cc/Bcc input fields and is
 *
 * automatically added if omitted when clicking the Cc/Bcc
 *
 * button.Additionally,default name attributes, 'sendTo,' 'sendToCc,' and
 *
 * 'sendToBcc,' are provided for the email inputs, which can be customized to suit
 *
 * your needs.
 *
 * @example 
 *
 * import SendToFields from "@bigbinary/neeto-molecules/SendToFields";
 * 
 * const SendToFieldsComponent = () => (
 *   <Form
 *     formikProps={{
 *       enableReinitialize: true,
 *       initialValues: {
 *         sendTo: [],
 *         sendToCc: [],
 *         sendToBcc: [],
 *         showCopyEmail: false,
 *       },
 *     }}
 *   >
 *     <SendToFields
 *       showUploadCsvButton
 *       showCcBccButton
 *       emailInputProps={{
 *         id: "sendTo",
 *         name: "sendTo",
 *       }}
 *       ccInputProps={{
 *         label: "CC",
 *         name: "sendToCc",
 *       }}
 *       bccInputProps={{
 *         label: "BCC",
 *         name: "sendToBcc",
 *       }}
 *     />
 *   </Form>
 * );
 * @endexample
*/
declare const SendToFields: React.FC<{
  inputProps?: InputProps;
  ccInputProps?: InputProps;
  bccInputPropse?: InputProps;
  showUploadCsvButton: boolean;
  showCcBccButton: boolean;
  showCcField?: boolean;
  showBccField?: boolean;
  showSendToField?: boolean;
}>;

export { SendToFields as default };
