import React from 'react';

/**
 *
 * This component can be used to display an input where the value is customizable
 *
 * by the user, but not the suffix. eg: Emails, blog urls etc.
 *
 * @example 
 *
 * import SuffixedInput from "@bigbinary/neeto-molecules/SuffixedInput";
 * 
 * const MailboxConfiguration = () => {
 *   return (
 *     <Form
 *       formikProps={{
 *         initialValues: { email: "" },
 *         onSubmit: noop,
 *         onreset: noop,
 *       }}
 *     >
 *       {({ values: { email } }) => (
 *         <div className="w-full p-6">
 *           <SuffixedInput {...{ ...args }} value={email} name="email" />
 *         </div>
 *       )}
 *     </Form>
 *   );
 * };
 * @endexample
*/
declare const SuffixedInput: React.FC<{
  placeholder?: string;
  helpUrl?: string;
  helpIconTooltipContent?: string;
  label: string;
  value: string;
  getInputRef?: (ref: HTMLInputElement | null) => void;
  suffix: string;
  isCopyToClipboardEnabled?: boolean;
  name?: string;
  inputProps?: object;
}>;

export { SuffixedInput as default };
