import React from 'react';
import { PopoverProps } from '@bigbinary/neetoui';

/**
 *
 * The Taxonomy component is used to manage taxonomies in a project.
 *
 * ![EmailPreview](https://user-images.githubusercontent.com/26121158/281420197-d00435c5-f07d-4e5a-a201-5bbda89e746a.png|height=200|width=300)
 *
 * @example 
 *
 * import Settings from "@bigbinary/neeto-molecules/Settings";
 * import Taxonomy from "@bigbinary/neeto-molecules/Taxonomy";
 * 
 * const Component = () => (
 *   <Settings
 *     categories={[
 *       {
 *         id: "general-settings",
 *         label: "General Settings",
 *         items: [
 *           {
 *             label: "Taxonomy",
 *             description: "Manage default labels for entities",
 *             icon: Tags,
 *             path: "/settings/general/taxonomy",
 *             component: () => (
 *               <Taxonomy
 *                 breadcrumbs={[
 *                   { text: "Settings", link: "/settings/general" },
 *                   { text: "Taxonomy" },
 *                 ]}
 *               />
 *             ),
 *           },
 *         ],
 *       },
 *     ]}
 *   />
 * );
 * @endexample
*/
declare const Taxonomy: React.FC<{
  breadcrumbs: {
    text: string;
    link: string;
  }[];
  columnsToShow?: {
    singularColumn?: boolean;
    pluralColumn?: boolean;
  };
  columnLabels?: {
    singular?: string;
    plural?: string;
  };
  titleHelpPopoverProps?: PopoverProps;
}>;

export { Taxonomy as default };
