import React from 'react';

/**
 *
 * A modal to show when the user's timezone is different from the timezone of the
 *
 * browser. The user can choose to continue with the users timezone or update the
 *
 * user timezone to the browsers's timezone.
 *
 * @example 
 *
 * import TimezoneMismatchModal from "@bigbinary/neeto-molecules/TimezoneMismatchModal";
 * 
 * const App = () => (
 *   <div>
 *     <TimezoneMismatchModal />
 *   </div>
 * );
 * @endexample
 * To control the visibility of the modal, use the isOpen prop. You can also pass
 *
 * a callback to the onClose prop to be called when the modal is closed. Usage:
 *
 * @example 
 *
 * import TimezoneMismatchModal from "@bigbinary/neeto-molecules/TimezoneMismatchModal";
 * 
 * const App = () => (
 *   <div>
 *     <TimezoneMismatchModal isOpen={true} onClose={() => {}} />
 *   </div>
 * );
 * @endexample
*/
declare const TimezoneMismatchModal: React.FC<{
  isOpen?: boolean;
  onClose?: Function;
}>;

export { TimezoneMismatchModal as default };
